.yoast-labeled-inserter{position:relative;width:100%}.yoast-labeled-inserter:before{color:#000;content:attr(data-label);height:100%;left:0;position:absolute}.yoast-labeled-inserter>.block-editor-inserter{width:100%}.yoast-warning-block{border-style:solid;border-width:0 0 0 4px;font-family:Arial,Roboto-Regular,HelveticaNeue,sans-serif;font-size:13px;padding:16px}.yoast-warning-block.required{background:#f8ebea;border-color:#cd423b}.yoast-warning-block.recommended{background:#fef8ee;border-color:#f0b650}.yoast-warning-block>.yoast-warning-block-message{font-family:Arial,Roboto-Regular,HelveticaNeue,sans-serif;margin:0}.yoast-warning-block>div{padding-top:8px;text-align:right}.yoast-warning-block>div>button{background:none;border:none;color:#0073aa;text-decoration:underline}.yoast-schema-block-appender__content{color:#1e1e1e99}.wp-block .yoast-warning-block>.yoast-warning-block-message>a{color:#0073aa;text-decoration:underline}.yoast-warning-block>div>button:not(:last-child){margin-right:24px}.yoast-block-sidebar-input label,.yoast-block-sidebar-title{color:#303030;font-weight:600;margin-bottom:0;padding-top:10px}.yoast-block-label-with-help-link{margin-bottom:3px;width:100%}.yoast-block-suggestions{padding:0 5px 0 15px;width:100%}.yoast-question-mark-icon{color:#767676}.yoast-question-mark-icon:hover{color:#1e8cbe}.yoast-inline-icon{vertical-align:middle}.yoast-block-sidebar-warnings{width:100%}.yoast-block-sidebar-warning{color:#404040;list-style:none;padding:0 0 0 17px}.yoast-block-sidebar-warning>.yoast-svg-icon{color:red;margin-left:-1.5em;margin-right:.5em}.yoast-block-suggestion{color:#707070;list-style:disc}.yoast-block-suggestion--added{color:#404040}.yoast-block-suggestion-checkmark{color:#6ea029}.yoast-block-suggestion-button{background:0;border:0;color:#006dac;cursor:pointer;float:right;text-decoration:underline}.yoast-block-date-picker-container>button{background:none;border:none;color:#747474;font-family:inherit}.yoast-block-date-picker{z-index:1}.yoast-block-date-picker .components-datetime__time>fieldset{margin:0}.yoast-block-date-picker .components-datetime__time>fieldset:last-child{display:none}.yoast-schema-blocks-icon svg{fill:none}.yoast-schema-analysis{margin-bottom:24px}.yoast-schema-flex.yoast-schema-duration{align-items:baseline;overflow:visible}.yoast-schema-flex.yoast-schema-duration p{margin-top:0;white-space:pre}.yoast-schema-duration .minutes-input{display:inline-block;max-width:100px;min-width:40px}.yoast-schema-flex{display:flex;line-height:1.25}.yoast-schema-select select.components-select-control__input{height:100%;padding:6px 33px 6px 8px}.yoast-schema-flex .components-text-control__input,.yoast-schema-select div.components-input-control__backdrop{border:1px solid #ccc;border-radius:0}