@import "../../../base/less/mixins";
@import "widget-mixins";

.widget-function('generate_calls_to', .create_social_media_button_style);

.sow-social-media-button {
	.social-media-button-base();
}

.create_social_media_button_style( @name, @icon_color:'', @button_color:'', @icon_color_hover: '', @button_color_hover: '' ) {

	.sow-social-media-button-@{name} {
		background: transparent;
		text-shadow: 0 1px 0 rgba(0,0,0,0.05);

		& when( iscolor( @button_color ) ) {
			@border_color: darken(@button_color, 15%);
			border: 2px solid @button_color !important;
			color: @button_color !important;

			&.ow-button-hover:focus,
			&.ow-button-hover:hover {
				& when not( iscolor( @button_color_hover ) ) {
					color: @button_color !important;
				}

				& when( iscolor( @button_color_hover ) ) {
					background: @button_color_hover;
				}
			}
		}

		& when( iscolor( @icon_color ) ) {
			&.ow-button-hover:hover {
				& when not( iscolor( @icon_color_hover ) ) {
					color: @icon_color !important;
				}

				& when( iscolor( @icon_color_hover ) ) {
					color: @icon_color_hover !important;
				}
			}
		}
	}
}
