.siteorigin-widget-form .siteorigin-widget-field input{margin:1px;padding:2px 5px}.siteorigin-widget-form .siteorigin-widget-field input[type="radio"]{width:inherit}.siteorigin-widget-form .siteorigin-widget-field select{padding:2px;height:28px;width:inherit;margin:1px}.vc_element-icon.so-widget-icon{background-size:cover;background-image:url("../../base/css/img/bundle-icon.png")}