.panel-grid {
  zoom: 1;
}
.panel-grid:before {
  content: '';
  display: block;
}
.panel-grid:after {
  content: '';
  display: table;
  clear: both;
}
.panel-grid .so-parallax {
  position: relative;
}
.panel-grid .so-parallax > div:not(.simpleParallax) {
  position: relative;
  z-index: 1;
}
.panel-grid .so-parallax .simpleParallax {
  overflow: hidden;
}
.panel-grid .so-parallax .simpleParallax,
.panel-grid .so-parallax img[data-siteorigin-parallax] {
  bottom: 0;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  width: 100%;
  z-index: 0;
}
.panel-grid-cell {
  -ms-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  min-height: 1em;
  float: left;
}
.panel-grid-cell .so-panel {
  zoom: 1;
}
.panel-grid-cell .so-panel:before {
  content: '';
  display: block;
}
.panel-grid-cell .so-panel:after {
  content: '';
  display: table;
  clear: both;
}
.panel-grid-cell .panel-last-child {
  margin-bottom: 0;
}
.panel-grid-cell .widget-title {
  margin-top: 0;
}
.panel-row-style {
  zoom: 1;
}
.panel-row-style:before {
  content: '';
  display: block;
}
.panel-row-style:after {
  content: '';
  display: table;
  clear: both;
}
