@font-face{font-family:'feature-background';src:url('fonts/feature-background.eot');src:url('fonts/feature-background.eot') format('embedded-opentype'),url('fonts/feature-background.woff') format('woff'),url('fonts/feature-background.ttf') format('truetype'),url('fonts/feature-background.svg') format('svg');font-weight:normal;font-style:normal;font-display:block}.sow-features-list .sow-icon-container{font-family:'feature-background';speak:none;font-style:normal;font-weight:normal;font-variant:normal;text-transform:none;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;display:inline-block;font-size:90px;position:relative;color:#404040}.sow-features-list .sow-icon-container.sow-container-round:before{content:"\e600"}.sow-features-list .sow-icon-container.sow-container-sticker:before{content:"\e601"}.sow-features-list .sow-icon-container.sow-container-rounded-sticker:before{content:"\e602"}.sow-features-list .sow-icon-container.sow-container-square:before{content:"\e603"}.sow-features-list .sow-icon-container.sow-container-rounded-square:before{content:"\e604"}.sow-features-list .sow-icon-container.sow-container-rounded-hex:before{content:"\e605"}.sow-features-list .sow-icon-container.sow-container-octagon:before{content:"\e606"}.sow-features-list .sow-icon-container.sow-container-hex:before{content:"\e607"}.sow-features-list .sow-icon-container.sow-container-frame:before{content:"\e608"}.sow-features-list .sow-icon-container.sow-container-explode:before{content:"\e609"}