.fs-badge {
    position: absolute;
    top: 10px;
    right: 0;
    background: #71ae00;
    color: white;
    text-transform: uppercase;
    padding: 5px 10px;
    -moz-border-radius: 3px 0 0 3px;
    -webkit-border-radius: 3px 0 0 3px;
    border-radius: 3px 0 0 3px;
    font-weight: bold;
    border-right: 0;
    -moz-box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.3);
    -webkit-box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.3);
    box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.3);
}
#fs_addons .fs-cards-list {
    list-style: none;
}
#fs_addons .fs-cards-list .fs-card {
    width: 32%;
    padding: 0;
    margin: 0 0.5% 30px;
    font-size: 16px;
    list-style: none;
    border: 1px solid #ddd;
    cursor: pointer;
    position: relative;
    height: 300px;
    min-width: 510px;
}
ul.fs-cards-list {
    display: flex;
    flex-wrap: wrap;
}
#fs_addons .fs-cards-list .fs-card .fs-overlay {
    position: absolute;
    left: 0;
    right: 0;
    bottom: 0;
    top: 0;
    z-index: 9;
}
#fs_addons .fs-cards-list .fs-card .fs-inner {
    background-color: #fff;
    overflow: hidden;
    height: 100%;
    position: relative;
}
#fs_addons .fs-cards-list .fs-card .fs-inner > ul {
    -moz-transition: all, 0.15s;
    -o-transition: all, 0.15s;
    -ms-transition: all, 0.15s;
    -webkit-transition: all, 0.15s;
    transition: all, 0.15s;
    left: 0;
    right: 0;
    top: 0;
    position: absolute;
}
#fs_addons .fs-cards-list .fs-card .fs-inner > ul > li {
    list-style: none;
    line-height: 23px;
    padding: 0 15px;
    width: 100%;
    display: block;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-card-banner {
    padding: 0;
    margin: 0;
    line-height: 0;
    display: block;
    height: auto;
    background-position: right;
    background-repeat: repeat-x;
    background-size: cover;
    -moz-transition: all, 0.15s;
    -o-transition: all, 0.15s;
    -ms-transition: all, 0.15s;
    -webkit-transition: all, 0.15s;
    transition: all, 0.15s;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-card-banner img{
    width:100%;
    height: auto;
    min-height: 186px;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-card-banner .fs-badge.fs-installed-addon-badge {
    font-size: 1.02em;
    line-height: 1.3em;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-title {
    margin: 10px 0 0 0;
    height: auto;
    overflow: hidden;
    color: #000;
    white-space: nowrap;
    text-overflow: ellipsis;
    font-weight: bold;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-offer {
    font-size: 0.9em;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-description {
    background-color: #f9f9f9;
    padding: 4px 15px 100px 15px;
    border-top: 1px solid #eee;
    margin: 0 0 10px 0;
    color: #777;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-tag {
    position: absolute;
    top: 10px;
    right: 0px;
    background: greenyellow;
    display: block;
    padding: 2px 10px;
    -moz-box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);
    -webkit-box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);
    box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);
    text-transform: uppercase;
    font-size: 0.9em;
    font-weight: bold;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-cta .button,
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-cta .button-group {
    position: absolute;
    top: 144px;
    right: 10px;
}
@media screen and (min-width: 960px) {
    #fs_addons .fs-cards-list .fs-card:hover .fs-overlay {
        border: 2px solid #29abe1;
        margin-left: -1px;
        margin-top: -1px;
    }
    #fs_addons .fs-cards-list .fs-card:hover .fs-inner ul {
        top: -100px;
    }
    #fs_addons .fs-cards-list .fs-card:hover .fs-inner .fs-title,
    #fs_addons .fs-cards-list .fs-card:hover .fs-inner .fs-offer {
        color: #29abe1;
    }
}
#TB_window,
#TB_window iframe {
    width: 821px !important;
}
#plugin-information .fyi {
    width: 266px !important;
}
#plugin-information #section-holder {
    margin-right: 299px;
}
#plugin-information #section-description h2,
#plugin-information #section-description h3,
#plugin-information #section-description p,
#plugin-information #section-description b,
#plugin-information #section-description i,
#plugin-information #section-description blockquote,
#plugin-information #section-description li,
#plugin-information #section-description ul,
#plugin-information #section-description ol {
    clear: none;
}
#plugin-information #section-description iframe {
    max-width: 100%;
}
#plugin-information #section-description .fs-selling-points {
    padding-bottom: 10px;
    border-bottom: 1px solid #ddd;
}
#plugin-information #section-description .fs-selling-points ul {
    margin: 0;
}
#plugin-information #section-description .fs-selling-points ul li {
    padding: 0;
    list-style: none outside none;
}
#plugin-information #section-description .fs-selling-points ul li i.dashicons {
    color: #71ae00;
    font-size: 3em;
    vertical-align: middle;
    line-height: 30px;
    float: left;
    margin: 0 0 0 -15px;
}
#plugin-information #section-description .fs-selling-points ul li h3 {
    margin: 1em 30px !important;
}
#plugin-information #section-description .fs-screenshots:after {
    content: "";
    display: table;
    clear: both;
}
#plugin-information #section-description .fs-screenshots ul {
    list-style: none;
    margin: 0;
}
#plugin-information #section-description .fs-screenshots ul li {
    width: 225px;
    height: 225px;
    float: left;
    margin-bottom: 20px;
    -moz-box-sizing: content-box;
    -webkit-box-sizing: content-box;
    box-sizing: content-box;
}
#plugin-information #section-description .fs-screenshots ul li a {
    display: block;
    width: 100%;
    height: 100%;
    border: 1px solid;
    -moz-box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.2);
    -webkit-box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.2);
    box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.2);
    background-size: cover;
}
#plugin-information #section-description .fs-screenshots ul li.odd {
    margin-right: 20px;
}
#plugin-information .plugin-information-pricing {
    margin: -16px;
    border-bottom: 1px solid #ddd;
}
#plugin-information .plugin-information-pricing .fs-plan h3 {
    margin-top: 0;
    padding: 20px;
    font-size: 16px;
}
#plugin-information .plugin-information-pricing .fs-plan .nav-tab-wrapper {
    border-bottom: 1px solid #ddd;
}
#plugin-information .plugin-information-pricing .fs-plan .nav-tab-wrapper .nav-tab {
    cursor: pointer;
    position: relative;
    padding: 0 10px;
    font-size: 0.9em;
}
#plugin-information .plugin-information-pricing .fs-plan .nav-tab-wrapper .nav-tab label {
    text-transform: uppercase;
    color: green;
    background: greenyellow;
    position: absolute;
    left: -1px;
    right: -1px;
    bottom: 100%;
    border: 1px solid darkgreen;
    padding: 2px;
    text-align: center;
    font-size: 0.9em;
    line-height: 1em;
}
#plugin-information .plugin-information-pricing .fs-plan .nav-tab-wrapper .nav-tab.nav-tab-active {
    cursor: default;
    background: #fffeec;
    border-bottom-color: #fffeec;
}
#plugin-information .plugin-information-pricing .fs-plan.fs-single-cycle h3 {
    background: #fffeec;
    margin: 0;
    padding-bottom: 0;
    color: #0073aa;
}
#plugin-information .plugin-information-pricing .fs-plan.fs-single-cycle .nav-tab-wrapper,
#plugin-information .plugin-information-pricing .fs-plan.fs-single-cycle .fs-billing-frequency {
    display: none;
}
#plugin-information .plugin-information-pricing .fs-plan .fs-pricing-body {
    background: #fffeec;
    padding: 20px;
}
#plugin-information .plugin-information-pricing .fs-plan .button {
    width: 100%;
    text-align: center;
    font-weight: bold;
    text-transform: uppercase;
    font-size: 1.1em;
}
#plugin-information .plugin-information-pricing .fs-plan label {
    white-space: nowrap;
}
#plugin-information .plugin-information-pricing .fs-plan var {
    font-style: normal;
}
#plugin-information .plugin-information-pricing .fs-plan .fs-billing-frequency,
#plugin-information .plugin-information-pricing .fs-plan .fs-annual-discount {
    text-align: center;
    display: block;
    font-weight: bold;
    margin-bottom: 10px;
    text-transform: uppercase;
    background: #f3f3f3;
    padding: 2px;
    border: 1px solid #ccc;
}
#plugin-information .plugin-information-pricing .fs-plan .fs-annual-discount {
    text-transform: none;
    color: green;
    background: greenyellow;
}
#plugin-information .plugin-information-pricing .fs-plan ul.fs-trial-terms {
    font-size: 0.9em;
}
#plugin-information .plugin-information-pricing .fs-plan ul.fs-trial-terms i {
    float: left;
    margin: 0 0 0 -15px;
}
#plugin-information .plugin-information-pricing .fs-plan ul.fs-trial-terms li {
    margin: 10px 0 0 0;
}
#plugin-information #section-features .fs-features {
    margin: -20px -26px;
}
#plugin-information #section-features table {
    width: 100%;
    border-spacing: 0;
    border-collapse: separate;
}
#plugin-information #section-features table thead th {
    padding: 10px 0;
}
#plugin-information #section-features table thead .fs-price {
    color: #71ae00;
    font-weight: normal;
    display: block;
    text-align: center;
}
#plugin-information #section-features table tbody td {
    border-top: 1px solid #ccc;
    padding: 10px 0;
    text-align: center;
    width: 100px;
    color: #71ae00;
}
#plugin-information #section-features table tbody td:first-child {
    text-align: left;
    width: auto;
    color: inherit;
    padding-left: 26px;
}
#plugin-information #section-features table tbody tr.fs-odd td {
    background: #fefefe;
}
#plugin-information #section-features .dashicons-yes {
    width: 30px;
    height: 30px;
    font-size: 30px;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown .button-group .button,
#plugin-information .fs-dropdown .button-group .button {
    position: relative;
    width: auto;
    top: 0;
    right: 0;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown .button-group .button:focus,
#plugin-information .fs-dropdown .button-group .button:focus {
    z-index: 10;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown .button-group .fs-dropdown-arrow,
#plugin-information .fs-dropdown .button-group .fs-dropdown-arrow {
    border-top: 6px solid white;
    border-right: 4px solid transparent;
    border-left: 4px solid transparent;
    top: 12px;
    position: relative;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown.active:not(.up) .button:not(.fs-dropdown-arrow-button),
#plugin-information .fs-dropdown.active:not(.up) .button:not(.fs-dropdown-arrow-button) {
    border-bottom-left-radius: 0;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown.active:not(.up) .fs-dropdown-arrow-button,
#plugin-information .fs-dropdown.active:not(.up) .fs-dropdown-arrow-button {
    border-bottom-right-radius: 0;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown.active.up .button:not(.fs-dropdown-arrow-button),
#plugin-information .fs-dropdown.active.up .button:not(.fs-dropdown-arrow-button) {
    border-top-left-radius: 0;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown.active.up .fs-dropdown-arrow-button,
#plugin-information .fs-dropdown.active.up .fs-dropdown-arrow-button {
    border-top-right-radius: 0;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown .fs-dropdown-list,
#plugin-information .fs-dropdown .fs-dropdown-list {
    position: absolute;
    right: -1px;
    top: 100%;
    margin-left: auto;
    padding: 3px 0;
    border: 1px solid #bfbfbf;
    background-color: #fff;
    z-index: 1;
    width: 230px;
    text-align: left;
    -moz-box-shadow: 0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14),
        0px 1px 10px 0px rgba(0, 0, 0, 0.12);
    -webkit-box-shadow: 0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14),
        0px 1px 10px 0px rgba(0, 0, 0, 0.12);
    box-shadow: 0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14),
        0px 1px 10px 0px rgba(0, 0, 0, 0.12);
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown .fs-dropdown-list li,
#plugin-information .fs-dropdown .fs-dropdown-list li {
    margin: 0;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown .fs-dropdown-list li a,
#plugin-information .fs-dropdown .fs-dropdown-list li a {
    display: block;
    padding: 5px 10px;
    text-decoration: none;
    text-shadow: none;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown .fs-dropdown-list li:hover,
#plugin-information .fs-dropdown .fs-dropdown-list li:hover {
    background-color: #0074a3;
    color: #fff;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown .fs-dropdown-list li:hover a,
#plugin-information .fs-dropdown .fs-dropdown-list li:hover a {
    color: #fff;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown:not(.up) .fs-dropdown-list,
#plugin-information .fs-dropdown:not(.up) .fs-dropdown-list {
    -moz-border-radius: 3px 0 3px 3px;
    -webkit-border-radius: 3px 0 3px 3px;
    border-radius: 3px 0 3px 3px;
}
#fs_addons .fs-cards-list .fs-card .fs-inner .fs-dropdown.up .fs-dropdown-list,
#plugin-information .fs-dropdown.up .fs-dropdown-list {
    -moz-border-radius: 3px 3px 0 3px;
    -webkit-border-radius: 3px 3px 0 3px;
    border-radius: 3px 3px 0 3px;
}
#plugin-information .fs-dropdown .button-group {
    width: 100%;
}
#plugin-information .fs-dropdown .button-group .button {
    float: none;
    font-size: 14px;
    font-weight: normal;
    text-transform: none;
}
#plugin-information .fs-dropdown .fs-dropdown-list {
    margin-top: 1px;
}
#plugin-information .fs-dropdown.up .fs-dropdown-list {
    top: auto;
    bottom: 100%;
    margin-bottom: 2px;
}
#plugin-information.wp-core-ui .fs-pricing-body .fs-dropdown .button-group {
    text-align: center;
    display: table;
}
#plugin-information.wp-core-ui .fs-pricing-body .fs-dropdown .button-group .button {
    display: table-cell;
}
#plugin-information.wp-core-ui .fs-pricing-body .fs-dropdown .button-group .button:not(.fs-dropdown-arrow-button) {
    left: 1px;
    width: 100%;
}
#plugin-information-footer > .button,
#plugin-information-footer .fs-dropdown {
    position: relative;
    top: 3px;
}
#plugin-information-footer > .button.left,
#plugin-information-footer .fs-dropdown.left {
    float: left;
}
#plugin-information-footer > .right,
#plugin-information-footer .fs-dropdown {
    float: right;
}
@media screen and (max-width: 961px) {
    #fs_addons .fs-cards-list .fs-card {
        height: 265px;
    }
}
