.sow-cta-base{zoom:1;padding:2em 2.5em}.sow-cta-base:before{content:'';display:block}.sow-cta-base:after{content:'';display:table;clear:both}.sow-cta-base .sow-cta-text .sow-cta-title,.sow-cta-base .sow-cta-text .sow-cta-subtitle,.sow-cta-base .sow-cta-text p{margin:.4em 0}.sow-cta-base .sow-cta-text .sow-cta-title{margin-top:0}.sow-cta-base .sow-cta-text .sow-cta-subtitle,.sow-cta-base .sow-cta-text p{margin-bottom:0;font-weight:normal}@media screen and (max-width:640px){.sow-cta-base{text-align:center;padding:1.75em}.sow-cta-base .sow-cta-text{float:none}.sow-cta-base .so-widget-sow-button{display:inline-block;float:none;margin-top:2em !important;margin-left:0!important}}