<?php
	$list = '';

	foreach($instance['list'] as $item) {
		$list .= '[pricing_table_row]' . $item['text'] . '[/pricing_table_row]';
	}
	
	echo do_shortcode('[pricing_table  link="' . $instance['link'] . '" link_text="' . $instance['link_text'] . '" title="' . $instance['title'] . '" price="' . $instance['price'] . '"  currency="' . $instance['currency'] . '"]' . $list . '[/pricing_table]');
?>