<?php

return array(
	'light_dashed' => array(
		'texture' => 'light-dashed',
		'title_text_color' => '#333333',
		'subtitle_text_color' => '#555555',
	),

	'dark_dashed' => array(
		'texture' => 'dark-dashed',
		'title_text_color' => '#FFFFFF',
		'subtitle_text_color' => '#CCCCCC',
	),

	'clean' => array(
		'background_color' => '#FCFCFC',
		'texture' => 'none',
		'title_text_color' => '#333333',
		'subtitle_text_color' => '#555555',
		'rounding' => '0px',
		'borders' => '1px solid #D0D0D0',
	),
);
