@font-face{font-family:'post-carousel-arrows';src:url('fonts/carousel-arrows.eot?-95vnmw');src:url('fonts/carousel-arrows.eot?#iefix-95vnmw') format('embedded-opentype'),url('fonts/carousel-arrows.woff?-95vnmw') format('woff'),url('fonts/carousel-arrows.ttf?-95vnmw') format('truetype'),url('fonts/carousel-arrows.svg?-95vnmw#carousel-arrows') format('svg');font-weight:normal;font-style:normal;font-display:block}.sow-post-carousel-theme-base .sow-carousel-title.has-title{align-items:baseline;display:flex}.sow-post-carousel-theme-base .sow-carousel-title.has-title .sow-carousel-navigation{margin-left:auto}body.rtl .sow-post-carousel-theme-base .sow-carousel-title.has-title .sow-carousel-navigation{margin-right:auto;margin-left:initial}.sow-post-carousel-theme-base .sow-carousel-title .widget-title{display:inline-block;padding-right:15px}.sow-post-carousel-theme-base .sow-carousel-title .sow-carousel-navigation{float:right}body.rtl .sow-post-carousel-theme-base .sow-carousel-title .sow-carousel-navigation{float:left}body.rtl .sow-post-carousel-theme-base .sow-carousel-title .sow-carousel-navigation a{margin-left:0;margin-right:2px}.sow-post-carousel-theme-base a.sow-carousel-next,.sow-post-carousel-theme-base a.sow-carousel-previous{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;border-radius:2px;display:block;float:right;font-family:'post-carousel-arrows';font-size:8px;font-style:normal;font-variant:normal;font-weight:normal;line-height:18px;margin-left:2px;margin-top:3px;text-align:center;text-decoration:none;text-transform:none;width:18px}.sow-post-carousel-theme-base a.sow-carousel-previous:before{content:"\e600"}.sow-post-carousel-theme-base a.sow-carousel-next:before{content:"\e601"}.sow-post-carousel-theme-base .sow-carousel-wrapper{left:0;overflow:hidden;position:relative;right:0}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items{zoom:1;margin:0;padding:0;transition:all .45s ease}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items:before{content:'';display:block}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items:after{clear:both;content:'';display:table}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items .sow-carousel-item{display:block;margin-right:15px}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items .sow-carousel-item .sow-carousel-thumbnail{line-height:0}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items .sow-carousel-item .sow-carousel-thumbnail:focus{outline:none}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items .sow-carousel-item .sow-carousel-thumbnail a{display:block;background-position:center center}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items .sow-carousel-item .sow-carousel-thumbnail a,.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items .sow-carousel-item .sow-carousel-thumbnail a span.overlay{transition:all .35s ease}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items .sow-carousel-item .sow-carousel-thumbnail a span.overlay{display:block;width:100%;height:100%;opacity:0;position:static}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items .sow-carousel-item .sow-carousel-default-thumbnail{display:block;background:#E8E8E8;background:-webkit-gradient(linear, left bottom, left top, color-stop(0, #E0E0E0), color-stop(1, #E8E8E8));background:-ms-linear-gradient(bottom, #E0E0E0, #E8E8E8);background:-moz-linear-gradient(center bottom, #E0E0E0 0%, #E8E8E8 100%);background:-o-linear-gradient(#E8E8E8, #E0E0E0)}.sow-post-carousel-theme-base .sow-carousel-wrapper .sow-carousel-items .sow-carousel-loading{display:block;background:url(images/carousel-loader.gif) #F6F6F6 center center no-repeat;margin:0}