<?php

namespace Yoast\WP\SEO\Actions\Indexing;

/**
 * Action for preparing the indexing routine.
 *
 * @deprecated 15.3 - Use \Yoast\WP\SEO\Actions\Indexing\Indexing_Prepare_Action instead.
 * @codeCoverageIgnore
 */
class Indexable_Prepare_Indexation_Action extends Indexing_Prepare_Action {

}
