<?php

/**
 * Class QRCodeException
 *
 * @filesource   QRCodeException.php
 * @created      27.11.2015
 * @package      chillerlan\QRCode
 * @author       Smiley <smiley@chillerlan.net>
 * @copyright    2015 Smiley
 * @license      MIT
 */
namespace YoastSEO_Vendor\chillerlan\QRCode;

use Exception;
/**
 * Placeholder
 */
class QRCodeException extends \Exception
{
}
