<?php

namespace Yoast\WP\SEO\Actions\Indexation;

/**
 * Reindexation action for post indexables.
 *
 * @deprecated 15.1 - Use \Yoast\WP\SEO\Actions\Indexing\Indexable_Post_Indexation_Action instead.
 * @codeCoverageIgnore
 */
class Indexable_Post_Indexation_Action extends \Yoast\WP\SEO\Actions\Indexing\Indexable_Post_Indexation_Action {

}
