<?php

/**
 * Class QRCodeDataException
 *
 * @filesource   QRCodeDataException.php
 * @created      09.12.2015
 * @package      chillerlan\QRCode\Data
 * @author       Smiley <smiley@chillerlan.net>
 * @copyright    2015 Smiley
 * @license      MIT
 */
namespace YoastSEO_Vendor\chillerlan\QRCode\Data;

use Exception;
/**
 * Placeholder
 */
class QRCodeDataException extends \Exception
{
}
