<?php

/*
Widget Name: Visual Editor widget
Description: TinyMCE editor for inserting content.
Author: Gfxbucket
Author URI: http://themeforest.net/user/gfxbucket
*/

class Gfxbucket_Visual_Editor extends SiteOrigin_Widget {
	function __construct() {
		parent::__construct(
			'gfxbucket-visual-editor',
			__('Gfxbucket Visual Editor', 'gfxbucket-shortcodes'),
			array(
				'description'  => __('TinyMCE editor for inserting content.', 'gfxbucket-shortcodes'),
				'panels_groups' => array('gfxbucket-widgets'),
				'panels_icon' => 'fa fa-indent'
			),
			array(),
			array(
				'text' => array(
					'type' => 'tinymce',
					'label' => __( 'Text', 'gfxbucket-shortcodes' )
				),
			),
			plugin_dir_path(__FILE__)
		);
	}

	function get_template_name($instance) {
		return 'template';
	}

	function get_style_name($instance) {
		return 'style';
	}
}

siteorigin_widget_register('gfxbucket-visual-editor', __FILE__, 'Gfxbucket_Visual_Editor');