<?php

/**
 * Class QRCodeOutputException
 *
 * @filesource   QRCodeOutputException.php
 * @created      09.12.2015
 * @package      chillerlan\QRCode
 * @author       Smiley <smiley@chillerlan.net>
 * @copyright    2015 Smiley
 * @license      MIT
 */
namespace YoastSEO_Vendor\chillerlan\QRCode\Output;

use Exception;
/**
 * Placeholder
 */
class QRCodeOutputException extends \Exception
{
}
