<?php
	echo do_shortcode('[blog per_page="' . $instance['per_page'] . '" type="' . $instance['type'] . '" categories="' . $instance['categories'] . '" pagination="' . $instance['pagination'] . '"]');
?>