<?php

function gfxbucket_section_title_func( $atts, $content ) {
	return '<h3 class="section-title">' . do_shortcode($content) . '</h3>';
}
add_shortcode( 'section_title', 'gfxbucket_section_title_func' );