div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field .sow-multi-measurement-container{display:flex}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field .sow-multi-measurement-container .sow-multi-measurement-input-container:not(:first-child){margin-left:15px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field .sow-multi-measurement-container .sow-multi-measurement-input-container>label{display:block;padding-left:5px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field .sow-multi-measurement-container .sow-multi-measurement-input-container input[type="text"].sow-multi-measurement-input{max-width:58px;margin:1px;height:28px;vertical-align:middle}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field .sow-multi-measurement-container .sow-multi-measurement-input-container select.sow-multi-measurement-select-unit{min-width:inherit}