.sow-testimonials{display:flex;flex-wrap:wrap}.sow-testimonials *{box-sizing:border-box}.sow-testimonials .sow-testimonial-wrapper{padding:10px}.sow-testimonials .sow-testimonial-wrapper.sow-layout-side .sow-testimonial{display:flex}.sow-testimonials .sow-testimonial-user{position:relative}.sow-testimonials .sow-testimonial-user .sow-round-image-frame{background-size:cover;display:inline-block}.sow-testimonials .sow-testimonial-user .sow-image-wrapper{display:block}.sow-testimonials .sow-testimonial-user .sow-text strong{display:block}.sow-testimonials .sow-testimonial-user .sow-caret{position:absolute;height:24px;width:14px;top:20px;right:-3px;fill:#f0f0f0}.sow-testimonials .sow-testimonial-text{width:100%}.sow-testimonials .sow-testimonial-text>*:first-child{margin-top:0}.sow-testimonials .sow-testimonial-text>*:last-child{margin-bottom:0}.sow-testimonials .sow-user-left .sow-testimonial-user{text-align:left}.sow-testimonials .sow-user-right .sow-image-wrapper{float:right}.sow-testimonials .sow-user-right .sow-text{clear:both}.sow-testimonials .sow-user-right .sow-testimonial-user{text-align:right}.sow-testimonials .sow-user-right .sow-testimonial{flex-direction:row-reverse}.sow-testimonials .sow-user-middle .sow-image-wrapper{margin:0 auto}.sow-testimonials .sow-user-middle .sow-testimonial-user{text-align:center}