<?php
	$new_window = '';
	if( !empty($instance['button_new_window']) ) {
		$new_window = 'true';
	}

	$image = $instance['image_fallback'];

	if( $instance['image'] ) {
		$image = wp_get_attachment_image_src($instance['image'], 'full');
		$image = $image[0];
	}

	echo do_shortcode('[member image="' . $image . '" text="' . $instance['text'] . '" new_window="' . $new_window . '" url="' . $instance['url'] . '" url_text="' . $instance['url_text'] . '"]');
?>