@font-face {
	font-family: 'sow-icomoon';
	src:  url('font/icomoon.eot?kbir8s');
	src:  url('font/icomoon.eot?kbir8s#iefix') format('embedded-opentype'),
	url('font/icomoon.ttf?kbir8s') format('truetype'),
	url('font/icomoon.woff?kbir8s') format('woff'),
	url('font/icomoon.svg?kbir8s#icomoon') format('svg');
	font-weight: normal;
	font-style: normal;
	font-display: block;
}

.sow-icon-icomoon {
	font-family: 'sow-icomoon';
	speak: none;
	font-style: normal;
	font-weight: normal;
	font-variant: normal;
	text-transform: none;
	line-height: 1;

	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.sow-icon-icomoon[data-sow-icon]:before {
	content: attr(data-sow-icon);
}
