<?php

return array(
	'facebook'    => array(
		'label'    => __( 'Facebook', 'so-widgets-bundle' ),
		'base_url' => 'https://www.facebook.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#3A5795'
	),
	'twitter'     => array(
		'label'    => __( 'Twitter', 'so-widgets-bundle' ),
		'base_url' => 'https://twitter.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#78BDF1'
	),
	'rss'         => array(
		'label'    => __( 'RSS', 'so-widgets-bundle' ),
		'base_url' => get_bloginfo('rss_url'),
		'icon_color' => '#FFFFFF',
		'button_color' => '#FAA21B'
	),
	'email'   => array(
		'label'    => __( 'Email', 'so-widgets-bundle' ),
		'base_url' => 'mailto:',
		'icon_color' => '#FFFFFF',
		'button_color' => '#99C4E6'
	),
	'phone'   => array(
		'label'    => __( 'Phone', 'so-widgets-bundle' ),
		'base_url' => 'tel:',
		'icon_color' => '#FFFFFF',
		'button_color' => '#99E5AA'
	),
	'snapchat'    => array(
		'label'    => __( 'Snapchat', 'so-widgets-bundle' ),
		'base_url' => 'https://www.snapchat.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#FFFC00'
	),
	'skype'    => array(
		'label'    => __( 'Skype', 'so-widgets-bundle' ),
		'base_url' => 'https://skype.com/',
		'icon_color' => '#0078d7',
		'button_color' => '#FFFFFF'
	),
	'linkedin'    => array(
		'label'    => __( 'LinkedIn', 'so-widgets-bundle' ),
		'base_url' => 'https://www.linkedin.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#0177B4'
	),
	'pinterest'   => array(
		'label'    => __( 'Pinterest', 'so-widgets-bundle' ),
		'base_url' => 'https://www.pinterest.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#DB7C83'
	),
	'tumblr'   => array(
		'label'    => __( 'Tumblr', 'so-widgets-bundle' ),
		'base_url' => 'https://www.tumblr.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#36465D'
	),
	'instagram'   => array(
		'label'    => __( 'Instagram', 'so-widgets-bundle' ),
		'base_url' => 'https://instagram.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#3D739C'
	),
	'vk'   => array(
		'label'    => __( 'VK', 'so-widgets-bundle' ),
		'base_url' => 'https://vk.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#537599'
	),
	'flickr'   => array(
		'label'    => __( 'Flickr', 'so-widgets-bundle' ),
		'base_url' => 'https://www.flickr.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#D40057'
	),
	'vine'   => array(
		'label'    => __( 'Vine', 'so-widgets-bundle' ),
		'base_url' => 'https://vine.co/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#17B48A'
	),

	// The rest of the networks, alphabetically

	'500px'   => array(
		'label'    => __( '500px', 'so-widgets-bundle' ),
		'base_url' => 'https://500px.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#292929'
	),
	'angellist'   => array(
		'label'    => __( 'AngelList', 'so-widgets-bundle' ),
		'base_url' => 'https://angel.co/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#2A2929'
	),
	'bandcamp'   => array(
		'label'    => __( 'Bandcamp', 'so-widgets-bundle' ),
		'base_url' => 'https://bandcamp.com/',
		'icon_color' => '#1da0c3',
		'button_color' => '#FFFFFF'
	),
	'behance'   => array(
		'label'    => __( 'Behance', 'so-widgets-bundle' ),
		'base_url' => 'https://www.behance.net/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#333333'
	),
	'bitbucket'   => array(
		'label'    => __( 'Bitbucket', 'so-widgets-bundle' ),
		'base_url' => 'https://bitbucket.org/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#205081'
	),
	'blogger-b'   => array(
		'label'    => __( 'Blogger', 'so-widgets-bundle' ),
		'base_url' => 'https://www.blogger.com/',
		'icon_color' => '#f1f1f1',
		'button_color' => '#ff5722'
	),
	'codepen'   => array(
		'label'    => __( 'Codepen', 'so-widgets-bundle' ),
		'base_url' => 'https://codepen.io/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#2A2A2A'
	),
	'delicious'   => array(
		'label'    => __( 'Delicious', 'so-widgets-bundle' ),
		'base_url' => 'https://delicious.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#58ACFD'
	),
	'deviantart'   => array(
		'label'    => __( 'deviantArt', 'so-widgets-bundle' ),
		'base_url' => 'http://www.deviantart.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#B2C01C'
	),
	'discord'   => array(
		'label'    => __( 'Discord', 'so-widgets-bundle' ),
		'base_url' => 'https://discord.gg/',
		'icon_color' => '#ffffff',
		'button_color' => '#7289da',
	),
	'dribbble'   => array(
		'label'    => __( 'Dribbble', 'so-widgets-bundle' ),
		'base_url' => 'https://dribbble.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#F26798'
	),
	'dropbox'   => array(
		'label'    => __( 'Dropbox', 'so-widgets-bundle' ),
		'base_url' => 'https://www.dropbox.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#1388E6'
	),
	'foursquare'   => array(
		'label'    => __( 'Foursquare', 'so-widgets-bundle' ),
		'base_url' => 'https://foursquare.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#EB4E79'
	),
	'github'   => array(
		'label'    => __( 'Github', 'so-widgets-bundle' ),
		'base_url' => 'https://github.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#202021'
	),
	'gittip'   => array(
		'label'    => __( 'Gratipay', 'so-widgets-bundle' ),
		'base_url' => 'https://gratipay.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#653614'
	),
	'goodreads-g'   => array(
		'label'    => __( 'Goodreads', 'so-widgets-bundle' ),
		'base_url' => 'https://goodreads.com/',
		'icon_color' => '#372213',
		'button_color' => '#e2e0d1'
	),
	'google' => array(
		'label'    => __( 'Google', 'so-widgets-bundle' ),
		'base_url' => 'https://google.com/',
		'icon_color' => '#4285F4',
		'button_color' => '#FFFFFF'
	),
	'hacker-news'   => array(
		'label'    => __( 'Hacker News', 'so-widgets-bundle' ),
		'base_url' => 'https://news.ycombinator.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#FF6600'
	),
	'imdb'   => array(
		'label'    => __( 'IMDb', 'so-widgets-bundle' ),
		'base_url' => 'https://www.imdb.com/',
		'icon_color' => '#F3CE13',
		'button_color' => '#000'
	),
	'jsfiddle'   => array(
		'label'    => __( 'JSFiddle', 'so-widgets-bundle' ),
		'base_url' => 'http://jsfiddle.net/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#4679BD'
	),
	'lastfm'   => array(
		'label'    => __( 'Last.fm', 'so-widgets-bundle' ),
		'base_url' => 'https://www.last.fm/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#C02C0C'
	),
	'reddit'   => array(
		'label'    => __( 'Reddit', 'so-widgets-bundle' ),
		'base_url' => 'https://www.reddit.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#CEE3F8'
	),
	'slack'   => array(
		'label'    => __( 'Slack', 'so-widgets-bundle' ),
		'base_url' => 'https://www.slack.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#4D394B'
	),
	'slideshare'   => array(
		'label'    => __( 'Slideshare', 'so-widgets-bundle' ),
		'base_url' => 'https://www.slideshare.net/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#00A8AA'
	),
	'soundcloud'   => array(
		'label'    => __( 'Soundcloud', 'so-widgets-bundle' ),
		'base_url' => 'https://soundcloud.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#FE4600'
	),
	'spotify'   => array(
		'label'    => __( 'Spotify', 'so-widgets-bundle' ),
		'base_url' => 'https://www.spotify.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#7BB72F'
	),
	'stack-exchange'   => array(
		'label'    => __( 'Stack Exchange', 'so-widgets-bundle' ),
		'base_url' => 'http://stackexchange.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#245598'
	),
	'stack-overflow'   => array(
		'label'    => __( 'Stack Overflow', 'so-widgets-bundle' ),
		'base_url' => 'http://stackoverflow.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#F57920'
	),
	'steam'   => array(
		'label'    => __( 'Steam', 'so-widgets-bundle' ),
		'base_url' => 'http://steamcommunity.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#171A21'
	),
	'strava'   => array(
		'label'    => __( 'Strava', 'so-widgets-bundle' ),
		'base_url' => 'https://www.strava.com/athletes/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#fc4c02'
	),
	'stumbleupon'   => array(
		'label'    => __( 'StumbleUpon', 'so-widgets-bundle' ),
		'base_url' => 'https://www.stumbleupon.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#EB4924'
	),
	'telegram-plane'   => array(
		'label'    => __( 'Telegram', 'so-widgets-bundle' ),
		'base_url' => 'https://t.me/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#27a7e5'
	),
	'tiktok'      => array(
		'label'    => __( 'TikTok', 'so-widgets-bundle' ),
		'base_url' => 'https://www.tiktok.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#000',
	),
	'trello'   => array(
		'label'    => __( 'Trello', 'so-widgets-bundle' ),
		'base_url' => 'https://trello.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#0E74AF'
	),
	'tripadvisor'   => array(
		'label'    => __( 'TripAdvisor', 'so-widgets-bundle' ),
		'base_url' => 'https://www.tripadvisor.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#589442'
	),
	'twitch'   => array(
		'label'    => __( 'Twitch', 'so-widgets-bundle' ),
		'base_url' => 'https://www.twitch.tv/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#6542A6'
	),
	'vimeo-square'   => array(
		'label'    => __( 'Vimeo', 'so-widgets-bundle' ),
		'base_url' => 'https://vimeo.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#5BC8FF'
	),
	'whatsapp'   => array(
		'label'    => __( 'WhatsApp', 'so-widgets-bundle' ),
		'base_url' => 'https://www.whatsapp.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#25D366'
	),
	'wordpress'   => array(
		'label'    => __( 'WordPress', 'so-widgets-bundle' ),
		'base_url' => 'https://wordpress.org/',
		'icon_color' => '#797979',
		'button_color' => '#222222'
	),
	'xing'   => array(
		'label'    => __( 'Xing', 'so-widgets-bundle' ),
		'base_url' => 'https://www.xing.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#00605E'
	),
	'yahoo'   => array(
		'label'    => __( 'Yahoo', 'so-widgets-bundle' ),
		'base_url' => 'https://yahoo.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#4101AF'
	),
	'yelp'   => array(
		'label'    => __( 'Yelp', 'so-widgets-bundle' ),
		'base_url' => 'https://www.yelp.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#B4282E'
	),
	'youtube'   => array(
		'label'    => __( 'YouTube', 'so-widgets-bundle' ),
		'base_url' => 'https://www.youtube.com/',
		'icon_color' => '#FFFFFF',
		'button_color' => '#CF3427'
	)
);
