/*!
 * Font Awesome Free 5.15.1 by @fontawesome - https://fontawesome.com
 * License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License)
 */

@font-face {
    font-family: 'sow-fontawesome-brands';
    font-style: normal;
    font-weight: normal;
    font-display: block;
    src: url("webfonts/fa-brands-400.eot");
    src: url("webfonts/fa-brands-400.eot?#iefix") format("embedded-opentype"),
    url("webfonts/fa-brands-400.woff2") format("woff2"),
    url("webfonts/fa-brands-400.woff") format("woff"),
    url("webfonts/fa-brands-400.ttf") format("truetype"),
    url("webfonts/fa-brands-400.svg#fontawesome") format("svg");
}

.sow-fab {
    font-family: 'sow-fontawesome-brands';
    font-style: normal !important;
    font-weight: normal !important;
}

@font-face {
    font-family: 'sow-fontawesome-free';
    font-style: normal;
    font-weight: 400;
    font-display: block;
    src: url("webfonts/fa-regular-400.eot");
    src: url("webfonts/fa-regular-400.eot?#iefix") format("embedded-opentype"),
    url("webfonts/fa-regular-400.woff2") format("woff2"),
    url("webfonts/fa-regular-400.woff") format("woff"),
    url("webfonts/fa-regular-400.ttf") format("truetype"),
    url("webfonts/fa-regular-400.svg#fontawesome") format("svg");
}

.sow-far {
    font-family: 'sow-fontawesome-free';
    font-style: normal !important;
    font-weight: 400 !important;
}

@font-face {
    font-family: 'sow-fontawesome-free';
    font-style: normal;
    font-weight: 900;
    font-display: block;
    src: url("webfonts/fa-solid-900.eot");
    src: url("webfonts/fa-solid-900.eot?#iefix") format("embedded-opentype"),
    url("webfonts/fa-solid-900.woff2") format("woff2"),
    url("webfonts/fa-solid-900.woff") format("woff"),
    url("webfonts/fa-solid-900.ttf") format("truetype"),
    url("webfonts/fa-solid-900.svg#fontawesome") format("svg");
}

.sow-fa,
.sow-fas {
    font-family: 'sow-fontawesome-free';
    font-weight: 900 !important;
    font-style: normal !important;
}

.sow-icon-fontawesome {
    display: inline-block;
    speak: none;
    font-variant: normal;
    text-transform: none;
    line-height: 1;

    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

.sow-icon-fontawesome[data-sow-icon]:before {
    content: attr(data-sow-icon);
}
