div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range>div{display:inline-block}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range>div:first-of-type{margin-right:5px}@media (max-width:680px){div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range>div{width:calc(50% - 10px)}}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range>div span{display:inline-block}@media (max-width:680px){div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range>div span{text-transform:capitalize}}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range>div span:last-of-type{margin-right:5px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range>div span:last-child{margin-left:10px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range>div input[type="text"].datepicker{display:inline-block;width:258px}@media (max-width:680px){div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range>div input[type="text"].datepicker{width:100%}}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range .sowb-relative-date>input{max-width:100px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-date-range .sowb-relative-date>select{min-width:inherit;width:auto}.pika-single{z-index:999999}