<?php
/**
 * WPSEO plugin file.
 *
 * @package WPSEO\Admin\OnPage
 */

// Mark this file as deprecated.
_deprecated_file( __FILE__, 'WPSEO 13.2' );

/**
 * Represents the service to be used by the WPSEO_Endpoint_Ryte endpoint.
 *
 * @deprecated 13.2
 * @codeCoverageIgnore
 */
class WPSEO_Ryte_Service {

	/**
	 * Constructs the WPSEO_Ryte_Service class.
	 *
	 * @deprecated 13.2
	 * @codeCoverageIgnore
	 */
	public function __construct() {
		_deprecated_function( __METHOD__, 'WPSEO 13.2' );
	}

	/**
	 * Fetches statistics via REST request.
	 *
	 * @deprecated 13.2
	 * @codeCoverageIgnore
	 */
	public function get_statistics() {
		_deprecated_function( __METHOD__, 'WPSEO 13.2' );
	}
}
