/**
 * CSS rules for the visibility module.
 */
.inactive-sidebar .csb-visibility {
  display: none;
}

.widget-control-actions .button {
  margin: 0 0 0 5px;
}
@media screen and (max-width: 782px) {
  .widget-control-actions .csb-visibility-button .dashicons {
    line-height: normal;
    height: auto;
    font-size: 19px;
  }
}
@media screen and (max-width: 782px) and (max-width: 400px) {
  .widget-control-actions .csb-visibility-button .dashicons {
    display: none;
  }
}

@media screen and (max-width: 782px) {
  .widget-control-actions .alignright,
  .widget-control-actions .alignleft {
    float: none;
  }
  .widget-control-actions .alignright {
    padding-top: 10px;
    text-align: right;
  }
  .widget-control-actions .alignright .button {
    margin-bottom: 5px;
  }
}

.csb-visibility {
  margin: 0 -15px 15px;
}

.csb-option-row {
  margin: 0 -15px;
  padding: 0 15px 12px;
  position: relative;
}

.csb-visibility-inner {
  border: 1px solid #E5E5E5;
  border-left: 0;
  border-right: 0;
  padding: 12px 15px 0;
  background: #FAFAFA;
}
.csb-visibility-inner .toggle-action {
  display: block;
  margin: -15px -15px 0;
  padding: 15px 15px 0;
  cursor: pointer;
  border: 0;
  /*color: #0074A2;*/
}
.csb-visibility-inner .csb-option-row:hover {
  background: #F4F4F4;
}
.csb-visibility-inner .csb-option-row:hover.csb-always:hover {
  background: transparent;
}
.csb-visibility-inner .csb-option-row.csb-action .action {
  top: 15px;
}
.csb-visibility-inner .csb-option-row .clear-filter:hover {
  color: #C00;
}
.csb-visibility-inner .csb-option-row .action {
  position: absolute;
  right: 15px;
  top: 7px;
  z-index: 1;
  color: #AAA;
  cursor: pointer;
  font-size: 20px;
}
.csb-visibility-inner .csb-option-row .action:hover {
  color: #000;
}
.csb-visibility-inner .csb-action {
  margin-bottom: 0;
}
.csb-visibility-inner .csb-action label {
  cursor: default;
}
.csb-visibility-inner .csb-action b {
  padding: 5px;
  border: 1px solid transparent;
  cursor: pointer;
  margin-left: -6px;
}
.csb-visibility-inner .csb-action:hover b {
  padding: 5px;
  background: #FFF;
  border: 1px solid #DDD;
}
.csb-visibility-inner .csb-always {
  padding-bottom: 0;
  text-align: center;
  font-style: italic;
}
.csb-visibility-inner .csb-always label {
  margin-bottom: 0;
  color: #AAA;
  cursor: default;
}
.csb-visibility-inner .csb-and {
  margin-right: 10px;
  font-weight: bold;
}
.csb-visibility-inner label {
  display: block;
  border-top: 1px solid #E8E8E8;
  margin: 0 -15px 5px;
  padding: 5px 15px;
}
.csb-visibility-inner .csb-detail-row label {
  border: 0;
  margin-bottom: 0;
  padding-bottom: 0;
}
.csb-visibility-inner .csb-detail-row .detail {
  margin-top: 10px;
}
.csb-visibility-inner .chosen-container {
  display: block !important;
  width: 100% !important;
}
.csb-visibility-inner .dropdown {
  position: absolute;
  z-index: 2;
  background: #FFF;
  border: 1px solid #DDD;
  right: 10px;
  top: 20px;
  color: #555;
  box-shadow: 0 1px 10px rgba(0, 0, 0, 0.15);
}
.csb-visibility-inner .dropdown li {
  padding: 5px 15px;
  cursor: pointer;
  margin: 0;
}
.csb-visibility-inner .dropdown li:hover {
  color: #000;
  background: #EEE;
}
.csb-visibility-inner .dropdown li.csb-group, .csb-visibility-inner .dropdown li.csb-group:hover {
  color: #999;
  font-weight: bold;
  background: #F8F8F8;
  padding-left: 5px;
  cursor: default;
}
