<?php
return array(
	'beaver_builder' => array(
		'name' => __( 'Beaver Builder', 'so-widgets-bundle' ),
		'file_path' => plugin_dir_path( __FILE__ ) . 'beaver-builder/beaver-builder.php',
	),
	'elementor' => array(
		'name' => __( 'Elementor', 'so-widgets-bundle' ),
		'file_path' => plugin_dir_path( __FILE__ ) . 'elementor/elementor.php',
	),
	'visual_composer' => array(
		'name' => __( 'Visual Composer', 'so-widgets-bundle' ),
		'file_path' => plugin_dir_path( __FILE__ ) . 'visual-composer/visual-composer.php',
	),
);
