@color: '';
@hover_color: '';

a {
	&.so-taxonomy-link {
		& when ( iscolor( @color ) ) {
			color: @color;
		}

		& when ( iscolor( @hover_color ) ) {
			&:hover {
				color: @hover_color;
			}
		}
	}

	&.so-taxonomy-button {
		margin-top: 1em;
		color: #fff;
		& when ( iscolor( @color ) ) {
			background: @color;
		}
		& when not ( iscolor( @color ) ) {
			background: #b0b0b0;
		}
		display: inline-block;
		margin-right: 0.5em;
		margin-bottom: 0.5em;
		text-decoration: none;
		line-height: 1em;
		font-size: 0.9em;
		padding: 0.65em 1em;

		&:hover {
			& when ( iscolor( @hover_color ) ) {
				background: @hover_color;
			}
			& when not ( iscolor( @hover_color ) ) {
				background: #cdcdcd;
			}
		}
	}
}

label {
	display: inline-block;
	margin-right: 0.5em;
}
