window.yoast=window.yoast||{},window.yoast.analysisReport=function(e){var t={};function s(r){if(t[r])return t[r].exports;var o=t[r]={i:r,l:!1,exports:{}};return e[r].call(o.exports,o,o.exports,s),o.l=!0,o.exports}return s.m=e,s.c=t,s.d=function(e,t,r){s.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},s.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},s.t=function(e,t){if(1&t&&(e=s(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(s.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var o in e)s.d(r,o,function(t){return e[t]}.bind(null,o));return r},s.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return s.d(t,"a",t),t},s.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},s.p="",s(s.s=490)}({0:function(e,t){e.exports=window.React},1:function(e,t){e.exports=window.yoast.propTypes},2:function(e,t){e.exports=window.wp.element},211:function(e,t){e.exports=window.lodash.noop},4:function(e,t){e.exports=window.wp.i18n},490:function(e,t,s){"use strict";s.r(t),s.d(t,"ContentAnalysis",(function(){return v})),s.d(t,"AnalysisResult",(function(){return B})),s.d(t,"AnalysisList",(function(){return C})),s.d(t,"renderRatingToColor",(function(){return y})),s.d(t,"SiteSEOReport",(function(){return N}));var r=s(2),o=s(4),n=s(0),a=s.n(n),l=s(5),i=s.n(l),u=s(1),c=s.n(u),d=s(211),p=s.n(d),m=s(6),g=s(7);const b=i.a.li`
	// This is the height of the IconButtonToggle.
	min-height: 24px;
	padding: 0;
	display: flex;
	align-items: flex-start;
`,f=i()(g.SvgIcon)`
	margin: 3px 11px 0 0; // icon 13 + 11 right margin = 24 for the 8px grid.
`,h=i.a.p`
	margin: 0 16px 0 0;
	flex: 1 1 auto;
	color: ${e=>e.suppressedText?"rgba(30,30,30,0.5)":"inherit"};
`,k=e=>Object(r.createElement)(b,null,Object(r.createElement)(f,{icon:e.icon,color:e.bulletColor,size:"13px"}),Object(r.createElement)(h,{suppressedText:e.suppressedText},e.hasBetaBadgeLabel&&Object(r.createElement)(g.BetaBadge,null),Object(r.createElement)("span",{dangerouslySetInnerHTML:{__html:e.text}})),e.hasMarksButton&&!function(e){return"hidden"===e.marksButtonStatus}(e)&&Object(r.createElement)(g.IconButtonToggle,{marksButtonStatus:e.marksButtonStatus,className:e.marksButtonClassName,onClick:e.onButtonClick,id:e.buttonId,icon:"eye",pressed:e.pressed,ariaLabel:e.ariaLabel}));k.propTypes={icon:c.a.string,text:c.a.string.isRequired,suppressedText:c.a.bool,bulletColor:c.a.string.isRequired,hasMarksButton:c.a.bool.isRequired,buttonId:c.a.string.isRequired,pressed:c.a.bool.isRequired,ariaLabel:c.a.string.isRequired,onButtonClick:c.a.func.isRequired,marksButtonStatus:c.a.string,marksButtonClassName:c.a.string,hasBetaBadgeLabel:c.a.bool},k.defaultProps={icon:"circle",suppressedText:!1,marksButtonStatus:"enabled",marksButtonClassName:"",hasBetaBadgeLabel:!1};var B=k;const x=i.a.ul`
	margin: 8px 0;
	padding: 0;
	list-style: none;
`;function y(e){switch(e){case"good":return m.colors.$color_good;case"OK":return m.colors.$color_ok;case"bad":return m.colors.$color_bad;default:return m.colors.$color_score_icon}}function C(e){let{results:t,marksButtonActivatedResult:s,marksButtonStatus:n,marksButtonClassName:a,onMarksButtonClick:l}=e;return Object(r.createElement)(x,{role:"list"},t.map(e=>{const t=y(e.rating),i=e.markerId===s;let u="";return u="disabled"===n?Object(o.__)("Marks are disabled in current view","wordpress-seo"):i?Object(o.__)("Remove highlight from the text","wordpress-seo"):Object(o.__)("Highlight this result in the text","wordpress-seo"),Object(r.createElement)(B,{key:e.id,text:e.text,bulletColor:t,hasMarksButton:e.hasMarks,ariaLabel:u,pressed:i,suppressedText:"upsell"===e.rating,buttonId:e.id,onButtonClick:()=>l(e.id,e.marker),marksButtonClassName:a,marksButtonStatus:n,hasBetaBadgeLabel:e.hasBetaBadge})}))}C.propTypes={results:c.a.array.isRequired,marksButtonActivatedResult:c.a.string,marksButtonStatus:c.a.string,marksButtonClassName:c.a.string,onMarksButtonClick:c.a.func},C.defaultProps={marksButtonActivatedResult:"",marksButtonStatus:"enabled",marksButtonClassName:"",onMarksButtonClick:p.a};const w=i.a.div`
	width: 100%;
	background-color: white;
	border-bottom: 1px solid transparent; // Avoid parent and child margin collapsing.
`,R=i()(g.Collapsible)`
	margin-bottom: 8px;

	button:first-child svg {
		margin: -2px 8px 0 -2px; // Compensate icon size set to 18px.
	}

	${g.StyledIconsButton} {
		padding: 8px 0;
		color: ${m.colors.$color_blue}
	}
`;class _ extends a.a.Component{renderCollapsible(e,t,s){return Object(r.createElement)(R,{initialIsOpen:!0,title:`${e} (${s.length})`,prefixIcon:{icon:"angle-up",color:m.colors.$color_grey_dark,size:"18px"},prefixIconCollapsed:{icon:"angle-down",color:m.colors.$color_grey_dark,size:"18px"},suffixIcon:null,suffixIconCollapsed:null,headingProps:{level:t,fontSize:"13px",fontWeight:"bold"}},Object(r.createElement)(C,{results:s,marksButtonActivatedResult:this.props.activeMarker,marksButtonStatus:this.props.marksButtonStatus,marksButtonClassName:this.props.marksButtonClassName,onMarksButtonClick:this.props.onMarkButtonClick}))}render(){const{problemsResults:e,improvementsResults:t,goodResults:s,considerationsResults:n,errorsResults:a,upsellResults:l,headingLevel:i}=this.props,u=a.length,c=e.length,d=t.length,p=n.length,m=s.length,g=l.length;return Object(r.createElement)(w,null,u>0&&this.renderCollapsible(Object(o.__)("Errors","wordpress-seo"),i,a),c+g>0&&this.renderCollapsible(Object(o.__)("Problems","wordpress-seo"),i,[...l,...e]),d>0&&this.renderCollapsible(Object(o.__)("Improvements","wordpress-seo"),i,t),p>0&&this.renderCollapsible(Object(o.__)("Considerations","wordpress-seo"),i,n),m>0&&this.renderCollapsible(Object(o.__)("Good results","wordpress-seo"),i,s))}}_.propTypes={onMarkButtonClick:c.a.func,problemsResults:c.a.array,improvementsResults:c.a.array,goodResults:c.a.array,considerationsResults:c.a.array,errorsResults:c.a.array,upsellResults:c.a.array,headingLevel:c.a.number,marksButtonStatus:c.a.string,marksButtonClassName:c.a.string,activeMarker:c.a.string},_.defaultProps={onMarkButtonClick:()=>{},problemsResults:[],improvementsResults:[],goodResults:[],considerationsResults:[],errorsResults:[],upsellResults:[],headingLevel:4,marksButtonStatus:"enabled",marksButtonClassName:"",activeMarker:""};var v=_;const O=i.a.div`
`,j=i.a.p`
	font-size: 14px;
`,S=e=>Object(r.createElement)(O,{className:e.className},Object(r.createElement)(j,{className:e.className+"__text"},e.seoAssessmentText),Object(r.createElement)(g.StackedProgressBar,{className:"progress",items:e.seoAssessmentItems,barHeight:e.barHeight}),Object(r.createElement)(g.ScoreAssessments,{className:"assessments",items:e.seoAssessmentItems}));S.propTypes={className:c.a.string,seoAssessmentText:c.a.string,seoAssessmentItems:c.a.arrayOf(c.a.shape({html:c.a.string.isRequired,value:c.a.number.isRequired,color:c.a.string.isRequired})),barHeight:c.a.string},S.defaultProps={className:"seo-assessment",seoAssessmentText:"SEO Assessment",seoAssessmentItems:null,barHeight:"24px"};var N=S},5:function(e,t){e.exports=window.yoast.styledComponents},6:function(e,t){e.exports=window.yoast.styleGuide},7:function(e,t){e.exports=window.yoast.componentsNew}});