<?php
	echo do_shortcode('[portfolio below_title="' . $instance['below_title'] . '" orderby="' . $instance['orderby'] . '" order="' . $instance['order'] . '" open_style="' . $instance['open_style'] . '" filter="' . $instance['filter'] . '" type="' . $instance['type'] . '" hover_style="' . $instance['hover_style'] . '" categories="' . $instance['categories'] . '" load_more="' . $instance['load_more'] . '" per_page="' . $instance['per_page'] . '"]');
?>