<?php
	$tab_list = '';
	
	foreach($instance['tab'] as $item) {
		$image = wp_get_attachment_image_src($item['image'], 'full');

		$tab_list .= '[tab_item title="' . $item['title'] . '"]' . do_shortcode($item['text']) . '[/tab_item]';
	}
	
	echo do_shortcode('[tab]' . $tab_list . '[/tab]');
?>