div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-size .custom-size-wrapper{margin-top:15px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-size .custom-size-wrapper label{font-weight:bold;font-size:13px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-size .custom-size-wrapper label:last-of-type{margin-left:12px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-size .custom-size-wrapper .siteorigin-widget-input{font-weight:400;width:80px}