.panel-grid.panel-no-style,
.panel-grid.panel-has-style > .panel-row-style {
  display: -webkit-flex;
  display: flex;
  -ms-flex-wrap: wrap;
  -webkit-flex-wrap: wrap;
  flex-wrap: nowrap;
  -ms-justify-content: space-between;
  -webkit-justify-content: space-between;
  justify-content: space-between;
}
.panel-grid .so-parallax {
  position: relative;
}
.panel-grid .so-parallax > *:not(.simpleParallax) {
  position: relative;
  z-index: 1;
}
.panel-grid .so-parallax .simpleParallax {
  overflow: hidden;
}
.panel-grid .so-parallax .simpleParallax,
.panel-grid .so-parallax img[data-siteorigin-parallax] {
  bottom: 0;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  width: 100%;
  z-index: 0;
}
.panel-layout.panel-is-rtl .panel-grid.panel-no-style,
.panel-layout.panel-is-rtl .panel-grid.panel-has-style > .panel-row-style {
  -ms-flex-direction: row-reverse;
  -webkit-flex-direction: row-reverse;
  flex-direction: row-reverse;
}
.panel-grid-cell {
  -ms-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.panel-grid-cell .panel-cell-style {
  height: 100%;
}
.panel-grid-cell .so-panel {
  zoom: 1;
}
.panel-grid-cell .so-panel:before {
  content: '';
  display: block;
}
.panel-grid-cell .so-panel:after {
  content: '';
  display: table;
  clear: both;
}
.panel-grid-cell .panel-last-child {
  margin-bottom: 0;
}
.panel-grid-cell .widget-title {
  margin-top: 0;
}
body.siteorigin-panels-before-js:not(.siteorigin-panels-css-container) {
  overflow-x: hidden;
}
body.siteorigin-panels-before-js:not(.siteorigin-panels-css-container) .siteorigin-panels-stretch {
  margin-right: -1000px !important;
  margin-left: -1000px !important;
  padding-right: 1000px !important;
  padding-left: 1000px !important;
}
