<?php

namespace Yoast\WP\SEO\Actions\Indexation;

/**
 * Interface definition of reindexation action for indexables.
 *
 * @deprecated 15.1 - Use \Yoast\WP\SEO\Actions\Indexing\Indexation_Action_Interface instead.
 * @codeCoverageIgnore
 */
interface Indexation_Action_Interface extends \Yoast\WP\SEO\Actions\Indexing\Indexation_Action_Interface {

}
