.ow-button-base{zoom:1}.ow-button-base:before{content:'';display:block}.ow-button-base:after{content:'';display:table;clear:both}.ow-button-base a{text-align:center;display:inline-block;cursor:pointer;text-decoration:none;line-height:1em}.ow-button-base a .sow-icon-image,.ow-button-base a [class^="sow-icon-"]{font-size:1.3em;height:1em;width:auto;margin:-0.1em .75em -0.2em -0.75em;display:block;float:left}.ow-button-base a .sow-icon-image{width:1em;background-size:cover}.ow-button-base a.ow-icon-placement-top .sow-icon-image,.ow-button-base a.ow-icon-placement-top [class^="sow-icon-"]{margin:0 auto .5em;float:none}.ow-button-base a.ow-icon-placement-right .sow-icon-image,.ow-button-base a.ow-icon-placement-right [class^="sow-icon-"]{margin:-0.1em -0.75em -0.2em .75em;float:right}.ow-button-base a.ow-icon-placement-bottom .sow-icon-image,.ow-button-base a.ow-icon-placement-bottom [class^="sow-icon-"]{float:none;margin:.5em auto 0}.ow-button-base a.ow-icon-placement-bottom>span{display:flex;flex-direction:column-reverse}.ow-button-base a.ow-icon-placement-left .sow-icon-image,.ow-button-base a.ow-icon-placement-left [class^="sow-icon-"]{margin:-0.1em .75em -0.2em -0.75em;float:left}.ow-button-base.ow-button-align-left{text-align:left}.ow-button-base.ow-button-align-right{text-align:right}.ow-button-base.ow-button-align-center{text-align:center}.ow-button-base.ow-button-align-justify a{display:block}