.redux-container-slider {
    .redux-slider-container {
        margin-left: 25px;
        margin-right: 25px;
        width: 200px;
        display: inline-block;
        vertical-align: middle;
    }

    .redux-slider-input,
    .redux-slider-select-one,
    .redux-slider-select-two {
        width: 100px !important;
        text-align: center;
    }

    .redux-slider-label {
        position: absolute;
        margin-left: -5px;
    }

    .redux-slider-label-one {
        position: absolute;
        margin-left: -22px;
    }

    .redux-slider-label-two {
        position: absolute;
        margin-top: -21px;
        margin-left: 245px;
    }
}

@media screen and (max-width: 782px) {
    .redux-container-slider {
        input {
            display: inline-block !important;
        }
    }
}

// Select Slider
@media screen and (max-width: 570px) {
    .redux-container-slider {
        text-align: center;

        input,
        select,
        .redux-slider-label,
        .select2-container {
            display: block !important;
            position: inherit;
            margin: 10px auto;
        }

        .redux-slider-container {
            margin-top: 3px;
            width: 80%;
        }
    }
}

.wp-customizer {
    .redux-container-slider {
        .redux-slider-label {
            float: left;
            position: inherit;
            width: 25%;
            text-align: center;
            margin-left:0;
        }
        .redux-slider-input, .redux-slider-select-one, .redux-slider-select-two {
            width: 25% !important;
        }
        .redux-slider-container {
            width: 70%;
            margin-right: 0;
            margin-left: 5%;
        }
    }
}

