<?php
/**
 * WPSEO plugin file.
 *
 * @package WPSEO\Admin\Ajax
 */

// Mark this file as deprecated.
_deprecated_file( __FILE__, 'WPSEO 13.2' );

/**
 * Class Yoast_OnPage_Ajax.
 *
 * This class will catch the request to dismiss the Ryte notice and will store
 * the dismiss status as an user meta in the database.
 *
 * @deprecated 13.2
 * @codeCoverageIgnore
 */
class Yoast_OnPage_Ajax {

	/**
	 * Initialize the hooks for the AJAX request.
	 *
	 * @deprecated 13.2
	 * @codeCoverageIgnore
	 */
	public function __construct() {
		_deprecated_function( __METHOD__, 'WPSEO 13.2' );
	}

	/**
	 * Handles the dismiss notice request.
	 *
	 * @deprecated 13.2
	 * @codeCoverageIgnore
	 */
	public function dismiss_notice() {
		_deprecated_function( __METHOD__, 'WPSEO 13.2' );
	}
}
