<?php
/**
 * WPSEO plugin file.
 *
 * @package WPSEO\Deprecated
 */

if ( ! function_exists( 'initialize_wpseo_front' ) ) {
	/**
	 * Wraps frontend class.
	 *
	 * @deprecated 14.0
	 * @codeCoverageIgnore
	 */
	function initialize_wpseo_front() {
		_deprecated_function( __FUNCTION__, 'WPSEO 14.0' );
	}
}
