/*
Name: Simple
Template: simple
Author: Greg Priday
Author URI: http://siteorigin.com/
*/

@import "../../../less/mixins";
@borders: 1px solid #E0E0E0;
@background_color: #FCFCFC;
@box_shadow: 0 1px 2px rgba(0,0,0,0.1);

& {
	padding: 25px 20px;
	border: @borders;
	background: @background_color;
	.box-shadow(@box_shadow);

	h2 {
		line-height: 1;
		margin: 0 0 0.25em 0;
		text-align: center;
	}

	h4 {
		line-height: 1;
		margin: 0 0 1em 0;
		text-align: center;

		span {
			font-size: 0.6em;
		}
	}

	.origin-widget-button {
		margin-top: 30px;
	}
}