/*!
 *  Elusive Icons 2.0.0 by @ReduxFramework - http://elusiveicons.com - @reduxframework
 *  License - http://elusiveicons.com/license (Font: SIL OFL 1.1, CSS: MIT License)
 */
@font-face {
    font-family: 'Elusive-Icons';
    src: url("fonts/elusiveicons-webfont.eot?v=2.0.0");
    src: url("fonts/elusiveicons-webfont.eot?#iefix&v=2.0.0") format("embedded-opentype"), url("fonts/elusiveicons-webfont.woff?v=2.0.0") format("woff"), url("fonts/elusiveicons-webfont.ttf?v=2.0.0") format("truetype"), url("fonts/elusiveicons-webfont.svg?v=2.0.0#elusiveiconsregular") format("svg");
    font-weight: normal;
    font-style: normal
}

.el {
    display: inline-block;
    font: normal normal normal 14px/1 "Elusive-Icons";
    font-size: inherit;
    text-rendering: auto;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    transform: translate(0, 0)
}

.el-lg {
    font-size: 1.33333em;
    line-height: 0.75em;
    vertical-align: -15%
}

.el-2x {
    font-size: 2em
}

.el-3x {
    font-size: 3em
}

.el-4x {
    font-size: 4em
}

.el-5x {
    font-size: 5em
}

.el-fw {
    width: 1.28571em;
    text-align: center
}

.el-ul {
    padding-left: 0;
    margin-left: 2.14286em;
    list-style-type: none
}

.el-ul > li {
    position: relative
}

.el-li {
    position: absolute;
    left: -2.14286em;
    width: 2.14286em;
    top: 0.14286em;
    text-align: center
}

.el-li.el-lg {
    left: -1.85714em
}

.el-border {
    padding: .2em .25em .15em;
    border: solid 0.08em #eee;
    border-radius: .1em
}

.pull-right {
    float: right
}

.pull-left {
    float: left
}

.el.pull-left {
    margin-right: .3em
}

.el.pull-right {
    margin-left: .3em
}

.el-spin {
    -webkit-animation: el-spin 2s infinite linear;
    animation: el-spin 2s infinite linear
}

.el-pulse {
    -webkit-animation: el-spin 1s infinite steps(8);
    animation: el-spin 1s infinite steps(8)
}

@-webkit-keyframes el-spin {
    0% {
        -webkit-transform: rotate(0deg);
        transform: rotate(0deg)
    }
    100% {
        -webkit-transform: rotate(359deg);
        transform: rotate(359deg)
    }
}

@keyframes el-spin {
    0% {
        -webkit-transform: rotate(0deg);
        transform: rotate(0deg)
    }
    100% {
        -webkit-transform: rotate(359deg);
        transform: rotate(359deg)
    }
}

.el-rotate-90 {
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
    -webkit-transform: rotate(90deg);
    -ms-transform: rotate(90deg);
    transform: rotate(90deg)
}

.el-rotate-180 {
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}

.el-rotate-270 {
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3);
    -webkit-transform: rotate(270deg);
    -ms-transform: rotate(270deg);
    transform: rotate(270deg)
}

.el-flip-horizontal {
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=0);
    -webkit-transform: scale(-1, 1);
    -ms-transform: scale(-1, 1);
    transform: scale(-1, 1)
}

.el-flip-vertical {
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2);
    -webkit-transform: scale(1, -1);
    -ms-transform: scale(1, -1);
    transform: scale(1, -1)
}

:root .el-rotate-90, :root .el-rotate-180, :root .el-rotate-270, :root .el-flip-horizontal, :root .el-flip-vertical {
    filter: none
}

.el-stack {
    position: relative;
    display: inline-block;
    width: 2em;
    height: 2em;
    line-height: 2em;
    vertical-align: middle
}

.el-stack-1x, .el-stack-2x {
    position: absolute;
    left: 0;
    width: 100%;
    text-align: center
}

.el-stack-1x {
    line-height: inherit
}

.el-stack-2x {
    font-size: 2em
}

.el-inverse {
    color: #fff
}

.el-icon-address-book-alt:before, .el-address-book-alt:before {
    content: ""
}

.el-icon-address-book:before, .el-address-book:before {
    content: ""
}

.el-icon-adjust-alt:before, .el-adjust-alt:before {
    content: ""
}

.el-icon-adjust:before, .el-adjust:before {
    content: ""
}

.el-icon-adult:before, .el-adult:before {
    content: ""
}

.el-icon-align-center:before, .el-align-center:before {
    content: ""
}

.el-icon-align-justify:before, .el-align-justify:before {
    content: ""
}

.el-icon-align-left:before, .el-align-left:before {
    content: ""
}

.el-icon-align-right:before, .el-align-right:before {
    content: ""
}

.el-icon-arrow-down:before, .el-arrow-down:before {
    content: ""
}

.el-icon-arrow-left:before, .el-arrow-left:before {
    content: ""
}

.el-icon-arrow-right:before, .el-arrow-right:before {
    content: ""
}

.el-icon-arrow-up:before, .el-arrow-up:before {
    content: ""
}

.el-icon-asl:before, .el-asl:before {
    content: ""
}

.el-icon-asterisk:before, .el-asterisk:before {
    content: ""
}

.el-icon-backward:before, .el-backward:before {
    content: ""
}

.el-icon-ban-circle:before, .el-ban-circle:before {
    content: ""
}

.el-icon-barcode:before, .el-barcode:before {
    content: ""
}

.el-icon-behance:before, .el-behance:before {
    content: ""
}

.el-icon-bell:before, .el-bell:before {
    content: ""
}

.el-icon-blind:before, .el-blind:before {
    content: ""
}

.el-icon-blogger:before, .el-blogger:before {
    content: ""
}

.el-icon-bold:before, .el-bold:before {
    content: ""
}

.el-icon-book:before, .el-book:before {
    content: ""
}

.el-icon-bookmark-empty:before, .el-bookmark-empty:before {
    content: ""
}

.el-icon-bookmark:before, .el-bookmark:before {
    content: ""
}

.el-icon-brackets:before, .el-brackets:before {
    content: ""
}

.el-icon-braille:before, .el-braille:before {
    content: ""
}

.el-icon-briefcase:before, .el-briefcase:before {
    content: ""
}

.el-icon-broom:before, .el-broom:before {
    content: ""
}

.el-icon-brush:before, .el-brush:before {
    content: ""
}

.el-icon-bulb:before, .el-bulb:before {
    content: ""
}

.el-icon-bullhorn:before, .el-bullhorn:before {
    content: ""
}

.el-icon-calendar-sign:before, .el-calendar-sign:before {
    content: ""
}

.el-icon-calendar:before, .el-calendar:before {
    content: ""
}

.el-icon-camera:before, .el-camera:before {
    content: ""
}

.el-icon-car:before, .el-car:before {
    content: ""
}

.el-icon-caret-down:before, .el-caret-down:before {
    content: ""
}

.el-icon-caret-left:before, .el-caret-left:before {
    content: ""
}

.el-icon-caret-right:before, .el-caret-right:before {
    content: ""
}

.el-icon-caret-up:before, .el-caret-up:before {
    content: ""
}

.el-icon-cc:before, .el-cc:before {
    content: ""
}

.el-icon-certificate:before, .el-certificate:before {
    content: ""
}

.el-icon-check-empty:before, .el-check-empty:before {
    content: ""
}

.el-icon-check:before, .el-check:before {
    content: ""
}

.el-icon-chevron-down:before, .el-chevron-down:before {
    content: ""
}

.el-icon-chevron-left:before, .el-chevron-left:before {
    content: ""
}

.el-icon-chevron-right:before, .el-chevron-right:before {
    content: ""
}

.el-icon-chevron-up:before, .el-chevron-up:before {
    content: ""
}

.el-icon-child:before, .el-child:before {
    content: ""
}

.el-icon-circle-arrow-down:before, .el-circle-arrow-down:before {
    content: ""
}

.el-icon-circle-arrow-left:before, .el-circle-arrow-left:before {
    content: ""
}

.el-icon-circle-arrow-right:before, .el-circle-arrow-right:before {
    content: ""
}

.el-icon-circle-arrow-up:before, .el-circle-arrow-up:before {
    content: ""
}

.el-icon-cloud-alt:before, .el-cloud-alt:before {
    content: ""
}

.el-icon-cloud:before, .el-cloud:before {
    content: ""
}

.el-icon-cog-alt:before, .el-cog-alt:before {
    content: ""
}

.el-icon-cog:before, .el-cog:before {
    content: ""
}

.el-icon-cogs:before, .el-cogs:before {
    content: ""
}

.el-icon-comment-alt:before, .el-comment-alt:before {
    content: ""
}

.el-icon-comment:before, .el-comment:before {
    content: ""
}

.el-icon-compass-alt:before, .el-compass-alt:before {
    content: ""
}

.el-icon-compass:before, .el-compass:before {
    content: ""
}

.el-icon-credit-card:before, .el-credit-card:before {
    content: ""
}

.el-icon-css:before, .el-css:before {
    content: ""
}

.el-icon-dashboard:before, .el-dashboard:before {
    content: ""
}

.el-icon-delicious:before, .el-delicious:before {
    content: ""
}

.el-icon-deviantart:before, .el-deviantart:before {
    content: ""
}

.el-icon-digg:before, .el-digg:before {
    content: ""
}

.el-icon-download-alt:before, .el-download-alt:before {
    content: ""
}

.el-icon-download:before, .el-download:before {
    content: ""
}

.el-icon-dribbble:before, .el-dribbble:before {
    content: ""
}

.el-icon-edit:before, .el-edit:before {
    content: ""
}

.el-icon-eject:before, .el-eject:before {
    content: ""
}

.el-icon-envelope-alt:before, .el-envelope-alt:before {
    content: ""
}

.el-icon-envelope:before, .el-envelope:before {
    content: ""
}

.el-icon-error-alt:before, .el-error-alt:before {
    content: ""
}

.el-icon-error:before, .el-error:before {
    content: ""
}

.el-icon-eur:before, .el-eur:before {
    content: ""
}

.el-icon-exclamation-sign:before, .el-exclamation-sign:before {
    content: ""
}

.el-icon-eye-close:before, .el-eye-close:before {
    content: ""
}

.el-icon-eye-open:before, .el-eye-open:before {
    content: ""
}

.el-icon-facebook:before, .el-facebook:before {
    content: ""
}

.el-icon-facetime-video:before, .el-facetime-video:before {
    content: ""
}

.el-icon-fast-backward:before, .el-fast-backward:before {
    content: ""
}

.el-icon-fast-forward:before, .el-fast-forward:before {
    content: ""
}

.el-icon-female:before, .el-female:before {
    content: ""
}

.el-icon-file-alt:before, .el-file-alt:before {
    content: ""
}

.el-icon-file-edit-alt:before, .el-file-edit-alt:before {
    content: ""
}

.el-icon-file-edit:before, .el-file-edit:before {
    content: ""
}

.el-icon-file-new-alt:before, .el-file-new-alt:before {
    content: ""
}

.el-icon-file-new:before, .el-file-new:before {
    content: ""
}

.el-icon-file:before, .el-file:before {
    content: ""
}

.el-icon-film:before, .el-film:before {
    content: ""
}

.el-icon-filter:before, .el-filter:before {
    content: ""
}

.el-icon-fire:before, .el-fire:before {
    content: ""
}

.el-icon-flag-alt:before, .el-flag-alt:before {
    content: ""
}

.el-icon-flag:before, .el-flag:before {
    content: ""
}

.el-icon-flickr:before, .el-flickr:before {
    content: ""
}

.el-icon-folder-close:before, .el-folder-close:before {
    content: ""
}

.el-icon-folder-open:before, .el-folder-open:before {
    content: ""
}

.el-icon-folder-sign:before, .el-folder-sign:before {
    content: ""
}

.el-icon-folder:before, .el-folder:before {
    content: ""
}

.el-icon-font:before, .el-font:before {
    content: ""
}

.el-icon-fontsize:before, .el-fontsize:before {
    content: ""
}

.el-icon-fork:before, .el-fork:before {
    content: ""
}

.el-icon-forward-alt:before, .el-forward-alt:before {
    content: ""
}

.el-icon-forward:before, .el-forward:before {
    content: ""
}

.el-icon-foursquare:before, .el-foursquare:before {
    content: ""
}

.el-icon-friendfeed-rect:before, .el-friendfeed-rect:before {
    content: ""
}

.el-icon-friendfeed:before, .el-friendfeed:before {
    content: ""
}

.el-icon-fullscreen:before, .el-fullscreen:before {
    content: ""
}

.el-icon-gallery:before, .el-gallery:before {
    content: ""
}

.el-icon-gbp:before, .el-gbp:before {
    content: ""
}

.el-icon-gift:before, .el-gift:before {
    content: ""
}

.el-icon-github-text:before, .el-github-text:before {
    content: ""
}

.el-icon-github:before, .el-github:before {
    content: ""
}

.el-icon-glass:before, .el-glass:before {
    content: ""
}

.el-icon-glasses:before, .el-glasses:before {
    content: ""
}

.el-icon-globe-alt:before, .el-globe-alt:before {
    content: ""
}

.el-icon-globe:before, .el-globe:before {
    content: ""
}

.el-icon-googleplus:before, .el-googleplus:before {
    content: ""
}

.el-icon-graph-alt:before, .el-graph-alt:before {
    content: ""
}

.el-icon-graph:before, .el-graph:before {
    content: ""
}

.el-icon-group-alt:before, .el-group-alt:before {
    content: ""
}

.el-icon-group:before, .el-group:before {
    content: ""
}

.el-icon-guidedog:before, .el-guidedog:before {
    content: ""
}

.el-icon-hand-down:before, .el-hand-down:before {
    content: ""
}

.el-icon-hand-left:before, .el-hand-left:before {
    content: ""
}

.el-icon-hand-right:before, .el-hand-right:before {
    content: ""
}

.el-icon-hand-up:before, .el-hand-up:before {
    content: ""
}

.el-icon-hdd:before, .el-hdd:before {
    content: ""
}

.el-icon-headphones:before, .el-headphones:before {
    content: ""
}

.el-icon-hearing-impaired:before, .el-hearing-impaired:before {
    content: ""
}

.el-icon-heart-alt:before, .el-heart-alt:before {
    content: ""
}

.el-icon-heart-empty:before, .el-heart-empty:before {
    content: ""
}

.el-icon-heart:before, .el-heart:before {
    content: ""
}

.el-icon-home-alt:before, .el-home-alt:before {
    content: ""
}

.el-icon-home:before, .el-home:before {
    content: ""
}

.el-icon-hourglass:before, .el-hourglass:before {
    content: ""
}

.el-icon-idea-alt:before, .el-idea-alt:before {
    content: ""
}

.el-icon-idea:before, .el-idea:before {
    content: ""
}

.el-icon-inbox-alt:before, .el-inbox-alt:before {
    content: ""
}

.el-icon-inbox-box:before, .el-inbox-box:before {
    content: ""
}

.el-icon-inbox:before, .el-inbox:before {
    content: ""
}

.el-icon-indent-left:before, .el-indent-left:before {
    content: ""
}

.el-icon-indent-right:before, .el-indent-right:before {
    content: ""
}

.el-icon-info-circle:before, .el-info-circle:before {
    content: ""
}

.el-icon-instagram:before, .el-instagram:before {
    content: ""
}

.el-icon-iphone-home:before, .el-iphone-home:before {
    content: ""
}

.el-icon-italic:before, .el-italic:before {
    content: ""
}

.el-icon-key:before, .el-key:before {
    content: ""
}

.el-icon-laptop-alt:before, .el-laptop-alt:before {
    content: ""
}

.el-icon-laptop:before, .el-laptop:before {
    content: ""
}

.el-icon-lastfm:before, .el-lastfm:before {
    content: ""
}

.el-icon-leaf:before, .el-leaf:before {
    content: ""
}

.el-icon-lines:before, .el-lines:before {
    content: ""
}

.el-icon-link:before, .el-link:before {
    content: ""
}

.el-icon-linkedin:before, .el-linkedin:before {
    content: ""
}

.el-icon-list-alt:before, .el-list-alt:before {
    content: ""
}

.el-icon-list:before, .el-list:before {
    content: ""
}

.el-icon-livejournal:before, .el-livejournal:before {
    content: ""
}

.el-icon-lock-alt:before, .el-lock-alt:before {
    content: ""
}

.el-icon-lock:before, .el-lock:before {
    content: ""
}

.el-icon-magic:before, .el-magic:before {
    content: ""
}

.el-icon-magnet:before, .el-magnet:before {
    content: ""
}

.el-icon-male:before, .el-male:before {
    content: ""
}

.el-icon-map-marker-alt:before, .el-map-marker-alt:before {
    content: ""
}

.el-icon-map-marker:before, .el-map-marker:before {
    content: ""
}

.el-icon-mic-alt:before, .el-mic-alt:before {
    content: ""
}

.el-icon-mic:before, .el-mic:before {
    content: ""
}

.el-icon-minus-sign:before, .el-minus-sign:before {
    content: ""
}

.el-icon-minus:before, .el-minus:before {
    content: ""
}

.el-icon-move:before, .el-move:before {
    content: ""
}

.el-icon-music:before, .el-music:before {
    content: ""
}

.el-icon-myspace:before, .el-myspace:before {
    content: ""
}

.el-icon-network:before, .el-network:before {
    content: ""
}

.el-icon-off:before, .el-off:before {
    content: ""
}

.el-icon-ok-circle:before, .el-ok-circle:before {
    content: ""
}

.el-icon-ok-sign:before, .el-ok-sign:before {
    content: ""
}

.el-icon-ok:before, .el-ok:before {
    content: ""
}

.el-icon-opensource:before, .el-opensource:before {
    content: ""
}

.el-icon-paper-clip-alt:before, .el-paper-clip-alt:before {
    content: ""
}

.el-icon-paper-clip:before, .el-paper-clip:before {
    content: ""
}

.el-icon-path:before, .el-path:before {
    content: ""
}

.el-icon-pause-alt:before, .el-pause-alt:before {
    content: ""
}

.el-icon-pause:before, .el-pause:before {
    content: ""
}

.el-icon-pencil-alt:before, .el-pencil-alt:before {
    content: ""
}

.el-icon-pencil:before, .el-pencil:before {
    content: ""
}

.el-icon-person:before, .el-person:before {
    content: ""
}

.el-icon-phone-alt:before, .el-phone-alt:before {
    content: ""
}

.el-icon-phone:before, .el-phone:before {
    content: ""
}

.el-icon-photo-alt:before, .el-photo-alt:before {
    content: ""
}

.el-icon-photo:before, .el-photo:before {
    content: ""
}

.el-icon-picasa:before, .el-picasa:before {
    content: ""
}

.el-icon-picture:before, .el-picture:before {
    content: ""
}

.el-icon-plane:before, .el-plane:before {
    content: ""
}

.el-icon-play-alt:before, .el-play-alt:before {
    content: ""
}

.el-icon-play-circle:before, .el-play-circle:before {
    content: ""
}

.el-icon-play:before, .el-play:before {
    content: ""
}

.el-icon-plurk-alt:before, .el-plurk-alt:before {
    content: ""
}

.el-icon-plurk:before, .el-plurk:before {
    content: ""
}

.el-icon-plus-sign:before, .el-plus-sign:before {
    content: ""
}

.el-icon-plus:before, .el-plus:before {
    content: ""
}

.el-icon-podcast:before, .el-podcast:before {
    content: ""
}

.el-icon-print:before, .el-print:before {
    content: ""
}

.el-icon-puzzle:before, .el-puzzle:before {
    content: ""
}

.el-icon-qrcode:before, .el-qrcode:before {
    content: ""
}

.el-icon-question-sign:before, .el-question-sign:before {
    content: ""
}

.el-icon-question:before, .el-question:before {
    content: ""
}

.el-icon-quote-alt:before, .el-quote-alt:before {
    content: ""
}

.el-icon-quote-right-alt:before, .el-quote-right-alt:before {
    content: ""
}

.el-icon-quote-right:before, .el-quote-right:before {
    content: ""
}

.el-icon-quotes:before, .el-quotes:before {
    content: ""
}

.el-icon-random:before, .el-random:before {
    content: ""
}

.el-icon-record:before, .el-record:before {
    content: ""
}

.el-icon-reddit:before, .el-reddit:before {
    content: ""
}

.el-icon-redux:before, .el-redux:before {
    content: ""
}

.el-icon-refresh:before, .el-refresh:before {
    content: ""
}

.el-icon-remove-circle:before, .el-remove-circle:before {
    content: ""
}

.el-icon-remove-sign:before, .el-remove-sign:before {
    content: ""
}

.el-icon-remove:before, .el-remove:before {
    content: ""
}

.el-icon-repeat-alt:before, .el-repeat-alt:before {
    content: ""
}

.el-icon-repeat:before, .el-repeat:before {
    content: ""
}

.el-icon-resize-full:before, .el-resize-full:before {
    content: ""
}

.el-icon-resize-horizontal:before, .el-resize-horizontal:before {
    content: ""
}

.el-icon-resize-small:before, .el-resize-small:before {
    content: ""
}

.el-icon-resize-vertical:before, .el-resize-vertical:before {
    content: ""
}

.el-icon-return-key:before, .el-return-key:before {
    content: ""
}

.el-icon-retweet:before, .el-retweet:before {
    content: ""
}

.el-icon-reverse-alt:before, .el-reverse-alt:before {
    content: ""
}

.el-icon-road:before, .el-road:before {
    content: ""
}

.el-icon-rss:before, .el-rss:before {
    content: ""
}

.el-icon-scissors:before, .el-scissors:before {
    content: ""
}

.el-icon-screen-alt:before, .el-screen-alt:before {
    content: ""
}

.el-icon-screen:before, .el-screen:before {
    content: ""
}

.el-icon-screenshot:before, .el-screenshot:before {
    content: ""
}

.el-icon-search-alt:before, .el-search-alt:before {
    content: ""
}

.el-icon-search:before, .el-search:before {
    content: ""
}

.el-icon-share-alt:before, .el-share-alt:before {
    content: ""
}

.el-icon-share:before, .el-share:before {
    content: ""
}

.el-icon-shopping-cart-sign:before, .el-shopping-cart-sign:before {
    content: ""
}

.el-icon-shopping-cart:before, .el-shopping-cart:before {
    content: ""
}

.el-icon-shortcode:before, .el-shortcode:before {
    content: ""
}

.el-icon-signal:before, .el-signal:before {
    content: ""
}

.el-icon-skype:before, .el-skype:before {
    content: ""
}

.el-icon-slideshare:before, .el-slideshare:before {
    content: ""
}

.el-icon-smiley-alt:before, .el-smiley-alt:before {
    content: ""
}

.el-icon-smiley:before, .el-smiley:before {
    content: ""
}

.el-icon-soundcloud:before, .el-soundcloud:before {
    content: ""
}

.el-icon-speaker:before, .el-speaker:before {
    content: ""
}

.el-icon-spotify:before, .el-spotify:before {
    content: ""
}

.el-icon-stackoverflow:before, .el-stackoverflow:before {
    content: ""
}

.el-icon-star-alt:before, .el-star-alt:before {
    content: ""
}

.el-icon-star-empty:before, .el-star-empty:before {
    content: ""
}

.el-icon-star:before, .el-star:before {
    content: ""
}

.el-icon-step-backward:before, .el-step-backward:before {
    content: ""
}

.el-icon-step-forward:before, .el-step-forward:before {
    content: ""
}

.el-icon-stop-alt:before, .el-stop-alt:before {
    content: ""
}

.el-icon-stop:before, .el-stop:before {
    content: ""
}

.el-icon-stumbleupon:before, .el-stumbleupon:before {
    content: ""
}

.el-icon-tag:before, .el-tag:before {
    content: ""
}

.el-icon-tags:before, .el-tags:before {
    content: ""
}

.el-icon-tasks:before, .el-tasks:before {
    content: ""
}

.el-icon-text-height:before, .el-text-height:before {
    content: ""
}

.el-icon-text-width:before, .el-text-width:before {
    content: ""
}

.el-icon-th-large:before, .el-th-large:before {
    content: ""
}

.el-icon-th-list:before, .el-th-list:before {
    content: ""
}

.el-icon-th:before, .el-th:before {
    content: ""
}

.el-icon-thumbs-down:before, .el-thumbs-down:before {
    content: ""
}

.el-icon-thumbs-up:before, .el-thumbs-up:before {
    content: ""
}

.el-icon-time-alt:before, .el-time-alt:before {
    content: ""
}

.el-icon-time:before, .el-time:before {
    content: ""
}

.el-icon-tint:before, .el-tint:before {
    content: ""
}

.el-icon-torso:before, .el-torso:before {
    content: ""
}

.el-icon-trash-alt:before, .el-trash-alt:before {
    content: ""
}

.el-icon-trash:before, .el-trash:before {
    content: ""
}

.el-icon-tumblr:before, .el-tumblr:before {
    content: ""
}

.el-icon-twitter:before, .el-twitter:before {
    content: ""
}

.el-icon-universal-access:before, .el-universal-access:before {
    content: ""
}

.el-icon-unlock-alt:before, .el-unlock-alt:before {
    content: ""
}

.el-icon-unlock:before, .el-unlock:before {
    content: ""
}

.el-icon-upload:before, .el-upload:before {
    content: ""
}

.el-icon-usd:before, .el-usd:before {
    content: ""
}

.el-icon-user:before, .el-user:before {
    content: ""
}

.el-icon-viadeo:before, .el-viadeo:before {
    content: ""
}

.el-icon-video-alt:before, .el-video-alt:before {
    content: ""
}

.el-icon-video-chat:before, .el-video-chat:before {
    content: ""
}

.el-icon-video:before, .el-video:before {
    content: ""
}

.el-icon-view-mode:before, .el-view-mode:before {
    content: ""
}

.el-icon-vimeo:before, .el-vimeo:before {
    content: ""
}

.el-icon-vkontakte:before, .el-vkontakte:before {
    content: ""
}

.el-icon-volume-down:before, .el-volume-down:before {
    content: ""
}

.el-icon-volume-off:before, .el-volume-off:before {
    content: ""
}

.el-icon-volume-up:before, .el-volume-up:before {
    content: ""
}

.el-icon-w3c:before, .el-w3c:before {
    content: ""
}

.el-icon-warning-sign:before, .el-warning-sign:before {
    content: ""
}

.el-icon-website-alt:before, .el-website-alt:before {
    content: ""
}

.el-icon-website:before, .el-website:before {
    content: ""
}

.el-icon-wheelchair:before, .el-wheelchair:before {
    content: ""
}

.el-icon-wordpress:before, .el-wordpress:before {
    content: ""
}

.el-icon-wrench-alt:before, .el-wrench-alt:before {
    content: ""
}

.el-icon-wrench:before, .el-wrench:before {
    content: ""
}

.el-icon-youtube:before, .el-youtube:before {
    content: ""
}

.el-icon-zoom-in:before, .el-zoom-in:before {
    content: ""
}

.el-icon-zoom-out:before, .el-zoom-out:before {
    content: ""
}
