<?php

namespace Yoast\WP\SEO\Config;

/**
 * Holds all languages supported with specific researches for our readability analysis.
 */
class Researcher_Languages {

	const SUPPORTED_LANGUAGES = [ 'ar', 'ca', 'de', 'en', 'es', 'fa', 'fr', 'he', 'hu', 'id', 'it', 'nb', 'nl', 'pl', 'pt', 'ru', 'sv', 'tr', 'cs', 'sk', 'el', 'ja' ];
}
