<?php
	$new_window = '';
	if( !empty($instance['button_new_window']) ) {
		$new_window = 'yes';
	}

	echo do_shortcode('[button url="' . $instance['button_url'] . '" new_window="' . $new_window . '" size="' . $instance['button_size'] . '"]' . $instance['button_text'] . '[/button]');
?>