<?php
/**
 * WPSEO plugin file.
 *
 * @package WPSEO\Admin
 */

/**
 * Class WPSEO_Recalculate_Scores.
 *
 * This class handles the SEO score recalculation for all posts with a filled focus keyword.
 *
 * @deprecated 14.4
 * @codeCoverageIgnore
 */
class WPSEO_Recalculate_Scores {

	/**
	 * Constructing the object by modalbox, the localization and the totals.
	 *
	 * @deprecated 14.4
	 * @codeCoverageIgnore
	 */
	public function __construct() {
		_deprecated_function( __METHOD__, 'WPSEO 14.4' );
	}

	/**
	 * Run the localize script.
	 *
	 * @deprecated 14.4
	 * @codeCoverageIgnore
	 */
	public function recalculate_assets() {
		_deprecated_function( __METHOD__, 'WPSEO 14.4' );
	}

	/**
	 * Initialize the modal box to be displayed when needed.
	 *
	 * @deprecated 14.4
	 * @codeCoverageIgnore
	 */
	public function modal_box() {
		_deprecated_function( __METHOD__, 'WPSEO 14.4' );
	}
}
