<?php
	$marker = $instance['marker'];

	if( $marker ) {
		$marker = wp_get_attachment_image_src($marker, 'full');
		$marker = $marker[0];
	}

	$scrollwheel = '';

	if( $instance['scrollwheel'] ) {
		$scrollwheel = 'on';
	} else {
		$scrollwheel = 'off';
	}

	$draggable = '';

	if( $instance['draggable'] ) {
		$draggable = 'on';
	} else {
		$draggable = 'off';
	}

	echo do_shortcode('[google_maps draggable="' . $draggable . '" scrollwheel="' . $scrollwheel . '" marker="' . $marker . '" api="' . $instance['api'] . '" location="' . $instance['location'] . '" zoom="' . $instance['zoom'] . '"]' . $instance['style'] . '[/google_maps]');
?>