<?php
	$list_left = '';
	$list_right = '';

	foreach($instance['left'] as $item) {
		$list_left .= '[progress_bar title="' . $item['title'] . '" subtitle="' . $item['subtitle'] . '" value="' . $item['value'] . '" max="' . $item['max'] . '"]';
	}

	foreach($instance['right'] as $item) {
		$list_right .= '[progress_bar title="' . $item['title'] . '" subtitle="' . $item['subtitle'] . '" value="' . $item['value'] . '" max="' . $item['max'] . '"]';
	}

	echo '<div class="row"><div class="col-md-6">' . do_shortcode($list_left) . '</div><div class="col-md-6">' . do_shortcode($list_right) . '</div></div>';
?>