/**
 * WPMU Dev UI library
 * (Philipp Stracker for WPMU Dev)
 *
 * This library provides a Javascript API via the global wpmuUI object.
 *
 * Content:
 *   00. Settings
 *   01. Modal overlays
 *   02. Popup Windows
 *   03. Messages
 *   04. Tooltips
 *   05. WordPress Pointers
 *   06. Form Layout
 *   07. Simple Grid
 *   08. WordPress Accordeon Box
 *   09. WordPress Tab-box
 *   10. Select2
 *   11. On Off Switch
 *   12. Confirmation
 *   13. Progress Bar
 *   99. General Styles
 */
/**
 * =============================================================================
 * == 00. SETTINGS
 * =============================================================================
 */
/**
 * =============================================================================
 * == 01. MODAL OVERLAYS
 * =============================================================================
 */
.wpmui-loading {
  position: relative;
}
.wpmui-loading:after {
  content: '';
  position: absolute;
  left: -1px;
  top: -1px;
  right: -1px;
  bottom: -1px;
  background: rgba(255, 255, 255, 0.8) url(../img/spinner.gif) center no-repeat;
  z-index: 1000;
  cursor: default;
  min-width: 20px;
  min-height: 20px;
}

.wpmui-loading-icon {
  display: inline-block;
  width: 20px;
  height: 20px;
  line-height: 20px;
  vertical-align: middle;
  background: transparent url(../img/spinner.gif) center no-repeat;
}

.wpmui-overlay {
  background: #000;
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  opacity: 0;
  transition: opacity 0.3s, z-index 0.3s step-end;
}

.wpmui-has-overlay .wpmui-overlay {
  z-index: 9999;
  opacity: 0.7;
  transition: opacity 0.3s, z-index 0.3s step-start;
}
.wpmui-has-overlay .wpmui-overlay.light {
  opacity: .25;
}
.wpmui-has-overlay #wpwrap {
  -webkit-filter: grayscale(75%);
  -moz-filter: grayscale(75%);
  filter: gray;
  filter: grayscale(75%);
}
.wpmui-has-overlay #wpbody {
  -webkit-filter: blur(3px);
  -moz-filter: blur(3px);
  filter: blur(3px);
}
.wpmui-has-overlay.no-blur #wpbody {
  -webkit-filter: blur(0);
  -moz-filter: blur(0);
  filter: blur(0);
}

.wpmui-no-scroll {
  overflow: hidden;
}

.wpmui-blur {
  -webkit-filter: blur(3px) grayscale(75%);
  -moz-filter: blur(3px) grayscale(75%);
  filter: blur(3px) grayscale(75%);
  position: relative;
}
.wpmui-blur:before {
  content: '';
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  z-index: 10;
}

/**
 * =============================================================================
 * == 02. POPUP WINDOWS
 * =============================================================================
 */
.wpmui-popup {
  background: #F5F5F5;
  position: fixed;
  box-shadow: 0 2px 20px rgba(0, 0, 0, 0.4);
  z-index: 10000;
  top: 50%;
  left: 50%;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.wpmui-popup .popup-title {
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  line-height: 50px;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  padding: 0 70px 0 20px;
  border-bottom: 1px solid #E5E5E5;
  background: #F8F8F8;
  min-height: 50px;
  display: block;
  font-size: 23px;
  font-weight: 100;
  z-index: 5;
}
.wpmui-popup .popup-title .the-title {
  display: inline-block;
  padding-right: 71px;
}
.wpmui-popup.slidein.slidein-down .popup-title {
  top: auto;
  bottom: 0;
  border-top: 1px solid #E5E5E5;
  border-bottom: 0;
}
.wpmui-popup.slidein .popup-title {
  cursor: pointer;
}
.wpmui-popup .only-slidein {
  display: none;
}
.wpmui-popup.slideing .only-slidein {
  display: block;
}
.wpmui-popup .popup-close {
  position: absolute;
  top: 0;
  right: 0;
  width: 50px;
  line-height: 50px;
  height: 50px;
  text-align: center;
  text-decoration: none;
  color: #666;
  border-left: 1px solid #E5E5E5;
  cursor: pointer;
  z-index: 10;
}
.wpmui-popup .popup-close:hover, .wpmui-popup .popup-close:focus, .wpmui-popup .popup-close:active {
  background: #FCFCFC;
  color: #333;
}
.wpmui-popup .popup-close .dashicons {
  line-height: 50px;
}
.wpmui-popup .popup-content {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  overflow: auto;
  padding: 20px 20px 20px 20px;
  z-index: 1;
}
.wpmui-popup .popup-content:after {
  content: '';
  display: block;
  clear: both;
  padding: 50px 0 0 0;
}
.wpmui-popup.no-buttons .popup-content:after {
  padding-top: 0;
}
.wpmui-popup.no-close .popup-title {
  padding: 0 20px;
}
.wpmui-popup.no-close .popup-close {
  display: none;
}
.wpmui-popup hr {
  margin: 15px -20px;
  border: 0;
  border-top: 1px solid #E5E5E5;
}
.wpmui-popup .buttons {
  text-align: right;
  position: absolute;
  bottom: 0;
  right: 0;
  background: rgba(245, 245, 245, 0.8);
  padding: 10px 20px 10px;
  left: 0;
  height: 50px;
  border-top: 1px solid #E5E5E5;
  margin: 0;
  z-index: 2;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.popup.wdev-window,
.popup.wdev-slidein {
  position: fixed;
  z-index: 10000;
  top: 50%;
  left: 50%;
  background: #FFF;
  box-sizing: border-box;
}
.popup.wdev-window.slidein .popup-title,
.popup.wdev-slidein.slidein .popup-title {
  cursor: pointer;
}

/**
 * =============================================================================
 * == 03. MESSAGES
 * =============================================================================
 */
.wpmui-msg {
  position: relative;
  min-height: 30px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.wpmui-msg .wpmui-close {
  float: right;
  margin-top: 8px;
  width: 20px;
  height: 20px;
  line-height: 20px;
  text-align: center;
  cursor: pointer;
  text-decoration: none;
  font-size: 16px;
  padding: 0;
  color: #CCC;
}

.wpmui-msg .wpmui-close:hover,
.wpmui-msg .wpmui-close:focus,
.wpmui-msg .wpmui-close:active {
  color: #333;
}

.wpmui-msg .debug {
  padding: 5px;
  color: #666;
  font-size: 12px;
  font-family: monospace;
  margin-bottom: 0.5em;
  background: #F8F8F8;
}

/**
 * =============================================================================
 * == 04. TOOLTIPS
 * =============================================================================
 */
.wpmui-tip-box {
  position: relative;
}

.wpmui-tip {
  position: absolute;
  display: none;
  padding: 8px;
  z-index: 100;
  background: #333;
  color: #EEE;
  box-shadow: 0 1px 8px rgba(0, 0, 0, 0.4);
  border-radius: 2px;
}
.wpmui-tip.wpmui-visible {
  display: block;
}
.wpmui-tip:before {
  content: '';
  position: absolute;
  border: 5px solid transparent;
  left: 50%;
  top: 50%;
  margin-left: -5px;
  margin-top: -5px;
}
.wpmui-tip.top:before {
  border-top-color: #333;
  bottom: -10px;
  top: auto;
}
.wpmui-tip.bottom:before {
  border-bottom-color: #333;
  top: -5px;
}
.wpmui-tip.left:before {
  border-left-color: #333;
  right: -10px;
  left: auto;
}
.wpmui-tip.right:before {
  border-right-color: #333;
  left: -5px;
}

/**
 * =============================================================================
 * == 05. WORDPRESS POINTERS
 * =============================================================================
 */
.wpmui-pointer.wp-pointer-left {
  margin-top: 30px;
}
.wpmui-pointer.wp-pointer-left h3 {
  background: transparent;
  color: #333;
  border: 0;
  margin: 0;
  padding: 13px 20px 5px;
  font-size: 13px;
}
.wpmui-pointer.wp-pointer-left h3:before {
  content: '';
  display: none;
}
.wpmui-pointer.wp-pointer-left p {
  padding: 0 20px;
  margin: 2px 0;
  font-size: 12px;
}
.wpmui-pointer.wp-pointer-left .wp-pointer-content {
  background: #FAFDFF;
  border-radius: 4px;
  border: 1px solid #ccc;
  box-shadow: 0px 1px 8px -2px rgba(0, 0, 0, 0.35);
  padding: 0 0 15px;
}
.wpmui-pointer.wp-pointer-left.no-title {
  margin-top: 13px;
}
.wpmui-pointer.wp-pointer-left.no-title .wp-pointer-content {
  padding-top: 17px;
}
.wpmui-pointer.wp-pointer-left .wp-pointer-buttons {
  position: absolute;
  top: 0;
  right: 0;
  white-space: nowrap;
  padding: 5px 10px;
}
.wpmui-pointer.wp-pointer-left .wp-pointer-buttons a.close {
  font-size: 1px;
  color: transparent;
  width: 10px;
  padding: 0;
}
.wpmui-pointer.wp-pointer-left .wp-pointer-buttons a.close:before {
  position: static;
  float: right;
  line-height: 14px;
  margin: 3px 0 1px 5px;
}
.wpmui-pointer.wp-pointer-left .wp-pointer-arrow {
  border: 0;
  position: absolute;
  top: 50%;
  left: 0;
  margin: -6px 0 0;
}
.wpmui-pointer.wp-pointer-left .wp-pointer-arrow:before, .wpmui-pointer.wp-pointer-left .wp-pointer-arrow:after {
  content: '';
  border: 6px solid transparent;
  margin: 0;
  left: -10px;
  position: absolute;
  top: 0;
}
.wpmui-pointer.wp-pointer-left .wp-pointer-arrow:before {
  border-right-color: #CCC;
  left: -11px;
}
.wpmui-pointer.wp-pointer-left .wp-pointer-arrow:after {
  border-right-color: #FAFDFF;
}
.wpmui-pointer.wp-pointer-left .wp-pointer-arrow-inner {
  display: none;
}
.wpmui-pointer.wp-pointer-left.wp-pointer-left {
  padding-left: 8px;
  margin-left: -12px;
}
.wpmui-pointer.wp-pointer-left.wp-pointer-left .wp-pointer-arrow {
  left: 8px;
}

/**
 * =============================================================================
 * == 06. FORM LAYOUT
 * =============================================================================
 */
.wpmui-form label {
  display: block;
  line-height: 26px;
  font-size: 14px;
  font-weight: 500;
}

.wpmui-form input[type='text'],
.wpmui-form input[type='password'],
.wpmui-form textarea,
.wpmui-form select {
  width: 100%;
  margin: 0;
  display: block;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.wpmui-form .hint {
  color: #666;
  font-size: 12px;
}

.wpmui-form .button-link,
.wpmui-popup .button-link {
  display: inline-block;
  text-decoration: underline;
  font-size: 13px;
  line-height: 26px;
  height: 28px;
  padding: 0 10px 1px;
  cursor: pointer;
  white-space: nowrap;
  color: #0074A2;
  background: transparent;
  border: 0;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-box-shadow: 0 0 0 transparent;
  -moz-box-shadow: 0 0 0 transparent;
  box-shadow: 0 0 0 transparent;
  -webkit-transition-property: border, background, color;
  transition-property: border, background, color;
  -webkit-transition-duration: .05s;
  transition-duration: .05s;
  -webkit-transition-timing-function: ease-in-out;
  transition-timing-function: ease-in-out;
}
.wpmui-form .button-link:hover, .wpmui-form .button-link:active, .wpmui-form .button-link:focus,
.wpmui-popup .button-link:hover,
.wpmui-popup .button-link:active,
.wpmui-popup .button-link:focus {
  color: #2EA2CC;
}

/**
 * =============================================================================
 * == 07. SIMPLE GRID (modified)
 *    Project Page - http://thisisdallas.github.com/Simple-Grid/
 *    Author - Dallas Bass
 * =============================================================================
 */
.wpmui-grid-8 *,
.wpmui-grid-12 *,
.wpmui-grid-8 *:after,
.wpmui-grid-12 *:after,
.wpmui-grid-8 *:before,
.wpmui-grid-12 *:before {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.wpmui-grid-8 [class*='col-'],
.wpmui-grid-12 [class*='col-'] {
  float: left;
  padding-right: 20px;
  position: relative;
}

.wpmui-grid-8 [class*='col-']:last-of-type,
.wpmui-grid-12 [class*='col-']:last-of-type {
  padding-right: 0px;
}

.wpmui-grid-8,
.wpmui-grid-12 {
  width: 100%;
  margin: 0;
  overflow: hidden;
  padding: 10px 0 0;
}

.wpmui-grid-8:after,
.wpmui-grid-12:after {
  content: '';
  display: table;
  clear: both;
}

.wpmui-grid-8 .col-8,
.wpmui-grid-12 .col-12 {
  width: 100%;
}

.wpmui-grid-12 .col-11 {
  width: 91.66%;
}

.wpmui-grid-8 .col-7 {
  width: 87.5%;
}

.wpmui-grid-12 .col-10 {
  width: 83.333%;
}

.wpmui-grid-8 .col-6,
.wpmui-grid-12 .col-9 {
  width: 75%;
}

.wpmui-grid-12 .col-8 {
  width: 66.66%;
}

.wpmui-grid-8 .col-5 {
  width: 62.5%;
}

.wpmui-grid-12 .col-7 {
  width: 58.33%;
}

.wpmui-grid-8 .col-4,
.wpmui-grid-12 .col-6 {
  width: 50%;
}

.wpmui-grid-12 .col-5 {
  width: 41.66%;
}

.wpmui-grid-8 .col-3 {
  width: 37.5%;
}

.wpmui-grid-12 .col-4 {
  width: 33.33%;
}

.wpmui-grid-8 .col-2,
.wpmui-grid-12 .col-3 {
  width: 25%;
}

.wpmui-grid-12 .col-2 {
  width: 16.667%;
}

.wpmui-grid-8 .col-1 {
  width: 12.5%;
}

.wpmui-grid-12 .col-1 {
  width: 8.33%;
}

@media handheld, only screen and (max-width: 767px) {
  .wpmui-grid-8,
  .wpmui-grid-12 {
    width: 100%;
    min-width: 0;
    margin-left: 0px;
    margin-right: 0px;
    padding-left: 0px;
    padding-right: 0px;
  }

  .wpmui-grid-8 [class*='col-'],
  .wpmui-grid-12 [class*='col-'] {
    width: auto;
    float: none;
    margin-left: 0px;
    margin-right: 0px;
    margin-top: 10px;
    margin-bottom: 10px;
    padding-left: 20px;
    padding-right: 20px;
  }
}
/**
 * =============================================================================
 * == 08. WORDPRESS ACCORDEON BOX
 * =============================================================================
 *
 * Example:
 *
 *   <div class="wpmui-box">
 *     <h3>
 *       <a href="#" class="toggle" title="<?php _e( 'Click to toggle' ); ?>"><br></a>
 *       <span>Title</span>
 *     </h3>
 *     <div class="inside">
 *       <p>Content...</p>
 *     </div>
 *   </div>
 */
.wpmui-box {
  margin-bottom: 10px;
  padding: 0;
  line-height: 1;
  position: relative;
  min-width: 255px;
  border: 1px solid #E5E5E5;
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
  background: #FFF;
}
.wpmui-box > h3 {
  font-size: 14px;
  padding: 8px 12px;
  margin: 0;
  line-height: 1.4;
  border-bottom: 1px solid #EEE;
  cursor: pointer;
}
.wpmui-box > h3 .toggle {
  cursor: pointer;
  float: right;
  width: 36px;
  height: 36px;
  color: #AAA;
  text-decoration: none;
  margin: -8px -12px;
  text-align: center;
  position: relative;
  line-height: 36px;
}
.wpmui-box > h3:hover .toggle,
.wpmui-box .toggle:hover,
.wpmui-box .toggle:focus,
.wpmui-box .toggle:active {
  color: #777;
}
.wpmui-box > h3 .toggle:before {
  content: '\f142';
  font: 400 20px/36px dashicons;
  speak: none;
  display: inline-block;
  position: absolute;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: none !important;
  width: 100%;
  height: 100%;
  top: 0;
  right: 0;
}
.wpmui-box > .inside {
  margin: 6px 0 0;
  position: relative;
  padding: 0 12px 12px;
  line-height: 1.4em;
  font-size: 13px;
}
.wpmui-box > .inside:after {
  content: '';
  display: table;
  clear: both;
}
.wpmui-box.closed > h3 .toggle:before {
  content: '\f140';
}
.wpmui-box.closed > .inside {
  display: none;
}
.wpmui-box.static > h3 {
  cursor: default;
}
.wpmui-box.static > h3 .toggle {
  display: none;
}
.wpmui-box.static > .inside {
  display: block;
}

/**
 * =============================================================================
 * == 09. WORDPRESS TAB-BOX
 * =============================================================================
 *
 * Example:
 *
 *   <div class="wpmui-tabs">
 *     <a href="#config" class="tab active">Config</a>
 *     <a href="#archive" class="tab">Archive</a>
 *   </div>
 *   <div class="wpmui-tab-contents">
 *     <div class="tab active" id="config"></div>
 *     <div class="tab" id="archive"></div>
 *   </div>
 */
.wpmui-tabs {
  border-bottom: 1px solid #EEE;
  padding-bottom: 0;
  padding-left: 10px;
  list-style: none;
  margin: 20px 0 0;
}

.wpmui-tabs .tab {
  border: 1px solid #EEE;
  background: #F0F0F0;
  color: #999;
  display: inline-block;
  text-decoration: none;
  margin: 0 4px -1px 0;
  padding: 0 12px;
  font-weight: 600;
  font-size: 13px;
  line-height: 34px;
}

.wpmui-tabs .tab:hover,
.wpmui-tabs .tab:focus,
.wpmui-tabs .tab:active {
  background: #F4F4F4;
  color: #777;
}

.wpmui-tabs .tab.active {
  border-bottom: 1px solid #FFF;
  background: #FFF;
  color: #444;
}

.wpmui-tab-contents {
  padding: 12px;
}

.wpmui-tab-contents .tab {
  display: none;
}

.wpmui-tab-contents .tab.active {
  display: block;
}

.wpmui-box > .inside > .wpmui-tabs {
  margin-left: -12px;
  margin-right: -12px;
  padding-left: 22px;
}

.wpmui-box > .inside > .wpmui-tab-contents {
  margin-left: -12px;
  margin-right: -12px;
  margin-bottom: -12px;
}

/**
 * =============================================================================
 * == 10. SELECT2
 * =============================================================================
 */
.select2-container {
  /* The select element */
  /* The dropdown list */
}
.select2-container .wpmui-select2.select2-selection--single {
  height: 28px;
}
.select2-container .wpmui-select2.select2-selection--single,
.select2-container .wpmui-select2.select2-selection--multiple {
  min-height: 28px;
  line-height: 27px;
  font-size: 14px;
  border-radius: 2px;
  border-color: #CCC;
}
.select2-container .wpmui-select2.select2-selection--single .select2-selection__arrow b,
.select2-container .wpmui-select2.select2-selection--multiple .select2-selection__arrow b {
  border-top-color: #AAA;
}
.select2-container .wpmui-select2.select2-selection--single .select2-selection__rendered,
.select2-container .wpmui-select2.select2-selection--multiple .select2-selection__rendered {
  display: block;
  margin-bottom: -1px;
}
.select2-container .wpmui-select2 .select2-search--inline {
  margin: 0;
  width: auto;
}
.select2-container .wpmui-select2 .select2-search--inline .select2-search__field {
  margin: 1px;
  background-image: none !important;
}
.select2-container.select2-container--focus .wpmui-select2 {
  border-color: #5897fb;
}
.select2-container.select2-container--disabled .wpmui-select2 {
  background: #DDD;
  font-weight: 200;
  opacity: .5;
}
.select2-container .select2-dropdown.wpmui-select2 {
  overflow: hidden;
  z-index: 1000500 !important;
  /* Thickbox modal background has 1000100 */
  margin-top: -1px;
  box-shadow: 0 0 0 1px #5897fb inset;
  border: 0;
  border-radius: 0;
}
.select2-container .select2-dropdown.wpmui-select2 .select2-search {
  margin-bottom: -1px;
  padding: 1px;
}
.select2-container .select2-dropdown.wpmui-select2 .select2-search .select2-search__field {
  margin: 0;
  border: 0;
  font-size: 13px;
  border-bottom: 1px solid #5897fb;
  background-color: #FAFDFF;
}
.select2-container .select2-dropdown.wpmui-select2 .select2-results {
  padding: 0;
  margin: 0;
  font-size: 13px;
}
.select2-container .select2-dropdown.wpmui-select2 .select2-results .select2-results__option {
  margin: 0;
  white-space: nowrap;
  padding-left: 20px;
  position: relative;
}
.select2-container .select2-dropdown.wpmui-select2 .select2-results .select2-results__option:before {
  content: '';
  background-color: transparent;
  background-position: center center;
  background-repeat: no-repeat;
  position: absolute;
  left: 1px;
  top: 1px;
  width: 20px;
  height: 28px;
}
.select2-container .select2-dropdown.wpmui-select2 .select2-results .select2-results__option[aria-selected=true] {
  color: #5897fb;
  background-color: #F5F9FF;
  margin: 1px;
}
.select2-container .select2-dropdown.wpmui-select2 .select2-results .select2-results__option[aria-selected=true]:before {
  /* blue check */
  background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+Cjxzdmcgd2lkdGg9IjEycHgiIGhlaWdodD0iOXB4IiB2aWV3Qm94PSIwIDAgMTIgOSIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIj4KICAgIDxnIGlkPSJpY29uIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtNC4wMDAwMDAsIC0xMC4wMDAwMDApIiBzdHJva2U9Im5vbmUiIGZpbGw9IiM1ODk3ZmIiPgogICAgICAgIDxnIHRyYW5zZm9ybT0idHJhbnNsYXRlKDQuNzUwMDAwLCAxMC41MDAwMDApIj4KICAgICAgICAgICAgPHBhdGggZD0iTTguNzUsMCBMNC4zNzUsNC4zNzUgTDEuNzUsMS43NSBMMCwzLjUgTDQuMzc1LDcuODc1IEwxMC41LDEuNzUgTDguNzUsMCBaIiBpZD0iU2hhcGUiPjwvcGF0aD4KICAgICAgICA8L2c+CiAgICA8L2c+Cjwvc3ZnPg==);
}
.select2-container .select2-dropdown.wpmui-select2 .select2-results .select2-results__option--highlighted,
.select2-container .select2-dropdown.wpmui-select2 .select2-results .select2-results__option--highlighted[aria-selected=true] {
  background-color: #5897fb;
  color: #FFF;
}
.select2-container .select2-dropdown.wpmui-select2 .select2-results .select2-results__option--highlighted:before,
.select2-container .select2-dropdown.wpmui-select2 .select2-results .select2-results__option--highlighted[aria-selected=true]:before {
  /* white check */
  background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+Cjxzdmcgd2lkdGg9IjEycHgiIGhlaWdodD0iOXB4IiB2aWV3Qm94PSIwIDAgMTIgOSIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIj4KICAgIDxnIGlkPSJpY29uIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtNC4wMDAwMDAsIC0xMC4wMDAwMDApIiBzdHJva2U9Im5vbmUiIGZpbGw9IiNGRkZGRkYiPgogICAgICAgIDxnIHRyYW5zZm9ybT0idHJhbnNsYXRlKDQuNzUwMDAwLCAxMC41MDAwMDApIj4KICAgICAgICAgICAgPHBhdGggZD0iTTguNzUsMCBMNC4zNzUsNC4zNzUgTDEuNzUsMS43NSBMMCwzLjUgTDQuMzc1LDcuODc1IEwxMC41LDEuNzUgTDguNzUsMCBaIiBpZD0iU2hhcGUiPjwvcGF0aD4KICAgICAgICA8L2c+CiAgICA8L2c+Cjwvc3ZnPg==);
}
.select2-container .select2-dropdown.wpmui-select2 .select2-results [aria-multiselectable=true] .select2-results__option--highlighted[aria-selected=true]:before {
  /* white cross */
  background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+Cjxzdmcgd2lkdGg9IjEwcHgiIGhlaWdodD0iMTBweCIgdmlld0JveD0iMCAwIDEwIDEwIiB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiPgogICAgPGcgaWQ9Imljb24iIHRyYW5zZm9ybT0idHJhbnNsYXRlKC01LjAwMDAwMCwgLTEwLjAwMDAwMCkiIHN0cm9rZT0ibm9uZSIgZmlsbD0iI0ZGRkZGRiI+CiAgICAgICAgPHBhdGggZD0iTTEyLjc0MDAwMTcsMTAuMzAwMDAwMiBMMTAuMTI1LDEyLjkyNSBMNy41LDEwLjMgTDUuNzUsMTIuMDUgTDguMzcwMDAwODQsMTQuNjgwMDAwMyBMNS43NSwxNy4zMTk5OTk3IEw3LjUsMTkuMDY5OTk5NyBMMTAuMTE5OTk4OSwxNi40Mzk5OTk2IEwxMi43NDAwMDE3LDE5LjA2OTk5OTcgTDE0LjQ5MDAwMTcsMTcuMzE5OTk5NyBMMTEuODY5OTk4OSwxNC42ODAwMDAzIEwxNC40OTAwMDE3LDEyLjA1MDAwMDIgTDEyLjc0MDAwMTcsMTAuMzAwMDAwMiBaIj48L3BhdGg+CiAgICA8L2c+Cjwvc3ZnPg==);
}

/**
 * =============================================================================
 * == 11. ON OFF SWITCH
 * =============================================================================
 *
 * Example:
 *
 * <div class="wpmui-toggle">
 *   <input type="checkbox" class="wpmui-toggle-checkbox" id="toggle-1" checked="checked" />
 *   <label class="wpmui-toggle-label" for="toggle-1">
 *     <span class="wpmui-toggle-inner"></span>
 *     <span class="wpmui-toggle-switch"></span>
 *   </label>
 * </div>
 */
.wpmui-toggle {
  position: relative;
  width: 26px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
}

.wpmui-toggle-checkbox {
  display: none !important;
}

.wpmui-toggle-label {
  display: block;
  overflow: hidden;
  cursor: pointer;
  border: 1px solid #CCC;
  border-radius: 50px;
}

.wpmui-toggle-inner {
  display: block;
  width: 200%;
  margin-left: -100%;
  -moz-transition: margin 0.3s ease-in 0s;
  -webkit-transition: margin 0.3s ease-in 0s;
  -o-transition: margin 0.3s ease-in 0s;
  transition: margin 0.3s ease-in 0s;
}
.wpmui-toggle-inner:before, .wpmui-toggle-inner:after {
  display: block;
  float: left;
  width: 50%;
  height: 5px;
  padding: 0;
  line-height: 5px;
  font-size: 10px;
  color: white;
  font-family: Trebuchet, Arial, sans-serif;
  font-weight: bold;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  box-shadow: 0 1px 0 rgba(0, 0, 0, 0.2) inset;
}
.wpmui-toggle-inner:before {
  content: "";
  padding-left: 5px;
  background-color: #0074A2;
}
.wpmui-toggle-inner:after {
  content: "";
  padding-right: 5px;
  background-color: #EEEEEE;
  text-align: right;
}

.wpmui-toggle-switch {
  display: block;
  width: 14px;
  margin: -3.5px;
  background: #F8F8F8;
  border: 1px solid #CCC;
  border-radius: 15px;
  position: absolute;
  top: 0;
  bottom: 0;
  right: 20px;
  -moz-transition: all 0.3s ease-in 0s;
  -webkit-transition: all 0.3s ease-in 0s;
  -o-transition: all 0.3s ease-in 0s;
  transition: all 0.3s ease-in 0s;
  box-shadow: -1px 1px 2px rgba(0, 0, 0, 0.1);
}

.wpmui-toggle-checkbox:checked + .wpmui-toggle-label .wpmui-toggle-inner {
  margin-left: 0;
}

.wpmui-toggle-checkbox:checked + .wpmui-toggle-label .wpmui-toggle-switch {
  right: 0px;
}

/**
 * =============================================================================
 * == 12. CONFIRMATION
 * =============================================================================
 */
.wpmui-confirm-modal {
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  z-index: 99998;
  background: #000;
  opacity: .4;
}

.wpmui-confirm-box {
  top: 25%;
  width: 580px;
  padding: 20px 20px 0;
  left: 50%;
  margin-left: -310px;
  /* Include the padding! */
  z-index: 99999;
  background: #FFF;
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.4);
}
.wpmui-confirm-box .wpmui-confirm-btn {
  margin: 10px -20px 0px;
  padding: 10px 20px;
  text-align: right;
  background: #FAFAFA;
  border-top: 1px solid #E5E5E5;
}
.wpmui-confirm-box .wpmui-confirm-btn button {
  margin-left: 10px;
}

/**
 * =============================================================================
 * == 13. PROGRESS BAR
 * =============================================================================
 */
.wpmui-progress-wrap {
  position: relative;
  width: 100%;
}
.wpmui-progress-wrap .wpmui-progress-full {
  background: rgba(255, 255, 255, 0.7);
  width: 100%;
  border-radius: 2px;
  box-shadow: 1px 1px 2px 0px rgba(0, 0, 0, 0.1);
}
.wpmui-progress-wrap .wpmui-progress {
  background: #369;
  border-radius: 2px;
  height: 28px;
  transition: width .25s;
}
.wpmui-progress-wrap .wpmui-progress-percent {
  position: absolute;
  left: 0;
  right: 0;
  top: 0;
  line-height: 28px;
  font-size: 13px;
  text-align: center;
  color: #FFF;
  text-shadow: 0 0 5px #264d73;
}
.wpmui-progress-wrap .wpmui-progress-percent:before {
  content: '';
  position: absolute;
  left: 50%;
  width: 30px;
  height: 10px;
  top: 50%;
  border-radius: 5px;
  margin-top: -5px;
  margin-left: -15px;
  box-shadow: 0 0 8px 4px #264d73;
  background: #264d73;
  z-index: -1;
  opacity: .5;
}
.wpmui-progress-wrap .wpmui-progress-label {
  font-size: 12px;
  margin-top: 6px;
  color: #888;
  text-align: right;
}

/**
 * =============================================================================
 * == 99. GENERAL STYLES
 * =============================================================================
 */
.no-pad-top {
  padding-top: 0 !important;
  margin-top: 0 !important;
}

.no-pad-bottom {
  padding-bottom: 0  !important;
  margin-bottom: 0  !important;
}

.no-pad {
  padding-top: 0  !important;
  padding-bottom: 0  !important;
  margin-top: 0  !important;
  margin-bottom: 0  !important;
}

.dashicons.light {
  opacity: .5;
}

.cf:before,
.cf:after {
  content: '';
  display: table;
}

.cf:after {
  clear: both;
}

.wpmui-left {
  float: left;
}

.wpmui-right {
  float: right;
}

.button .dashicons,
.button-primary .dashicons {
  line-height: 26px;
  height: 26px;
  float: left;
  margin-right: 6px;
}
