div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .button{box-sizing:border-box}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .multiple-media-field-items{box-sizing:content-box}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .multiple-media-field-items{line-height:18.2px;overflow:auto}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .multiple-media-field-item{-ms-box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;box-sizing:border-box;float:left;padding:4px;position:relative;margin:5px 0}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .multiple-media-field-item .thumbnail{border:1px solid #999;box-shadow:0 1px 1px #fff;box-shadow:inset 0 1px 3px rgba(0,0,0,0.2);background:#cfcfcf;background:-webkit-gradient(linear, left bottom, left top, color-stop(0, #cccccc), color-stop(1, #cfcfcf));background:-ms-linear-gradient(bottom, #cccccc, #cfcfcf);background:-moz-linear-gradient(center bottom, #cccccc 0%, #cfcfcf 100%);background:-o-linear-gradient(#cfcfcf, #cccccc);filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='#cfcfcf', endColorstr='#cccccc', GradientType=0);line-height:0}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .multiple-media-field-item .title{display:none}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .multiple-media-field-item .title.title-enabled{display:block;font-size:12px;word-break:break-all}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .multiple-media-field-item .media-remove-button{color:#aaa;display:block;font-size:11px;line-height:1em;opacity:1;text-align:center;text-decoration:none;-webkit-transition:all .25s ease;-moz-transition:all .25s ease;-o-transition:all .25s ease;transition:all .25s ease}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .multiple-media-field-item .media-remove-button.remove-hide{opacity:0;pointer-events:none}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .multiple-media-field-wrapper .multiple-media-field-item .media-remove-button:hover{color:#bc0b0b}div.siteorigin-widget-form .siteorigin-widget-field-type-multiple_media .media-field-template{display:none}