<?php

namespace Yoast\WP\SEO\Actions\Indexation;

use Yoast\WP\SEO\Actions\Indexing\Indexing_Complete_Action;

/**
 * Indexing action to call when the indexing is completed.
 *
 * @deprecated 15.1 - Use \Yoast\WP\SEO\Actions\Indexing\Indexing_Complete_Action instead.
 * @codeCoverageIgnore
 */
class Indexable_Complete_Indexation_Action extends Indexing_Complete_Action {

}
