<?php
	$show_more_button = 'no';
	if( isset($instance['show_more_button']) && $instance['show_more_button'] ) {
		$show_more_button = 'yes';
	}

	echo do_shortcode('[recent_posts id="' . $instance['id'] . '" categories="' . $instance['categories'] . '" show_more_button="' . $show_more_button . '"]' . $instance['num_posts'] . '[/recent_posts]');
?>