!function(e){var t={};function s(o){if(t[o])return t[o].exports;var n=t[o]={i:o,l:!1,exports:{}};return e[o].call(n.exports,n,n.exports,s),n.l=!0,n.exports}s.m=e,s.c=t,s.d=function(e,t,o){s.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:o})},s.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},s.t=function(e,t){if(1&t&&(e=s(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var o=Object.create(null);if(s.r(o),Object.defineProperty(o,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var n in e)s.d(o,n,function(t){return e[t]}.bind(null,n));return o},s.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return s.d(t,"a",t),t},s.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},s.p="",s(s.s=225)}({0:function(e,t){e.exports=window.React},1:function(e,t){e.exports=window.wp.element},10:function(e,t){e.exports=window.yoast.analysis},11:function(e,t){e.exports=window.wp.components},113:function(e,t,s){"use strict";var o=s(1),n=s(19),r=s.n(n),a=s(9),i=s(3),l=s(71),c=s(2),p=s.n(c);const u=Object(a.makeOutboundLink)(),d=e=>{const t=Object(i.sprintf)(
/* translators: %s expands to a 'Yoast SEO Premium' text linked to the yoast.com website. */
Object(i.__)("Great news: you can, with %s!","wordpress-seo"),"{{link}}Yoast SEO Premium{{/link}}"),s=[Object(i.sprintf)(
/* translators: %1$s expands to a 'strong' start tag, %2$s to a 'strong' end tag. */
Object(i.__)("%1$sNo more dead links%2$s: easy redirect manager","wordpress-seo"),"<strong>","</strong>"),`<strong>${Object(i.__)("Superfast internal linking suggestions","wordpress-seo")}</strong>`,Object(i.sprintf)(
/* translators: %1$s expands to a 'strong' start tag, %2$s to a 'strong' end tag. */
Object(i.__)("%1$sSocial media preview%2$s: Facebook & Twitter","wordpress-seo"),"<strong>","</strong>"),`<strong>${Object(i.__)("24/7 email support","wordpress-seo")}</strong>`,`<strong>${Object(i.__)("No ads!","wordpress-seo")}</strong>`],n=r()({mixedString:t,components:{link:Object(o.createElement)(u,{href:e.link})}}),a=Object(i.sprintf)(
/* translators: %s expands to 'Yoast SEO Premium'. */
Object(i.__)("Other benefits of %s for you:","wordpress-seo"),"Yoast SEO Premium");return Object(o.createElement)(l.a,{infoParagraphs:[n,a],benefits:s,upsellButtonText:Object(i.sprintf)(
/* translators: %s expands to 'Yoast SEO Premium'. */
Object(i.__)("Get %s","wordpress-seo"),"Yoast SEO Premium"),upsellButton:{href:e.buyLink,className:"yoast-button-upsell",rel:null},upsellButtonLabel:Object(i.__)("1 year free support and updates included!","wordpress-seo")})};d.propTypes={link:p.a.string.isRequired,buyLink:p.a.string.isRequired},t.a=d},12:function(e,t){e.exports=window.wp.compose},123:function(e,t){e.exports=window.yoast.analysisReport},13:function(e,t){e.exports=window.yoast.styleGuide},14:function(e,t){function s(){return e.exports=s=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var s=arguments[t];for(var o in s)Object.prototype.hasOwnProperty.call(s,o)&&(e[o]=s[o])}return e},e.exports.__esModule=!0,e.exports.default=e.exports,s.apply(this,arguments)}e.exports=s,e.exports.__esModule=!0,e.exports.default=e.exports},153:function(e,t,s){"use strict";var o=s(6),n=s(12),r=s(1),a=s(2),i=s.n(a),l=s(123),c=s(10),p=s(57);class u extends r.Component{constructor(e){super(e);const t=this.props.results;this.state={mappedResults:{}},null!==t&&(this.state={mappedResults:Object(p.default)(t,this.props.keywordKey)}),this.handleMarkButtonClick=this.handleMarkButtonClick.bind(this)}componentDidUpdate(e){null!==this.props.results&&this.props.results!==e.results&&this.setState({mappedResults:Object(p.default)(this.props.results,this.props.keywordKey)})}handleMarkButtonClick(e,t){const s=this.props.keywordKey.length>0?`${this.props.keywordKey}:${e}`:e;s===this.props.activeMarker?(this.props.setActiveMarker(null),this.props.setMarkerPauseStatus(!1),this.removeMarkers()):(this.props.setActiveMarker(s),t())}removeMarkers(){window.YoastSEO.analysis.applyMarks(new c.Paper("",{}),[])}render(){const{mappedResults:e}=this.state,{errorsResults:t,improvementsResults:s,goodResults:o,considerationsResults:n,problemsResults:a}=e,{upsellResults:i}=this.props;return Object(r.createElement)(r.Fragment,null,Object(r.createElement)(l.ContentAnalysis,{errorsResults:t,problemsResults:a,upsellResults:i,improvementsResults:s,considerationsResults:n,goodResults:o,activeMarker:this.props.activeMarker,onMarkButtonClick:this.handleMarkButtonClick,marksButtonClassName:this.props.marksButtonClassName,marksButtonStatus:this.props.marksButtonStatus,headingLevel:3,keywordKey:this.props.keywordKey}))}}u.propTypes={results:i.a.array,upsellResults:i.a.array,marksButtonClassName:i.a.string,marksButtonStatus:i.a.string,setActiveMarker:i.a.func.isRequired,setMarkerPauseStatus:i.a.func.isRequired,activeMarker:i.a.string,keywordKey:i.a.string},u.defaultProps={results:null,upsellResults:[],marksButtonStatus:"enabled",marksButtonClassName:"",activeMarker:null,keywordKey:""};var d=u;t.a=Object(n.compose)([Object(o.withSelect)(e=>{const{getActiveMarker:t}=e("yoast-seo/editor");return{activeMarker:t()}}),Object(o.withDispatch)(e=>{const{setActiveMarker:t,setMarkerPauseStatus:s}=e("yoast-seo/editor");return{setActiveMarker:t,setMarkerPauseStatus:s}})])(d)},16:function(e,t,s){"use strict";s.d(t,"a",(function(){return n}));var o=s(4);function n(){return Object(o.get)(window,"wpseoScriptData.metabox",{intl:{},isRtl:!1})}},18:function(e,t){e.exports=window.yoast.externals.contexts},19:function(e,t,s){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},n=i(s(0)),r=i(s(95)),a=i(s(98));function i(e){return e&&e.__esModule?e:{default:e}}var l=void 0;t.default=function(e){var t=e.mixedString,s=e.components,i=e.throwErrors;if(l=t,!s)return t;if("object"!==(void 0===s?"undefined":o(s))){if(i)throw new Error("Interpolation Error: unable to process `"+t+"` because components is not an object");return t}var c=(0,a.default)(t);try{return function e(t,s){var a,i,c,p,u,d,b,m,h=[],y={};for(d=0;d<t.length;d++)if("string"!==(u=t[d]).type){if(!s.hasOwnProperty(u.value)||void 0===s[u.value])throw new Error("Invalid interpolation, missing component node: `"+u.value+"`");if("object"!==o(s[u.value]))throw new Error("Invalid interpolation, component node must be a ReactElement or null: `"+u.value+"`","\n> "+l);if("componentClose"===u.type)throw new Error("Missing opening component token: `"+u.value+"`");if("componentOpen"===u.type){a=s[u.value],c=d;break}h.push(s[u.value])}else h.push(u.value);return a&&(p=function(e,t){var s,o,n=t[e],r=0;for(o=e+1;o<t.length;o++)if((s=t[o]).value===n.value){if("componentOpen"===s.type){r++;continue}if("componentClose"===s.type){if(0===r)return o;r--}}throw new Error("Missing closing component token `"+n.value+"`")}(c,t),b=e(t.slice(c+1,p),s),i=n.default.cloneElement(a,{},b),h.push(i),p<t.length-1&&(m=e(t.slice(p+1),s),h=h.concat(m))),1===h.length?h[0]:(h.forEach((function(e,t){e&&(y["interpolation-child-"+t]=e)})),(0,r.default)(y))}(c,s)}catch(e){if(i)throw new Error("Interpolation Error: unable to process `"+t+"` because of error `"+e.message+"`");return t}}},2:function(e,t){e.exports=window.yoast.propTypes},22:function(e,t){e.exports=window.wp.apiFetch},225:function(e,t,s){"use strict";s.r(t);var o=s(1),n=s(3),r=s(11),a=s(7),i=s(9),l=s(2),c=s.n(l),p=s(8),u=s.n(p);const d=u.a.div`
	display: flex;
	margin-top: 8px;
`;class b extends o.Component{render(){return Object(o.createElement)(d,null,Object(o.createElement)(a.Toggle,{id:this.props.id,labelText:Object(n.__)("Mark as cornerstone content","wordpress-seo"),isEnabled:this.props.isEnabled,onSetToggleState:this.props.onToggle,onToggleDisabled:this.props.onToggleDisabled}))}}b.propTypes={id:c.a.string,isEnabled:c.a.bool,onToggle:c.a.func,onToggleDisabled:c.a.func},b.defaultProps={id:"cornerstone-toggle",isEnabled:!0,onToggle:()=>{},onToggleDisabled:()=>{}};var m=b,h=s(38),y=s(52);const g=Object(i.makeOutboundLink)();function f(e){let{isCornerstone:t,onChange:s,learnMoreUrl:l,location:c}=e;const p="metabox"===c?h.a:y.a;return Object(o.createElement)(p,{id:Object(i.join)(["yoast-cornerstone-collapsible",c]),title:Object(n.__)("Cornerstone content","wordpress-seo")},Object(o.createElement)(a.HelpText,null,Object(n.__)("Cornerstone content should be the most important and extensive articles on your site.","wordpress-seo")+" ",Object(o.createElement)(g,{href:l},Object(n.__)("Learn more about Cornerstone Content.","wordpress-seo"))),Object(o.createElement)(m,{id:Object(i.join)(["yoast-cornerstone",c]),isEnabled:t,onToggle:s}),Object(o.createElement)(r.Slot,{name:"YoastAfterCornerstoneToggle"}))}f.propTypes={isCornerstone:c.a.bool,onChange:c.a.func,learnMoreUrl:c.a.string.isRequired,location:c.a.string},f.defaultProps={isCornerstone:!0,onChange:()=>{},location:""};var O=s(12),w=s(6),k=s(48),j=s(22),v=s.n(j),_=s(59),E=s(29),x=s(87),R=s(82);class S extends o.Component{constructor(e){super(e),this.onModalOpen=this.onModalOpen.bind(this),this.onModalClose=this.onModalClose.bind(this),this.onLinkClick=this.onLinkClick.bind(this),this.listenToMessages=this.listenToMessages.bind(this)}onModalOpen(){this.props.keyphrase.trim()?this.props.onOpen(this.props.location):this.props.onOpenWithNoKeyphrase()}onModalClose(e){Object(R.b)(e)&&this.props.onClose()}onLinkClick(e){if(e.preventDefault(),!this.props.keyphrase.trim())return void this.props.onOpenWithNoKeyphrase();const t=e.target.href,s=["top="+(window.top.outerHeight/2+window.top.screenY-285),"left="+(window.top.outerWidth/2+window.top.screenX-170),"width=340","height=570","resizable=1","scrollbars=1","status=0"];this.popup&&!this.popup.closed||(this.popup=window.open(t,"SEMrush_login",s.join(","))),this.popup&&this.popup.focus(),window.addEventListener("message",this.listenToMessages,!1)}async listenToMessages(e){const{data:t,source:s,origin:o}=e;"https://oauth.semrush.com"===o&&this.popup===s&&("semrush:oauth:success"===t.type&&(this.popup.close(),window.removeEventListener("message",this.listenToMessages,!1),await this.performAuthenticationRequest(t)),"semrush:oauth:denied"===t.type&&(this.popup.close(),window.removeEventListener("message",this.listenToMessages,!1),this.props.onAuthentication(!1)))}async performAuthenticationRequest(e){try{const t=new URL(e.url).searchParams.get("code"),s=await v()({path:"yoast/v1/semrush/authenticate",method:"POST",data:{code:t}});200===s.status?(this.props.onAuthentication(!0),this.onModalOpen(),this.popup.close()):console.error(s.error)}catch(e){console.error(e.message)}}render(){const{keyphrase:e,location:t,whichModalOpen:s,isLoggedIn:i,shouldCloseOnClickOutside:l}=this.props;return Object(o.createElement)(o.Fragment,null,i&&Object(o.createElement)("div",{className:"yoast"},Object(o.createElement)(a.NewButton,{variant:"secondary",id:"yoast-get-related-keyphrases-"+t,onClick:this.onModalOpen},Object(n.__)("Get related keyphrases","wordpress-seo"))),e&&s===t&&Object(o.createElement)(E.a,{title:Object(n.__)("Related keyphrases","wordpress-seo"),onRequestClose:this.onModalClose,icon:Object(o.createElement)(x.a,null),additionalClassName:"yoast-related-keyphrases-modal",shouldCloseOnClickOutside:l},Object(o.createElement)(_.a,{className:"yoast-gutenberg-modal__content yoast-related-keyphrases-modal__content"},Object(o.createElement)(r.Slot,{name:"YoastRelatedKeyphrases"}))),!i&&Object(o.createElement)("div",{className:"yoast"},Object(o.createElement)(a.ButtonStyledLink,{variant:"secondary",id:"yoast-get-related-keyphrases-"+t,href:"https://oauth.semrush.com/oauth2/authorize?ref=1513012826&client_id=yoast&redirect_uri=https%3A%2F%2Foauth.semrush.com%2Foauth2%2Fyoast%2Fsuccess&response_type=code&scope=user.id",onClick:this.onLinkClick},Object(n.__)("Get related keyphrases","wordpress-seo"),Object(o.createElement)("span",{className:"screen-reader-text"},Object(n.__)("(Opens in a new browser window)","wordpress-seo")))))}}S.propTypes={keyphrase:c.a.string,location:c.a.string,whichModalOpen:c.a.oneOf(["none","metabox","sidebar"]),isLoggedIn:c.a.bool,onOpen:c.a.func.isRequired,onOpenWithNoKeyphrase:c.a.func.isRequired,onClose:c.a.func.isRequired,onAuthentication:c.a.func.isRequired,shouldCloseOnClickOutside:c.a.bool},S.defaultProps={keyphrase:"",location:"",whichModalOpen:"none",isLoggedIn:!1,shouldCloseOnClickOutside:!0};var C=S,M=Object(O.compose)([Object(w.withSelect)(e=>{const{getSEMrushModalOpen:t,getSEMrushLoginStatus:s,getIsElementorEditor:o}=e("yoast-seo/editor");return{whichModalOpen:t(),isLoggedIn:s(),shouldCloseOnClickOutside:!o()}}),Object(w.withDispatch)(e=>{const{setSEMrushNoKeyphraseMessage:t,setSEMrushOpenModal:s,setSEMrushDismissModal:o,setSEMrushLoginStatus:n}=e("yoast-seo/editor");return{onOpenWithNoKeyphrase:()=>{t()},onOpen:e=>{s(e)},onClose:()=>{o()},onAuthentication:e=>{n(e)}}})])(C),N=s(18),T=s(53);const I=u.a.div`
	padding: 16px;
	/* Necessary to compensate negative top margin of the collapsible after the keyword input. */
	border-bottom: 1px solid transparent;
`;class B extends o.Component{constructor(e){super(e),this.validate=this.validate.bind(this)}static renderHelpLink(){return Object(o.createElement)(T.a,{href:wpseoAdminL10n["shortlinks.focus_keyword_info"],className:"dashicons"},Object(o.createElement)("span",{className:"screen-reader-text"},Object(n.__)("Help on choosing the perfect focus keyphrase","wordpress-seo")))}validate(){const e=[];return 0===this.props.keyword.trim().length&&this.props.displayNoKeyphraseMessage&&e.push(Object(n.__)("Please enter a focus keyphrase first to get related keyphrases","wordpress-seo")),0===this.props.keyword.trim().length&&this.props.displayNoKeyphrasForTrackingMessage&&e.push(Object(n.__)("Please enter a focus keyphrase first to track keyphrase performance","wordpress-seo")),this.props.keyword.includes(",")&&e.push(Object(n.__)("Are you trying to use multiple keyphrases? You should add them separately below.","wordpress-seo")),this.props.keyword.length>191&&e.push(Object(n.__)("Your keyphrase is too long. It can be a maximum of 191 characters.","wordpress-seo")),e}render(){const e=this.validate();return Object(o.createElement)(N.LocationConsumer,null,t=>Object(o.createElement)("div",{style:"sidebar"===t?{borderBottom:"1px solid #f0f0f0"}:{}},Object(o.createElement)(I,{location:t},Object(o.createElement)(k.KeywordInput,{id:"focus-keyword-input-"+t,onChange:this.props.onFocusKeywordChange,keyword:this.props.keyword,label:Object(n.__)("Focus keyphrase","wordpress-seo"),helpLink:B.renderHelpLink(),onBlurKeyword:this.props.onBlurKeyword,onFocusKeyword:this.props.onFocusKeyword,hasError:e.length>0,errorMessages:e}),this.props.isSEMrushIntegrationActive&&Object(o.createElement)(M,{location:t,keyphrase:this.props.keyword})),Object(o.createElement)(r.Slot,{name:"YoastAfterKeywordInput"+(t.charAt(0).toUpperCase()+t.slice(1))})))}}B.propTypes={keyword:c.a.string,onFocusKeywordChange:c.a.func.isRequired,onFocusKeyword:c.a.func.isRequired,onBlurKeyword:c.a.func.isRequired,isSEMrushIntegrationActive:c.a.bool,displayNoKeyphraseMessage:c.a.bool,displayNoKeyphrasForTrackingMessage:c.a.bool},B.defaultProps={keyword:"",isSEMrushIntegrationActive:!1,displayNoKeyphraseMessage:!1,displayNoKeyphrasForTrackingMessage:!1};var A=Object(O.compose)([Object(w.withSelect)(e=>{const{getFocusKeyphrase:t,getSEMrushNoKeyphraseMessage:s,hasWincherNoKeyphrase:o}=e("yoast-seo/editor");return{keyword:t(),displayNoKeyphraseMessage:s(),displayNoKeyphrasForTrackingMessage:o()}}),Object(w.withDispatch)(e=>{const{setFocusKeyword:t,setMarkerPauseStatus:s}=e("yoast-seo/editor");return{onFocusKeywordChange:t,onFocusKeyword:()=>s(!0),onBlurKeyword:()=>s(!1)}})])(B),L=s(4),P=s(57),$=s(37);const F=e=>{let{target:t,scoreIndicator:s}=e;return Object(o.createElement)($.a,{target:t},Object(o.createElement)(a.SvgIcon,Object(P.getIconForScore)(s)))};F.propTypes={target:c.a.string.isRequired,scoreIndicator:c.a.string.isRequired};var K=F,q=s(153),W=s(41);function Y(e){let{target:t,children:s}=e;return Object(o.createElement)($.a,{target:t},s)}Y.propTypes={target:c.a.string.isRequired,children:c.a.node.isRequired};var U=s(123),z=s(10);const D=u.a.span`
	font-size: 1em;
	font-weight: bold;
	margin: 0 0 8px;
	display: block;
`,G=u.a.div`
	padding: 16px;
`,H=u()(T.a)`
	margin: -8px 0 -4px 4px;
`;class V extends o.Component{renderResults(e){return Object(o.createElement)(o.Fragment,null,Object(o.createElement)(D,null,Object(n.__)("Analysis results","wordpress-seo"),Object(o.createElement)(H,{href:wpseoAdminL10n["shortlinks.readability_analysis_info"],className:"dashicons"},Object(o.createElement)("span",{className:"screen-reader-text"},Object(n.__)("Learn more about the readability analysis","wordpress-seo")))),Object(o.createElement)(q.a,{results:this.props.results,upsellResults:e,marksButtonClassName:"yoast-tooltip yoast-tooltip-w",marksButtonStatus:this.props.marksButtonStatus}))}getUpsellResults(e){let t=wpseoAdminL10n["shortlinks.upsell.metabox.word_complexity"];"sidebar"===e&&(t=wpseoAdminL10n["shortlinks.upsell.sidebar.word_complexity"]);const s=wpseoAdminL10n.postType;return this.props.isYoastSEOWooActive&&"product"===s||!function(){const e=z.helpers.getLanguagesWithWordComplexity(),t=window.wpseoScriptData.metabox.contentLocale,s=z.languageProcessing.getLanguage(t);return e.includes(s)}()?[]:[{score:0,rating:"upsell",hasMarks:!1,id:"wordComplexity",text:Object(n.sprintf)(
/* Translators: %1$s is a span tag that adds styling to 'Word complexity', %2$s is a closing span tag.
       %3$s is an anchor tag with a link to yoast.com, %4$s is a closing anchor tag.*/
Object(n.__)("%1$sWord complexity%2$s: Is your vocabulary suited for a larger audience? %3$sYoast SEO Premium will tell you!%4$s","wordpress-seo"),"<span style='text-decoration: underline'>","</span>",`<a href="${t}">`,"</a>"),markerId:"wordComplexity"}]}renderFleschReadingEaseNote(e){const t=`<svg\n\t\t\tstyle="vertical-align: middle; margin-left: 2px"\n\t\t\twidth="14px"\n\t\t\theight="14px"\n\t\t\taria-hidden="true"\n\t\t\trole="img"\n\t\t\tfocusable="false"\n\t\t\tclass="yoast-svg-icon yoast-svg-icon-pencil-square"\n\t\t\tviewBox="0 0 1792 1792"\n\t\t\tfill="currentColor">\n\t\t\t\t<path d="${a.icons["pencil-square"].path}"></path>\n\t\t</svg>`,s="sidebar"===e?wpseoAdminL10n["shortlinks-insights-flesch_reading_ease_sidebar"]:wpseoAdminL10n["shortlinks-insights-flesch_reading_ease_metabox"];let r="";if(this.props.isInsightsEnabled){const o=`\n\t\t\tconst location = "${e}";\n\t\t\tconst isElementor = ${this.props.isElementorEditor};\n\t\t\t\n\t\t\tif ( isElementor ) {\n\t\t\t\tdocument.getElementById( "yoast-insights-modal-elementor-open-button" ).click();\n\t\t\t} else {\n\t\t\t\tconst metaTab = document.getElementById( "wpseo-meta-tab-content" );\n\t\t\t\tif ( metaTab && location === "metabox" ) {\n\t\t\t\t\tmetaTab.click();\n\t\t\t\t\tsetTimeout( () => {\n\t\t\t\t\t\tconst collapsible = document.getElementById( "yoast-insights-collapsible-metabox" );\n\t\t\t\t\t\tif( collapsible.getAttribute( "aria-expanded" ) === "false" ) {\n\t\t\t\t\t\t\tcollapsible.click();\n\t\t\t\t\t\t}\n\t\t\t\t\t\tdocument.getElementById( "yoastseo-flesch-reading-ease-insights" ).scrollIntoView();\n\t\t\t\t\t}, 300 );\n\t\t\t\t} else if ( location === "sidebar" ) {\n\t\t\t\t\tdocument.getElementById( "yoast-insights-modal-sidebar-open-button" ).click();\n\t\t\t\t}\n\t\t\t}\n\t\t\t`.replaceAll(/(\n|\s)+/g," ");r=Object(n.sprintf)(
/* Translators:
      	%1$s is an anchor opening tag with a link leading to an article on yoast.com;
      	%2$s is an anchor closing tag;
      	%3$s is an anchor opening tag with a link to our insights section;
      	%4$s is an icon. */
Object(n.__)("Curious to see the %1$sFlesch reading ease%2$s score of your text? We've moved the score to our %3$sInsights%4$s%2$s section.","wordpress-seo"),`<a href='${s}' target='_blank'>`,"</a>",`<a href='#' onclick='${o}'>`,t)}else r=Object(n.sprintf)(
/* Translators:
      	%1$s is an anchor opening tag with a link leading to an article on yoast.com;
      	%2$s is an anchor closing tag; */
Object(n.__)("Curious to see the %1$sFlesch reading ease%2$s score of your text? We've moved the score to our Insights section. Enable the Insights feature in General > Features, or ask your admin to enable it for you.","wordpress-seo"),`<a href='${s}' target='_blank'>`,"</a>");return Object(o.createElement)("ul",null,Object(o.createElement)(U.AnalysisResult,{icon:"alert-info",pressed:!1,onButtonClick:L.noop,bulletColor:"gray",buttonId:"",text:r,hasMarksButton:!1,ariaLabel:""}))}render(){const e=Object(W.a)(this.props.overallScore);return Object(L.isNil)(this.props.overallScore)&&(e.className="loading"),Object(o.createElement)(N.LocationConsumer,null,t=>{let s=[];return this.props.shouldUpsell&&(s=this.getUpsellResults(t)),"sidebar"===t?Object(o.createElement)(y.a,{title:Object(n.__)("Readability analysis","wordpress-seo"),titleScreenReaderText:e.screenReaderReadabilityText,prefixIcon:Object(P.getIconForScore)(e.className),prefixIconCollapsed:Object(P.getIconForScore)(e.className),id:"yoast-readability-analysis-collapsible-"+t},this.renderResults(s),this.props.isFleschReadingEaseAvailable&&this.renderFleschReadingEaseNote(t)):"metabox"===t?Object(o.createElement)(Y,{target:"wpseo-metabox-readability-root"},Object(o.createElement)(G,null,Object(o.createElement)(K,{target:"wpseo-readability-score-icon",scoreIndicator:e.className}),this.renderResults(s),this.props.isFleschReadingEaseAvailable&&this.renderFleschReadingEaseNote(t))):void 0})}}V.propTypes={results:c.a.array.isRequired,marksButtonStatus:c.a.string.isRequired,overallScore:c.a.number,shouldUpsell:c.a.bool,isYoastSEOWooActive:c.a.bool,isInsightsEnabled:c.a.bool,isElementorEditor:c.a.bool,isFleschReadingEaseAvailable:c.a.bool},V.defaultProps={overallScore:null,shouldUpsell:!1,isYoastSEOWooActive:!1,isInsightsEnabled:!1,isElementorEditor:!1,isFleschReadingEaseAvailable:!1};var X=Object(w.withSelect)(e=>{const{getReadabilityResults:t,getMarkButtonStatus:s,getPreference:o,getIsElementorEditor:n,isFleschReadingEaseAvailable:r}=e("yoast-seo/editor"),a=o("isInsightsEnabled",!1);return{...t(),marksButtonStatus:s(),isInsightsEnabled:a,isElementorEditor:n(),isFleschReadingEaseAvailable:r()}})(V),J=s(16),Q=s(13);const Z=u.a.p`
	color: ${Q.colors.$color_upsell_text};
	margin: 0;
	padding-right: 8px;
`,ee=u.a.div`
	font-size: 1em;
	display: flex;
	flex-direction: ${e=>"horizontal"===e.alignment?"row":"column"};
	${Object(i.getDirectionalStyle)("border-left","border-right")}: 4px solid ${Q.colors.$color_pink_dark};
	margin: 16px 0;
	padding: 0 0 0 8px;
	max-width: 600px;

	> ${Z} {
		margin-bottom: ${e=>"vertical"===e.alignment&&"16px"};
	}
`,te=u()(a.SvgIcon)`
	margin: ${Object(i.getDirectionalStyle)("0 0 0 4px","0 4px 0 0")};
	transform: ${Object(i.getDirectionalStyle)("rotate(0deg)","rotate(180deg)")};
`,se=Object(i.makeOutboundLink)(a.UpsellLinkButton),oe=e=>{const{alignment:t,url:s}=e;return Object(o.createElement)(ee,{alignment:t},Object(o.createElement)(Z,null,Object(n.sprintf)(
/* translators: %s expands to Yoast SEO Premium */
Object(n.__)("Did you know %s also analyzes the different word forms of your keyphrase, like plurals and past tenses?","wordpress-seo"),"Yoast SEO Premium")),Object(o.createElement)("div",null,Object(o.createElement)(se,{href:s,className:"UpsellLinkButton"},Object(n.sprintf)(
/* translators: %s expands to Premium */
Object(n.__)("Go %s!","wordpress-seo"),"Premium"),Object(o.createElement)(te,{icon:"arrow-right",size:"8px",color:Q.colors.$color_black}))))};oe.propTypes={alignment:c.a.oneOf(["horizontal","vertical"]),url:c.a.string.isRequired},oe.defaultProps={alignment:"vertical"};var ne=oe,re=s(19),ae=s.n(re),ie=s(71);const le=Object(i.makeOutboundLink)(),ce=e=>{const t=Object(n.sprintf)(
/* translators: %1$s expands to a 'Yoast SEO Premium' text linked to the yoast.com website. */
Object(n.__)("Great news: you can, with %1$s!","wordpress-seo"),"{{link}}Yoast SEO Premium{{/link}}"),s=ae()({mixedString:t,components:{link:Object(o.createElement)(le,{href:e.link})}}),r=[`<strong>${Object(n.__)("Rank better with synonyms & related keyphrases","wordpress-seo")}</strong>`,Object(n.sprintf)(
/* translators: %1$s expands to a 'strong' start tag, %2$s to a 'strong' end tag. */
Object(n.__)("%1$sNo more dead links%2$s: easy redirect manager","wordpress-seo"),"<strong>","</strong>"),`<strong>${Object(n.__)("Superfast internal linking suggestions","wordpress-seo")}</strong>`,Object(n.sprintf)(
/* translators: %1$s expands to a 'strong' start tag, %2$s to a 'strong' end tag. */
Object(n.__)("%1$sSocial media preview%2$s: Facebook & Twitter","wordpress-seo"),"<strong>","</strong>"),`<strong>${Object(n.__)("24/7 email support","wordpress-seo")}</strong>`,`<strong>${Object(n.__)("No ads!","wordpress-seo")}</strong>`],a=Object(n.sprintf)(
/* translators: %s expands to 'Yoast SEO Premium'. */
Object(n.__)("Other benefits of %s for you:","wordpress-seo"),"Yoast SEO Premium");return Object(o.createElement)(ie.a,{infoParagraphs:[s,a],benefits:r,upsellButtonText:Object(n.sprintf)(
/* translators: %s expands to 'Yoast SEO Premium'. */
Object(n.__)("Get %s","wordpress-seo"),"Yoast SEO Premium"),upsellButton:{href:e.buyLink,className:"yoast-button-upsell",rel:null},upsellButtonLabel:Object(n.__)("1 year free support and updates included!","wordpress-seo")})};ce.propTypes={link:c.a.string.isRequired,buyLink:c.a.string.isRequired};var pe=ce,ue=s(113);const de=u.a.button`
	// Increase specificity to override WP rules.
	&& {
		display: flex;
		align-items: center;
	}

	.yoast-svg-icon {
		margin: 1px 7px 0 0;
		fill: currentColor;
	}
`,be={open:Object(n.__)("Open","wordpress-seo"),heading:"",closeIconButton:Object(n.__)("Close","wordpress-seo"),closeButton:""},me=e=>{const[t,s]=Object(o.useState)(!1),n=Object.assign({},be,e.labels),r=Object(o.useCallback)(()=>s(!1),[]),i=Object(o.useCallback)(()=>s(!0),[]);return Object(o.createElement)(o.Fragment,null,Object(o.createElement)(de,{type:"button",onClick:i,className:e.classes.openButton+" yoast-modal__button-open"},e.openButtonIcon&&Object(o.createElement)(a.SvgIcon,{icon:e.openButtonIcon,size:"13px"}),n.open),t&&Object(o.createElement)(E.a,{onRequestClose:r,className:e.className,title:n.heading},e.children))};me.propTypes={openButtonIcon:c.a.string,labels:c.a.shape({open:c.a.string,modalAriaLabel:c.a.string.isRequired,heading:c.a.string,closeIconButton:c.a.string,closeButton:c.a.string}).isRequired,classes:c.a.shape({openButton:c.a.string,closeIconButton:c.a.string,closeButton:c.a.string}),className:c.a.string,children:c.a.any.isRequired},me.defaultProps={className:E.b,openButtonIcon:"",classes:{}};var he=me;function ye(e){let{location:t}=e;return Object(o.createElement)(r.Slot,{name:"yoast-synonyms-"+t})}ye.propTypes={location:c.a.string.isRequired};const ge=u.a.span`
	font-size: 1em;
	font-weight: bold;
	margin: 1.5em 0 1em;
	display: block;
`;class fe extends o.Component{renderSynonymsUpsell(e){const t={classes:{openButton:"wpseo-keyword-synonyms button-link"},labels:{open:"+ "+Object(n.__)("Add synonyms","wordpress-seo"),modalAriaLabel:Object(n.sprintf)(
/* translators: %s expands to 'Yoast SEO Premium'. */
Object(n.__)("Get %s","wordpress-seo"),"Yoast SEO Premium"),heading:Object(n.sprintf)(
/* translators: %s expands to 'Yoast SEO Premium'. */
Object(n.__)("Get %s","wordpress-seo"),"Yoast SEO Premium")}};let s=wpseoAdminL10n["shortlinks.upsell.metabox.focus_keyword_synonyms_link"],r=wpseoAdminL10n["shortlinks.upsell.metabox.focus_keyword_synonyms_button"];return"sidebar"===e.toLowerCase()&&(s=wpseoAdminL10n["shortlinks.upsell.sidebar.focus_keyword_synonyms_link"],r=wpseoAdminL10n["shortlinks.upsell.sidebar.focus_keyword_synonyms_button"]),Object(o.createElement)(he,t,Object(o.createElement)(_.a,null,Object(o.createElement)(_.b,{icon:a.YoastSeoIcon}),Object(o.createElement)("h2",null,Object(n.__)("Would you like to add keyphrase synonyms?","wordpress-seo")),Object(o.createElement)(pe,{link:s,buyLink:r})))}renderMultipleKeywordsUpsell(e){const t={classes:{openButton:"wpseo-multiple-keywords button-link"},labels:{open:"+ "+Object(n.__)("Add related keyphrase","wordpress-seo"),modalAriaLabel:Object(n.sprintf)(
/* translators: %s expands to 'Yoast SEO Premium'. */
Object(n.__)("Get %s","wordpress-seo"),"Yoast SEO Premium"),heading:Object(n.sprintf)(
/* translators: %s expands to 'Yoast SEO Premium'. */
Object(n.__)("Get %s","wordpress-seo"),"Yoast SEO Premium")}};let s=wpseoAdminL10n["shortlinks.upsell.metabox.focus_keyword_additional_link"],r=wpseoAdminL10n["shortlinks.upsell.metabox.focus_keyword_additional_button"];return"sidebar"===e.toLowerCase()&&(s=wpseoAdminL10n["shortlinks.upsell.sidebar.focus_keyword_additional_link"],r=wpseoAdminL10n["shortlinks.upsell.sidebar.focus_keyword_additional_button"]),Object(o.createElement)(he,t,Object(o.createElement)(_.a,null,Object(o.createElement)(_.b,{icon:a.YoastSeoIcon}),Object(o.createElement)("h2",null,Object(n.__)("Would you like to add a related keyphrase?","wordpress-seo")),Object(o.createElement)(ue.a,{link:s,buyLink:r})))}renderWordFormsUpsell(e){return Object(o.createElement)(ne,{url:"sidebar"===e?wpseoAdminL10n["shortlinks.upsell.sidebar.morphology_upsell_sidebar"]:wpseoAdminL10n["shortlinks.upsell.sidebar.morphology_upsell_metabox"],alignment:"sidebar"===e?"vertical":"horizontal"})}renderTabIcon(e,t){return"metabox"!==e?null:Object(o.createElement)(K,{target:"wpseo-seo-score-icon",scoreIndicator:t})}getUpsellResults(e){let t=wpseoAdminL10n["shortlinks.upsell.metabox.keyphrase_distribution"];"sidebar"===e&&(t=wpseoAdminL10n["shortlinks.upsell.sidebar.keyphrase_distribution"]);const s=wpseoAdminL10n.postType;return this.props.isYoastSEOWooActive&&"product"===s?[]:[{score:0,rating:"upsell",hasMarks:!1,id:"keyphraseDistribution",text:Object(n.sprintf)(
/* Translators: %1$s is a span tag that adds styling to 'Keyphrase distribution', %2$s is a closing span tag.
       %3%s is an anchor tag with a link to yoast.com, %4$s is a closing anchor tag.*/
Object(n.__)("%1$sKeyphrase distribution%2$s: Have you evenly distributed your focus keyphrase throughout the whole text? %3$sYoast SEO Premium will tell you!%4$s","wordpress-seo"),"<span style='text-decoration: underline'>","</span>",`<a href="${t}">`,"</a>"),markerId:"keyphraseDistribution"}]}render(){const e=Object(W.a)(this.props.overallScore),t=Object(J.a)().isPremium;return"loading"!==e.className&&""===this.props.keyword&&(e.className="na",e.screenReaderReadabilityText=Object(n.__)("Enter a focus keyphrase to calculate the SEO score","wordpress-seo")),Object(o.createElement)(N.LocationConsumer,null,s=>{const r="metabox"===s?h.a:y.a;let a=[];return this.props.shouldUpsell&&(a=this.getUpsellResults(s)),Object(o.createElement)(o.Fragment,null,Object(o.createElement)(r,{title:t?Object(n.__)("Premium SEO analysis","wordpress-seo"):Object(n.__)("SEO analysis","wordpress-seo"),titleScreenReaderText:e.screenReaderReadabilityText,prefixIcon:Object(P.getIconForScore)(e.className),prefixIconCollapsed:Object(P.getIconForScore)(e.className),subTitle:this.props.keyword,id:"yoast-seo-analysis-collapsible-"+s},Object(o.createElement)(ye,{location:s}),this.props.shouldUpsell&&Object(o.createElement)(o.Fragment,null,this.renderSynonymsUpsell(s),this.renderMultipleKeywordsUpsell(s)),this.props.shouldUpsellWordFormRecognition&&this.renderWordFormsUpsell(s),Object(o.createElement)(ge,null,Object(n.__)("Analysis results","wordpress-seo")),Object(o.createElement)(q.a,{results:this.props.results,upsellResults:a,marksButtonClassName:"yoast-tooltip yoast-tooltip-w",marksButtonStatus:this.props.marksButtonStatus})),this.renderTabIcon(s,e.className))})}}fe.propTypes={results:c.a.array,marksButtonStatus:c.a.string,keyword:c.a.string,shouldUpsell:c.a.bool,shouldUpsellWordFormRecognition:c.a.bool,overallScore:c.a.number,isYoastSEOWooActive:c.a.bool},fe.defaultProps={results:[],marksButtonStatus:null,keyword:"",shouldUpsell:!1,shouldUpsellWordFormRecognition:!1,overallScore:null,isYoastSEOWooActive:!1};var Oe=Object(w.withSelect)((e,t)=>{const{getFocusKeyphrase:s,getMarksButtonStatus:o,getResultsForKeyword:n}=e("yoast-seo/editor"),r=s();return{...n(r),marksButtonStatus:t.hideMarksButtons?"disabled":o(),keyword:r}})(fe);window.yoast=window.yoast||{},window.yoast.externals=window.yoast.externals||{},window.yoast.externals.components={CollapsibleCornerstone:f,KeywordInput:A,ReadabilityAnalysis:X,SeoAnalysis:Oe}},29:function(e,t,s){"use strict";s.d(t,"b",(function(){return c}));var o=s(14),n=s.n(o),r=s(1),a=s(2),i=s.n(a),l=s(11);const c="yoast yoast-gutenberg-modal",p=e=>{const{title:t,className:s,showYoastIcon:o,additionalClassName:a,...i}=e,c=o?Object(r.createElement)("span",{className:"yoast-icon"}):null;return Object(r.createElement)(l.Modal,n()({title:t,className:`${s} ${a}`,icon:c},i),e.children)};p.propTypes={title:i.a.string,className:i.a.string,showYoastIcon:i.a.bool,children:i.a.oneOfType([i.a.node,i.a.arrayOf(i.a.node)]),additionalClassName:i.a.string},p.defaultProps={title:"Yoast SEO",className:c,showYoastIcon:!0,children:null,additionalClassName:""},t.a=p},3:function(e,t){e.exports=window.wp.i18n},37:function(e,t,s){"use strict";s.d(t,"a",(function(){return a}));var o=s(1),n=s(2),r=s.n(n);function a(e){let{target:t,children:s}=e,n=t;return"string"==typeof t&&(n=document.getElementById(t)),n?Object(o.createPortal)(s,n):null}a.propTypes={target:r.a.oneOfType([r.a.string,r.a.object]).isRequired,children:r.a.node.isRequired}},38:function(e,t,s){"use strict";var o=s(14),n=s.n(o),r=s(1),a=s(7),i=s(8);const l=s.n(i)()(a.Collapsible)`
	h2 > button {
		padding-left: 24px;
		padding-top: 16px;

		&:hover {
			background-color: #f0f0f0;
		}
	}

	div[class^="collapsible_content"] {
		padding: 24px 0;
		margin: 0 24px;
		border-top: 1px solid rgba(0,0,0,0.2);
	}

`;t.a=e=>Object(r.createElement)(l,n()({hasPadding:!0,hasSeparator:!0},e))},4:function(e,t){e.exports=window.lodash},41:function(e,t,s){"use strict";s.d(t,"a",(function(){return a}));var o=s(3),n=s(10),r=s(4);function a(e){return Object(r.isNil)(e)||(e/=10),function(e){switch(e){case"feedback":return{className:"na",screenReaderText:Object(o.__)("Feedback","wordpress-seo"),screenReaderReadabilityText:""};case"bad":return{className:"bad",screenReaderText:Object(o.__)("Needs improvement","wordpress-seo"),screenReaderReadabilityText:Object(o.__)("Needs improvement","wordpress-seo")};case"ok":return{className:"ok",screenReaderText:Object(o.__)("OK SEO score","wordpress-seo"),screenReaderReadabilityText:Object(o.__)("OK","wordpress-seo")};case"good":return{className:"good",screenReaderText:Object(o.__)("Good SEO score","wordpress-seo"),screenReaderReadabilityText:Object(o.__)("Good","wordpress-seo")};default:return{className:"loading",screenReaderText:"",screenReaderReadabilityText:""}}}(n.interpreters.scoreToRating(e))}},48:function(e,t){e.exports=window.yoast.components},52:function(e,t,s){"use strict";var o=s(1),n=s(7),r=s(2),a=s.n(r);const i=e=>{const[t,s]=Object(o.useState)(!1),{prefixIcon:r}=e;return Object(o.createElement)("div",{className:"yoast components-panel__body "+(t?"is-opened":"")},Object(o.createElement)("h2",{className:"components-panel__body-title"},Object(o.createElement)("button",{onClick:function(){s(!t)},className:"components-button components-panel__body-toggle"},Object(o.createElement)("span",{className:"yoast-icon-span",style:{fill:""+(r&&r.color||"")}},r&&Object(o.createElement)(n.SvgIcon,{icon:r.icon,color:r.color,size:r.size})),Object(o.createElement)("span",{className:"yoast-title-container"},Object(o.createElement)("div",{className:"yoast-title"},e.title),Object(o.createElement)("div",{className:"yoast-subtitle"},e.subTitle)),Object(o.createElement)("span",{className:"yoast-chevron","aria-hidden":"true"}))),t&&e.children)};t.a=i,i.propTypes={title:a.a.string.isRequired,children:a.a.oneOfType([a.a.node,a.a.arrayOf(a.a.node)]).isRequired,prefixIcon:a.a.object,subTitle:a.a.string},i.defaultProps={prefixIcon:null,subTitle:""}},53:function(e,t,s){"use strict";var o=s(13),n=s(9),r=s(8),a=s.n(r);const i=Object(n.makeOutboundLink)(a.a.a`
	display: inline-block;
	position: relative;
	outline: none;
	text-decoration: none;
	border-radius: 100%;
	width: 24px;
	height: 24px;
	margin: -4px 0;
	vertical-align: middle;

	color: ${o.colors.$color_help_text};
	
	&:hover,
	&:focus {
		color: ${o.colors.$color_snippet_focus};	
	}
	
	// Overwrite the default blue active color for links.
	&:active {
		color: ${o.colors.$color_help_text};	
	}

	&::before {
		position: absolute;
		top: 0;
		left: 0;
		padding: 2px;
		content: "\f223";
	}
`);t.a=i},57:function(e,t,s){"use strict";s.r(t),s.d(t,"getIconForScore",(function(){return i})),s.d(t,"default",(function(){return l}));var o=s(10),n=s(13);function r(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"";const s=e.getIdentifier(),n={score:e.score,rating:o.interpreters.scoreToRating(e.score),hasMarks:e.hasMarks(),marker:e.getMarker(),id:s,text:e.text,markerId:t.length>0?`${t}:${s}`:s,hasBetaBadge:e.hasBetaBadge()};return"ok"===n.rating&&(n.rating="OK"),n}function a(e,t){switch(e.rating){case"error":t.errorsResults.push(e);break;case"feedback":t.considerationsResults.push(e);break;case"bad":t.problemsResults.push(e);break;case"OK":t.improvementsResults.push(e);break;case"good":t.goodResults.push(e)}return t}function i(e){let t={icon:"seo-score-none",color:n.colors.$color_red};switch(e){case"loading":t={icon:"loading-spinner",color:n.colors.$color_green_medium_light};break;case"not-set":t={icon:"seo-score-none",color:n.colors.$color_grey};break;case"good":t={icon:"seo-score-good",color:n.colors.$color_green_medium};break;case"ok":t={icon:"seo-score-ok",color:n.colors.$color_ok};break;case"bad":t={icon:"seo-score-bad",color:n.colors.$color_red}}return t}function l(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"",s={errorsResults:[],problemsResults:[],improvementsResults:[],goodResults:[],considerationsResults:[]};if(!e)return s;for(let o=0;o<e.length;o++){const n=e[o];n.text&&(s=a(r(n,t),s))}return s}},59:function(e,t,s){"use strict";s.d(t,"a",(function(){return i})),s.d(t,"b",(function(){return l}));var o=s(8),n=s.n(o),r=s(7),a=s(9);const i=n.a.div`
	min-width: 600px;

	@media screen and ( max-width: 680px ) {
		min-width: 0;
		width: 86vw;
	}
`,l=n()(r.Icon)`
	float: ${Object(a.getDirectionalStyle)("right","left")};
	margin: ${Object(a.getDirectionalStyle)("0 0 16px 16px","0 16px 16px 0")};

	&& {
		width: 150px;
		height: 150px;

		@media screen and ( max-width: 680px ) {
			width: 80px;
			height: 80px;
		}
	}
`},6:function(e,t){e.exports=window.wp.data},61:function(e,t,s){"use strict";var o=s(1),n=s(7),r=s(2),a=s.n(r);const i=e=>Object(o.createElement)("div",{className:"yoast components-panel__body"},Object(o.createElement)("h2",{className:"components-panel__body-title"},Object(o.createElement)("button",{id:e.id,onClick:e.onClick,className:"components-button components-panel__body-toggle"},e.prefixIcon&&Object(o.createElement)("span",{className:"yoast-icon-span",style:{fill:""+(e.prefixIcon&&e.prefixIcon.color||"")}},Object(o.createElement)(n.SvgIcon,{size:e.prefixIcon.size,icon:e.prefixIcon.icon})),Object(o.createElement)("span",{className:"yoast-title-container"},Object(o.createElement)("div",{className:"yoast-title"},e.title),Object(o.createElement)("div",{className:"yoast-subtitle"},e.subTitle)),e.children,e.suffixIcon&&Object(o.createElement)(n.SvgIcon,{size:e.suffixIcon.size,icon:e.suffixIcon.icon}))));t.a=i,i.propTypes={onClick:a.a.func.isRequired,title:a.a.string.isRequired,id:a.a.string,subTitle:a.a.string,suffixIcon:a.a.object,prefixIcon:a.a.object,children:a.a.node},i.defaultProps={id:"",suffixIcon:null,prefixIcon:null,subTitle:"",children:null}},68:function(e,t,s){"use strict";function o(e){return function(){return e}}var n=function(){};n.thatReturns=o,n.thatReturnsFalse=o(!1),n.thatReturnsTrue=o(!0),n.thatReturnsNull=o(null),n.thatReturnsThis=function(){return this},n.thatReturnsArgument=function(e){return e},e.exports=n},7:function(e,t){e.exports=window.yoast.componentsNew},71:function(e,t,s){"use strict";var o=s(1),n=s(19),r=s.n(n),a=s(2),i=s.n(a),l=s(8),c=s.n(l),p=s(9);const u=c.a.ul`
	list-style: none;
	margin: 0 0 24px;
	padding: 0;

	li {
		margin: 10px 0 0 0;
	}

	span[aria-hidden="true"]:before {
		content: "";
		display: inline-block;
		height: 13px;
		width: 13px;
		background-size: 13px 13px;
		background-image: var( --yoast-svg-icon-check );
		background-repeat: no-repeat;
		margin-right: 10px;
	}
`,d=c.a.small`
	display: block;
	margin-top: 4px;
`,b=Object(p.makeOutboundLink)();class m extends o.Component{constructor(e){super(e)}createBenefitsList(e){return e.length>0&&Object(o.createElement)(u,{role:"list"},e.map((e,t)=>Object(o.createElement)("li",{key:t},Object(o.createElement)("span",{"aria-hidden":"true"}),r()({mixedString:e.replace("<strong>","{{strong}}").replace("</strong>","{{/strong}}"),components:{strong:Object(o.createElement)("strong",null)}}))))}createInfoParagraphs(e){return e.map((e,t)=>Object(o.createElement)("p",{key:t},e))}render(){return Object(o.createElement)("div",null,this.createInfoParagraphs(this.props.infoParagraphs),this.createBenefitsList(this.props.benefits),Object(o.createElement)(b,this.props.upsellButton,this.props.upsellButtonText,this.props.upsellButtonHasCaret&&Object(o.createElement)("span",{"aria-hidden":"true",className:"yoast-button-upsell__caret"})),Object(o.createElement)(d,{id:this.props.upsellButton["aria-describedby"]},this.props.upsellButtonLabel))}}m.propTypes={benefits:i.a.array,infoParagraphs:i.a.array,upsellButton:i.a.object,upsellButtonText:i.a.string.isRequired,upsellButtonLabel:i.a.string,upsellButtonHasCaret:i.a.bool},m.defaultProps={infoParagraphs:[],benefits:[],upsellButton:{href:"",className:"button button-primary"},upsellButtonLabel:"",upsellButtonHasCaret:!0},t.a=m},8:function(e,t){e.exports=window.yoast.styledComponents},82:function(e,t,s){"use strict";s.d(t,"b",(function(){return u}));var o=s(1),n=s(3),r=s(29),a=s(2),i=s.n(a),l=s(4),c=s(61),p=s(18);const u=e=>{let t=!0;if("blur"===e.type){const{relatedTarget:s}=e;if(s){const e=["media-modal","wp-core-ui"];t=Object(l.intersection)(e,Array.from(s.classList)).length!==e.length}}return t},d=e=>{let{id:t,postTypeName:s,children:a,title:i,isOpen:l,close:d,open:b,shouldCloseOnClickOutside:m,showChangesWarning:h}=e;const y=Object(o.useCallback)(e=>{u(e)&&d()},[d]);return Object(o.createElement)(o.Fragment,null,l&&Object(o.createElement)(p.LocationProvider,{value:"modal"},Object(o.createElement)(r.a,{title:i,onRequestClose:y,additionalClassName:"yoast-collapsible-modal yoast-post-settings-modal",id:"id",shouldCloseOnClickOutside:m},Object(o.createElement)("div",{className:"yoast-content-container"},Object(o.createElement)("div",{className:"yoast-modal-content"},a)),Object(o.createElement)("div",{className:"yoast-notice-container"},Object(o.createElement)("hr",null),Object(o.createElement)("div",{className:"yoast-button-container"},h&&Object(o.createElement)("p",null,
/* Translators: %s translates to the Post Label in singular form */
Object(n.sprintf)(Object(n.__)("Make sure to save your %s for changes to take effect","wordpress-seo"),s)),Object(o.createElement)("button",{className:"yoast-button yoast-button--primary yoast-button--post-settings-modal",type:"button",onClick:y},
/* Translators: %s translates to the Post Label in singular form */
Object(n.sprintf)(Object(n.__)("Return to your %s","wordpress-seo"),s)))))),Object(o.createElement)(c.a,{id:t+"-open-button",title:i,suffixIcon:{size:"20px",icon:"pencil-square"},onClick:b}))};d.propTypes={id:i.a.string.isRequired,postTypeName:i.a.string.isRequired,children:i.a.oneOfType([i.a.node,i.a.arrayOf(i.a.node)]).isRequired,title:i.a.string.isRequired,isOpen:i.a.bool.isRequired,open:i.a.func.isRequired,close:i.a.func.isRequired,shouldCloseOnClickOutside:i.a.bool,showChangesWarning:i.a.bool},d.defaultProps={shouldCloseOnClickOutside:!0,showChangesWarning:!0},t.a=d},87:function(e,t,s){"use strict";s.d(t,"a",(function(){return i}));var o,n,r=s(0);function a(){return(a=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var s=arguments[t];for(var o in s)Object.prototype.hasOwnProperty.call(s,o)&&(e[o]=s[o])}return e}).apply(this,arguments)}function i(e){return r.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 425 456.27","aria-hidden":"true"},e),o||(o=r.createElement("path",{d:"M73 405.26a66.79 66.79 0 01-6.54-1.7 64.75 64.75 0 01-6.28-2.31c-1-.42-2-.89-3-1.37-1.49-.72-3-1.56-4.77-2.56-1.5-.88-2.71-1.64-3.83-2.39-.9-.61-1.8-1.26-2.68-1.92a70.154 70.154 0 01-5.08-4.19 69.21 69.21 0 01-8.4-9.17c-.92-1.2-1.68-2.25-2.35-3.24a70.747 70.747 0 01-3.44-5.64 68.29 68.29 0 01-8.29-32.55V142.13a68.26 68.26 0 018.29-32.55c1-1.92 2.21-3.82 3.44-5.64s2.55-3.58 4-5.27a69.26 69.26 0 0114.49-13.25C50.37 84.19 52.27 83 54.2 82A67.59 67.59 0 0173 75.09a68.75 68.75 0 0113.75-1.39h169.66L263 55.39H86.75A86.84 86.84 0 000 142.13v196.09A86.84 86.84 0 0086.75 425h11.32v-18.35H86.75A68.75 68.75 0 0173 405.26zM368.55 60.85l-1.41-.53-6.41 17.18 1.41.53a68.06 68.06 0 018.66 4c1.93 1 3.82 2.2 5.65 3.43A69.19 69.19 0 01391 98.67c1.4 1.68 2.72 3.46 3.95 5.27s2.39 3.72 3.44 5.64a68.29 68.29 0 018.29 32.55v264.52H233.55l-.44.76c-3.07 5.37-6.26 10.48-9.49 15.19L222 425h203V142.13a87.2 87.2 0 00-56.45-81.28z"})),n||(n=r.createElement("path",{d:"M119.8 408.28v46c28.49-1.12 50.73-10.6 69.61-29.58 19.45-19.55 36.17-50 52.61-96L363.94 1.9H305l-98.25 272.89-48.86-153h-54l71.7 184.18a75.67 75.67 0 010 55.12c-7.3 18.68-20.25 40.66-55.79 47.19z",stroke:"#000",strokeMiterlimit:10,strokeWidth:3.81})))}},9:function(e,t){e.exports=window.yoast.helpers},95:function(e,t,s){"use strict";var o=s(0),n="function"==typeof Symbol&&Symbol.for&&Symbol.for("react.element")||60103,r=s(68),a=s(96),i=s(97),l="function"==typeof Symbol&&Symbol.iterator;function c(e,t){return e&&"object"==typeof e&&null!=e.key?(s=e.key,o={"=":"=0",":":"=2"},"$"+(""+s).replace(/[=:]/g,(function(e){return o[e]}))):t.toString(36);var s,o}var p=/\/+/g;function u(e){return(""+e).replace(p,"$&/")}var d,b,m=h,h=function(e){if(this.instancePool.length){var t=this.instancePool.pop();return this.call(t,e),t}return new this(e)};function y(e,t,s,o){this.result=e,this.keyPrefix=t,this.func=s,this.context=o,this.count=0}function g(e,t,s){var n,a,i=e.result,l=e.keyPrefix,c=e.func,p=e.context,d=c.call(p,t,e.count++);Array.isArray(d)?f(d,i,s,r.thatReturnsArgument):null!=d&&(o.isValidElement(d)&&(n=d,a=l+(!d.key||t&&t.key===d.key?"":u(d.key)+"/")+s,d=o.cloneElement(n,{key:a},void 0!==n.props?n.props.children:void 0)),i.push(d))}function f(e,t,s,o,r){var i="";null!=s&&(i=u(s)+"/");var p=y.getPooled(t,i,o,r);!function(e,t,s){null==e||function e(t,s,o,r){var i,p=typeof t;if("undefined"!==p&&"boolean"!==p||(t=null),null===t||"string"===p||"number"===p||"object"===p&&t.$$typeof===n)return o(r,t,""===s?"."+c(t,0):s),1;var u=0,d=""===s?".":s+":";if(Array.isArray(t))for(var b=0;b<t.length;b++)u+=e(i=t[b],d+c(i,b),o,r);else{var m=function(e){var t=e&&(l&&e[l]||e["@@iterator"]);if("function"==typeof t)return t}(t);if(m)for(var h,y=m.call(t),g=0;!(h=y.next()).done;)u+=e(i=h.value,d+c(i,g++),o,r);else if("object"===p){var f=""+t;a(!1,"Objects are not valid as a React child (found: %s).%s","[object Object]"===f?"object with keys {"+Object.keys(t).join(", ")+"}":f,"")}}return u}(e,"",t,s)}(e,g,p),y.release(p)}y.prototype.destructor=function(){this.result=null,this.keyPrefix=null,this.func=null,this.context=null,this.count=0},d=function(e,t,s,o){if(this.instancePool.length){var n=this.instancePool.pop();return this.call(n,e,t,s,o),n}return new this(e,t,s,o)},(b=y).instancePool=[],b.getPooled=d||m,b.poolSize||(b.poolSize=10),b.release=function(e){a(e instanceof this,"Trying to release an instance into a pool of a different type."),e.destructor(),this.instancePool.length<this.poolSize&&this.instancePool.push(e)},e.exports=function(e){if("object"!=typeof e||!e||Array.isArray(e))return i(!1,"React.addons.createFragment only accepts a single object. Got: %s",e),e;if(o.isValidElement(e))return i(!1,"React.addons.createFragment does not accept a ReactElement without a wrapper object."),e;a(1!==e.nodeType,"React.addons.createFragment(...): Encountered an invalid child; DOM elements are not valid children of React components.");var t=[];for(var s in e)f(e[s],t,s,r.thatReturnsArgument);return t}},96:function(e,t,s){"use strict";e.exports=function(e,t,s,o,n,r,a,i){if(!e){var l;if(void 0===t)l=new Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var c=[s,o,n,r,a,i],p=0;(l=new Error(t.replace(/%s/g,(function(){return c[p++]})))).name="Invariant Violation"}throw l.framesToPop=1,l}}},97:function(e,t,s){"use strict";var o=s(68);e.exports=o},98:function(e,t,s){"use strict";function o(e){return e.match(/^\{\{\//)?{type:"componentClose",value:e.replace(/\W/g,"")}:e.match(/\/\}\}$/)?{type:"componentSelfClosing",value:e.replace(/\W/g,"")}:e.match(/^\{\{/)?{type:"componentOpen",value:e.replace(/\W/g,"")}:{type:"string",value:e}}e.exports=function(e){return e.split(/(\{\{\/?\s*\w+\s*\/?\}\})/g).map(o)}}});