/* Load this script using conditional IE comments if you need to support IE 7 and IE 6. */

window.onload = function() {
	function addIcon(el, entity) {
		var html = el.innerHTML;
		el.innerHTML = '<span style="font-family: \'Elusive-Icons\'">' + entity + '</span>' + html;
	}
	var icons = {
			'icon-move' : '&#xe074;',
			'icon-music' : '&#xe073;',
			'icon-network' : '&#xe072;',
			'icon-off' : '&#xe071;',
			'icon-ok' : '&#xe070;',
			'icon-ok-circle' : '&#xe06f;',
			'icon-ok-sign' : '&#xe06e;',
			'icon-paper-clip' : '&#xe06d;',
			'icon-paper-clip-alt' : '&#xe06c;',
			'icon-path' : '&#xe06b;',
			'icon-plus-sign' : '&#xe059;',
			'icon-print' : '&#xe058;',
			'icon-qrcode' : '&#xe057;',
			'icon-question' : '&#xe056;',
			'icon-question-sign' : '&#xe055;',
			'icon-quotes' : '&#xe054;',
			'icon-quotes-alt' : '&#xe053;',
			'icon-random' : '&#xe052;',
			'icon-record' : '&#xe051;',
			'icon-reddit' : '&#xe050;',
			'icon-refresh' : '&#xe04f;',
			'icon-screenshot' : '&#xe03f;',
			'icon-search' : '&#xe03e;',
			'icon-search-alt' : '&#xe03d;',
			'icon-share' : '&#xe03c;',
			'icon-share-alt' : '&#xe03b;',
			'icon-shopping-cart' : '&#xe03a;',
			'icon-shopping-cart-sign' : '&#xe039;',
			'icon-signal' : '&#xe038;',
			'icon-skype' : '&#xe037;',
			'icon-slideshare' : '&#xe036;',
			'icon-smiley' : '&#xe035;',
			'icon-th-large' : '&#xe023;',
			'icon-th-list' : '&#xe022;',
			'icon-thumbs-down' : '&#xe021;',
			'icon-thumbs-up' : '&#xe020;',
			'icon-time' : '&#xe01f;',
			'icon-time-alt' : '&#xe01e;',
			'icon-tint' : '&#xe01d;',
			'icon-torso' : '&#xe01c;',
			'icon-trash' : '&#xe01b;',
			'icon-trash-alt' : '&#xe01a;',
			'icon-tumblr' : '&#xe019;',
			'icon-w3c' : '&#xe00a;',
			'icon-warning-sign' : '&#xe009;',
			'icon-website' : '&#xe008;',
			'icon-website-alt' : '&#xe007;',
			'icon-wheelchair' : '&#xe006;',
			'icon-wordpress' : '&#xe005;',
			'icon-wrench' : '&#xe004;',
			'icon-wrench-alt' : '&#xe003;',
			'icon-youtube' : '&#xe002;',
			'icon-zoom-in' : '&#xe001;',
			'icon-zoom-out' : '&#xe000;',
			'icon-pause-alt' : '&#xe069;',
			'icon-pencil' : '&#xe068;',
			'icon-pencil-alt' : '&#xe067;',
			'icon-person' : '&#xe066;',
			'icon-phone' : '&#xe065;',
			'icon-phone-alt' : '&#xe064;',
			'icon-photo' : '&#xe063;',
			'icon-photo-alt' : '&#xe062;',
			'icon-picasa' : '&#xe061;',
			'icon-picture' : '&#xe060;',
			'icon-pinterest' : '&#xe05f;',
			'icon-plane' : '&#xe05e;',
			'icon-play-alt' : '&#xe05c;',
			'icon-play-circle' : '&#xe05b;',
			'icon-plus' : '&#xe05a;',
			'icon-remove' : '&#xe04e;',
			'icon-remove-circle' : '&#xe04d;',
			'icon-remove-sign' : '&#xe04c;',
			'icon-repeat' : '&#xe04b;',
			'icon-repeat-alt' : '&#xe04a;',
			'icon-resize-full' : '&#xe049;',
			'icon-resize-horizontal' : '&#xe048;',
			'icon-resize-small' : '&#xe047;',
			'icon-resize-vertical' : '&#xe046;',
			'icon-retweet' : '&#xe045;',
			'icon-reverse-alt' : '&#xe044;',
			'icon-road' : '&#xe043;',
			'icon-rss' : '&#xe042;',
			'icon-screen' : '&#xe041;',
			'icon-screen-alt' : '&#xe040;',
			'icon-smiley-alt' : '&#xe034;',
			'icon-speaker' : '&#xe033;',
			'icon-stackoverflow' : '&#xe032;',
			'icon-star' : '&#xe031;',
			'icon-star-alt' : '&#xe030;',
			'icon-star-empty' : '&#xe02f;',
			'icon-stop-alt' : '&#xe02b;',
			'icon-stumbleupon' : '&#xe02a;',
			'icon-tag' : '&#xe029;',
			'icon-tags' : '&#xe028;',
			'icon-tasks' : '&#xe027;',
			'icon-text-height' : '&#xe026;',
			'icon-text-width' : '&#xe025;',
			'icon-th' : '&#xe024;',
			'icon-twitter' : '&#xe018;',
			'icon-universal-access' : '&#xe017;',
			'icon-unlock' : '&#xe016;',
			'icon-unlock-alt' : '&#xe015;',
			'icon-upload' : '&#xe014;',
			'icon-user' : '&#xe013;',
			'icon-video' : '&#xe012;',
			'icon-video-alt' : '&#xe011;',
			'icon-video-chat' : '&#xe010;',
			'icon-view-mode' : '&#xe00f;',
			'icon-vimeo' : '&#xe00e;',
			'icon-vkontakte' : '&#xe10e;',
			'icon-volume-down' : '&#xe00d;',
			'icon-volume-off' : '&#xe00c;',
			'icon-volume-up' : '&#xe00b;',
			'icon-backward' : '&#xe0ab;',
			'icon-fast-backward' : '&#xe09a;',
			'icon-fast-forward' : '&#xe099;',
			'icon-forward' : '&#xe093;',
			'icon-play' : '&#xe05d;',
			'icon-step-backward' : '&#xe02e;',
			'icon-step-forward' : '&#xe02d;',
			'icon-briefcase' : '&#xe10d;',
			'icon-bullhorn' : '&#xe10c;',
			'icon-calendar' : '&#xe10b;',
			'icon-calendar-sign' : '&#xe10a;',
			'icon-address-book' : '&#xe0dd;',
			'icon-address-book-alt' : '&#xe0dc;',
			'icon-adjust' : '&#xe0db;',
			'icon-adult' : '&#xe0da;',
			'icon-align-center' : '&#xe0d9;',
			'icon-align-justify' : '&#xe0d8;',
			'icon-align-left' : '&#xe0d7;',
			'icon-align-right' : '&#xe0d6;',
			'icon-arrow-down' : '&#xe0d5;',
			'icon-arrow-left' : '&#xe0d4;',
			'icon-arrow-right' : '&#xe0af;',
			'icon-arrow-up' : '&#xe0ae;',
			'icon-asl' : '&#xe0ad;',
			'icon-asterisk' : '&#xe0ac;',
			'icon-ban-circle' : '&#xe0aa;',
			'icon-barcode' : '&#xe0d3;',
			'icon-behance' : '&#xe0d2;',
			'icon-bell' : '&#xe0d1;',
			'icon-blind' : '&#xe0d0;',
			'icon-blogger' : '&#xe0cf;',
			'icon-bold' : '&#xe0ce;',
			'icon-book' : '&#xe0f5;',
			'icon-bookmark' : '&#xe0f4;',
			'icon-bookmark-empty' : '&#xe0f3;',
			'icon-braille' : '&#xe0f2;',
			'icon-camera' : '&#xe0a9;',
			'icon-cc' : '&#xe0a8;',
			'icon-certificate' : '&#xe0a7;',
			'icon-check' : '&#xe0a6;',
			'icon-check-empty' : '&#xe0a5;',
			'icon-chevron-down' : '&#xe0a4;',
			'icon-chevron-left' : '&#xe0cd;',
			'icon-chevron-right' : '&#xe0cc;',
			'icon-chevron-up' : '&#xe0cb;',
			'icon-child' : '&#xe0ca;',
			'icon-circle-arrow-down' : '&#xe0c9;',
			'icon-circle-arrow-left' : '&#xe0c8;',
			'icon-circle-arrow-right' : '&#xe0f1;',
			'icon-circle-arrow-up' : '&#xe0f0;',
			'icon-cloud' : '&#xe0ef;',
			'icon-cloud-alt' : '&#xe0ee;',
			'icon-cog' : '&#xe109;',
			'icon-cog-alt' : '&#xe108;',
			'icon-cogs' : '&#xe107;',
			'icon-comment' : '&#xe106;',
			'icon-comment-alt' : '&#xe0a3;',
			'icon-compass' : '&#xe0a2;',
			'icon-compass-alt' : '&#xe0a1;',
			'icon-credit-card' : '&#xe0a0;',
			'icon-css' : '&#xe09f;',
			'icon-dashboard' : '&#xe09e;',
			'icon-delicious' : '&#xe0c7;',
			'icon-deviantart' : '&#xe0c6;',
			'icon-digg' : '&#xe0c5;',
			'icon-download' : '&#xe0c4;',
			'icon-download-alt' : '&#xe0c3;',
			'icon-dribble' : '&#xe0c2;',
			'icon-edit' : '&#xe0ed;',
			'icon-eject' : '&#xe0ec;',
			'icon-envelope' : '&#xe0eb;',
			'icon-envelope-alt' : '&#xe0ea;',
			'icon-error' : '&#xe105;',
			'icon-error-alt' : '&#xe104;',
			'icon-exclamation-sign' : '&#xe103;',
			'icon-eye-close' : '&#xe102;',
			'icon-eye-open' : '&#xe09d;',
			'icon-facebook' : '&#xe09c;',
			'icon-facetime-video' : '&#xe09b;',
			'icon-female' : '&#xe098;',
			'icon-file' : '&#xe0c1;',
			'icon-file-alt' : '&#xe0c0;',
			'icon-file-edit' : '&#xe0bf;',
			'icon-file-edit-alt' : '&#xe0be;',
			'icon-file-new' : '&#xe0bd;',
			'icon-file-new-alt' : '&#xe0bc;',
			'icon-film' : '&#xe0e9;',
			'icon-filter' : '&#xe0e8;',
			'icon-fire' : '&#xe0e7;',
			'icon-flag' : '&#xe0e6;',
			'icon-flag-alt' : '&#xe101;',
			'icon-flickr' : '&#xe100;',
			'icon-folder' : '&#xe0ff;',
			'icon-folder-close' : '&#xe0fe;',
			'icon-folder-open' : '&#xe097;',
			'icon-folder-sign' : '&#xe096;',
			'icon-font' : '&#xe095;',
			'icon-fontsize' : '&#xe094;',
			'icon-forward-alt' : '&#xe092;',
			'icon-foursquare' : '&#xe0bb;',
			'icon-friendfeed' : '&#xe0ba;',
			'icon-friendfeed-rect' : '&#xe0b9;',
			'icon-fullscreen' : '&#xe0b8;',
			'icon-gift' : '&#xe0b7;',
			'icon-github' : '&#xe0b6;',
			'icon-github-text' : '&#xe0e5;',
			'icon-glass' : '&#xe0e4;',
			'icon-glasses' : '&#xe0e3;',
			'icon-globe' : '&#xe0e2;',
			'icon-globe-alt' : '&#xe0fd;',
			'icon-googleplus' : '&#xe0fc;',
			'icon-graph' : '&#xe0fb;',
			'icon-graph-alt' : '&#xe0fa;',
			'icon-group' : '&#xe091;',
			'icon-group-alt' : '&#xe090;',
			'icon-guidedog' : '&#xe08f;',
			'icon-hand-down' : '&#xe08e;',
			'icon-hand-left' : '&#xe08d;',
			'icon-hand-right' : '&#xe08c;',
			'icon-hand-up' : '&#xe0b5;',
			'icon-hdd' : '&#xe0b4;',
			'icon-headphones' : '&#xe0b3;',
			'icon-hearing-impaired' : '&#xe0b2;',
			'icon-heart' : '&#xe0b1;',
			'icon-heart-alt' : '&#xe0b0;',
			'icon-heart-empty' : '&#xe0e1;',
			'icon-home' : '&#xe0e0;',
			'icon-home-alt' : '&#xe0df;',
			'icon-idea' : '&#xe0de;',
			'icon-idea-alt' : '&#xe0f9;',
			'icon-inbox' : '&#xe0f8;',
			'icon-inbox-alt' : '&#xe0f7;',
			'icon-inbox-box' : '&#xe0f6;',
			'icon-indent-left' : '&#xe08b;',
			'icon-indent-right' : '&#xe08a;',
			'icon-info-sign' : '&#xe089;',
			'icon-instagram' : '&#xe088;',
			'icon-iphone-home' : '&#xe087;',
			'icon-italic' : '&#xe086;',
			'icon-key' : '&#xe085;',
			'icon-laptop' : '&#xe084;',
			'icon-laptop-alt' : '&#xe083;',
			'icon-leaf' : '&#xe082;',
			'icon-linkedin' : '&#xe081;',
			'icon-list' : '&#xe080;',
			'icon-list-alt' : '&#xe07f;',
			'icon-lock' : '&#xe07e;',
			'icon-lock-alt' : '&#xe07d;',
			'icon-magnet' : '&#xe07c;',
			'icon-male' : '&#xe07b;',
			'icon-map-marker' : '&#xe07a;',
			'icon-map-marker-alt' : '&#xe079;',
			'icon-mic' : '&#xe078;',
			'icon-mic-alt' : '&#xe077;',
			'icon-minus' : '&#xe076;',
			'icon-minus-sign' : '&#xe075;',
			'icon-pause' : '&#xe06a;',
			'icon-fork' : '&#xe10f;',
			'icon-broom' : '&#xe110;',
			'icon-return-key' : '&#xe111;',
			'icon-lastfm' : '&#xe112;',
			'icon-livejournal' : '&#xe113;',
			'icon-myspace' : '&#xe114;',
			'icon-soundcloud' : '&#xe115;',
			'icon-viadeo' : '&#xe116;',
			'icon-spotify' : '&#xe117;',
			'icon-caret-left' : '&#xe119;',
			'icon-caret-up' : '&#xe02c;',
			'icon-caret-right' : '&#xe118;',
			'icon-caret-down' : '&#xe11a;',
			'icon-stop' : '&#xe11b;'
		},
		els = document.getElementsByTagName('*'),
		i, attr, html, c, el;
	for (i = 0; ; i += 1) {
		el = els[i];
		if(!el) {
			break;
		}
		attr = el.getAttribute('data-icon');
		if (attr) {
			addIcon(el, attr);
		}
		c = el.className;
		c = c.match(/icon-[^\s'"]+/);
		if (c && icons[c[0]]) {
			addIcon(el, icons[c[0]]);
		}
	}
};