<?php

function gfxbucket_image_func( $atts, $content ) {
	extract(shortcode_atts( array(
        'url' => '',
        'alt' => ''
	), $atts ));

	return '<img src="' . $url . '" alt="' . $alt . '" />';
}
add_shortcode( 'image', 'gfxbucket_image_func' );