<h1><?php esc_html_e( 'Welcome To SiteOrigin Page Builder', 'siteorigin-panels' ); ?></h1>

<p>
	<?php esc_html_e( 'Page Builder by SiteOrigin makes it easy to create responsive column based content, using the widgets you know and love. Your content will accurately adapt to all mobile devices, ensuring your site is mobile-ready.', 'siteorigin-panels' ); ?>
</p>

<p>
	<?php printf( esc_html__( "Page Builder works with standard WordPress widgets, so you’ll always find the widget you need. We've also created the %s to give you a wide range of additional functionality. All the widgets are built on our powerful framework, giving you advanced forms, unlimited colours and 1500+ icons.", 'siteorigin-panels' ), '<a href="https://wordpress.org/plugins/so-widgets-bundle/" target="_blank">SiteOrigin Widgets Bundle</a>' ); ?>
</p>

<h2><?php esc_html_e( 'Simple Drag and Drop', 'siteorigin-panels' ); ?></h2>

<p>
	<?php esc_html_e( "Reorder rows, move widgets, resize columns and build your page, all with your mouse. Page Builder makes it easy to nudge every detail into place, no matter how often you change your mind. We've meticulously crafted each and every interaction to make sure they all feel natural. It's intuitive content editing that doesn't sacrifice on functionality.", 'siteorigin-panels' ); ?>
</p>

<h2><?php esc_html_e( 'Live Editing', 'siteorigin-panels' ); ?></h2>

<p>
	<?php esc_html_e( 'The live editor gives you an exact preview of your content, that you can edit in real-time. You can use this to pin-point the sections and widgets you want to edit, then see those edits without leaving the page. Create content in a fraction of the time.', 'siteorigin-panels' ); ?>
</p>

<h2><?php esc_html_e( 'History Browser', 'siteorigin-panels' ); ?></h2>

<p>
	<?php esc_html_e( 'Worry free editing is having the freedom to experiment without fearing mistakes. The History Browser lets you roll forward and back through your changes. Preview changes, then roll back to that version without skipping a beat. Your personal safety net.', 'siteorigin-panels' ); ?>
</p>

<h2><?php esc_html_e( 'Row and Widget Styles', 'siteorigin-panels' ); ?></h2>

<p>
	<?php esc_html_e( 'Row and widget styles give you all the control you need to make your content uniquely your own. Change attributes like paddings, background colours and column spacing. You can also enter custom CSS and CSS classes if you need even finer grained control.', 'siteorigin-panels' ); ?>
</p>

<h2><?php esc_html_e( 'Get More Features', 'siteorigin-panels' ); ?></h2>

<p>
	<?php printf( esc_html__( '%s is a single plugin that adds additional settings and functionality to Page Builder, SiteOrigin widgets and SiteOrign themes. SiteOrigin Premium also includes our next level email support service. If you need expert advice and quick replies, consider SiteOrigin Premium.', 'siteorigin-panels' ), '<a href="https://siteorigin.com/downloads/premium/" target="_blank">SiteOrigin Premium</a>' ); ?>
</p>

<iframe src="https://player.vimeo.com/video/314964526" width="800" height="450" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>
