#yoast-seo-dashboard-widget h3{font-weight:700}#yoast-seo-dashboard-widget .assessments,#yoast-seo-dashboard-widget .score-assessments{padding-left:0}#yoast-seo-dashboard-widget .wincher-seo-performance,#yoast-seo-dashboard-widget .wordpress-feed{border-top:1px solid #eee;margin:16px -12px 0;padding:12px 12px 0}#yoast-seo-dashboard-widget .wordpress-feed .wordpress-feed__post{margin-top:12px}#yoast-seo-dashboard-widget .wordpress-feed .wordpress-feed__footer{border-top:1px solid #eee;margin:0 -12px;padding:4px 12px 0}#yoast-seo-ryte-assessment{border-top:1px solid #eee;margin:12px -12px 0;padding:12px 12px 0}#yoast-seo-ryte-assessment .button{margin-right:8px}#yoast-seo-ryte-assessment .button.landing-page{background:#a4286a;border-color:#7b1e4f #6f1b47 #6f1b47;box-shadow:0 1px 0 #6f1b47;color:#fff}#yoast-seo-ryte-assessment .button.landing-page:focus,#yoast-seo-ryte-assessment .button.landing-page:hover{background:#90235d;border-color:#6f1b47}#yoast-seo-ryte-assessment .button.landing-page:focus{box-shadow:0 1px 0 #7b1e4f,0 0 2px 1px #a35685}#yoast-seo-ryte-assessment .button.landing-page:active{background:#7b1e4f;border-color:#6f1b47;box-shadow:inset 0 2px 0 #6f1b47;vertical-align:top}#yoast-seo-dashboard-widget:empty:before{animation:rotate 2s linear infinite;background-image:url(../../packages/js/images/Yoast_SEO_Icon.svg);content:"";display:block;height:40px;margin:25px auto;width:40px}@keyframes rotate{0%{transform:perspective(120px) rotateX(0deg) rotateY(0deg);-webkit-transform:perspective(120px) rotateX(0deg) rotateY(0deg)}to{transform:perspective(120px) rotateX(0deg) rotateY(1turn);-webkit-transform:perspective(120px) rotateX(0deg) rotateY(1turn)}}