<?php
	$image = $instance['image_fallback'];

	if( $instance['image'] ) {
		$image = wp_get_attachment_image_src($instance['image'], 'full');
		$image = $image[0];
	}

	echo do_shortcode('[icon style="' . $instance['style'] . '" image="' . $image . '" color="' . $instance['color'] . '" icon="' . $instance['icon'] . '" text="' . $instance['text'] . '" title="' . $instance['title'] . '"]');
?>