window.yoast=window.yoast||{},window.yoast.Researcher=function(e){var t={};function n(r){if(t[r])return t[r].exports;var s=t[r]={i:r,l:!1,exports:{}};return e[r].call(s.exports,s,s.exports,n),s.l=!0,s.exports}return n.m=e,n.c=t,n.d=function(e,t,r){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var s in e)n.d(r,s,function(t){return e[t]}.bind(null,s));return r},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=49)}({0:function(e,t){e.exports=window.yoast.analysis},49:function(e,t,n){"use strict";n.r(t),n.d(t,"default",(function(){return u}));var r=n(0);const{baseStemmer:s}=r.languageProcessing;function o(){return s}const{AbstractResearcher:i}=r.languageProcessing;class u extends i{constructor(e){super(e),delete this.defaultResearches.getFleschReadingScore,delete this.defaultResearches.getPassiveVoiceResult,delete this.defaultResearches.getSentenceBeginnings,delete this.defaultResearches.findTransitionWords,delete this.defaultResearches.functionWordsInKeyphrase,delete this.defaultResearches.wordComplexity,Object.assign(this.config,{functionWords:[]}),Object.assign(this.helpers,{getStemmer:o})}}}});