@font-face{font-family:'anything-carousel-arrows';src:url('fonts/carousel-arrows.eot?-95vnmw');src:url('fonts/carousel-arrows.eot?#iefix-95vnmw') format('embedded-opentype'),url('fonts/carousel-arrows.woff?-95vnmw') format('woff'),url('fonts/carousel-arrows.ttf?-95vnmw') format('truetype'),url('fonts/carousel-arrows.svg?-95vnmw#carousel-arrows') format('svg');font-weight:normal;font-style:normal;font-display:block}.so-widget-sow-anything-carousel .sow-carousel-container{align-items:center;display:flex;justify-content:center}body.rtl .so-widget-sow-anything-carousel .sow-carousel-container{flex-direction:row-reverse}.so-widget-sow-anything-carousel .sow-carousel-container a.sow-carousel-next,.so-widget-sow-anything-carousel .sow-carousel-container a.sow-carousel-previous{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-family:'anything-carousel-arrows';font-style:normal;font-variant:normal;font-weight:normal;text-align:center;text-decoration:none;text-transform:none}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper{left:0;overflow:hidden;position:relative;right:0;width:100%}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .sow-carousel-items{zoom:1;margin:0;padding:0;transition:all .45s ease}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .sow-carousel-items:before{content:'';display:block}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .sow-carousel-items:after{clear:both;content:'';display:table}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .sow-carousel-items .sow-carousel-item{display:block}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .slick-dots{display:block;line-height:0;list-style:none;margin:0;padding:0;text-align:center;width:100%}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .slick-dots li{cursor:pointer;display:inline-block;margin:0;padding:0;position:relative}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .slick-dots li button{background:transparent;border:0;box-shadow:none;color:transparent;cursor:pointer;display:block;font-size:0;font-style:normal;letter-spacing:normal;line-height:0;margin:0;outline:none;padding:0}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .slick-dots li button:active,.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .slick-dots li button:hover,.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .slick-dots li button:focus{box-shadow:none;outline:none}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .slick-dots li button:before{content:'•';display:block;font-family:initial;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;position:relative;text-align:center}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .slick-dots li.slick-active button:before{opacity:1}.so-widget-sow-anything-carousel .sow-carousel-container .sow-carousel-wrapper .slick-dots li.slick-active button:hover{cursor:default}