.so-panel {
  -webkit-transition-duration: 0.6s !important;
  transition-duration: 0.6s !important;
}
.so-panel.so-panels-highlighted {
  opacity: 1 !important;
}
.so-panel.so-panels-faded {
  opacity: 0.275 !important;
}
