div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field input[type="text"].siteorigin-widget-input-measurement{float:left;max-width:58px;margin-right:5px;min-height:30px;vertical-align:middle;padding:0 8px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field select.sow-measurement-select-unit{min-width:inherit;padding:0 24px 0;width:auto}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field input[type="text"].siteorigin-widget-input-measurement,div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field select.sow-measurement-select-unit{line-height:2em}@media (max-width:680px){div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field input[type="text"].siteorigin-widget-input-measurement{margin-right:1%;max-width:none}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field input[type="text"].siteorigin-widget-input-measurement,div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field select.sow-measurement-select-unit{width:49%}}