<?php

function gfxbucket_more_func( $atts, $content ) {
	extract(shortcode_atts( array(
        'url' 	     => '#',
        'new_window' => 'false',
        'text'       => ''
	), $atts ));

	// If set, wrap target attribute with HTML target attribute
	$target = '';
	if( $new_window == 'true' || $new_window == '1' ) {
		$target = ' target="_blank"';
	}

	// Return more shortcode
	return '<a class="more" href="' . $url . '"' . $target . '>' . $text . '</a>';
}
add_shortcode( 'more', 'gfxbucket_more_func' );