div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-radio .siteorigin-widget-image-radio-layout-horizontal{display:grid;grid-template-columns:repeat(auto-fill, minmax(215px, 1fr));grid-gap:12px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-radio .siteorigin-widget-image-radio-items{margin-bottom:10px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-radio label.so-image-radio{display:flex;align-items:center;padding:10px;background-color:#f6f6f6;border:1px solid #e6e6e6}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-radio label.so-image-radio img{max-width:100px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-radio label.so-image-radio input{margin:0 4px 0 10px}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-radio label.so-image-radio.so-selected{background:#eaf2f6;border-color:#c9d0d4}div.siteorigin-widget-form div.siteorigin-widget-field.siteorigin-widget-field-type-image-radio label.so-image-radio.so-selected img{box-shadow:0 0 3px rgba(0,0,0,0.15)}