<?php

return array(
	'white' => array(
		'background_color' => '#F5F5F5',
		'text_darken' => '45%',
		'text_shadow' => '30%',
	),

	'charcoal' => array(
		'background_color' => '#999999',
	),

	'pink' => array(
		'background_color' => '#f6778c',
	),

	'orange' => array(
		'background_color' => '#fece62',
		'text_darken' => '37.5%',
	),

	'green' => array(
		'background_color' => '#b7d870',
		'text_darken' => '37.5%',
	),

	'blue' => array(
		'background_color' => '#91dbf6',
		'text_darken' => '37.5%',
	),

	'purple' => array(
		'background_color' => '#e5b2dd',
	),

	'turquoise' => array(
		'background_color' => '#a2ebf1',
	),

	'slate' => array(
		'background_color' => '#a5b7c3',
		'text_darken' => '45%',
		'text_shadow' => '15%',
		'inset_highlight' => '10%',
	),

	'black' => array(
		'background_color' => '#333333',
		'text_darken' => '-75%',
		'text_shadow' => '-30%',
		'inset_highlight' => '17%',
	),
);
