<?php

namespace Yoast\WP\SEO\Actions\Indexation;

/**
 * Action for preparing the indexable indexation routine.
 *
 * @deprecated 15.1 - Use \Yoast\WP\SEO\Actions\Indexing\Indexable_Prepare_Indexation_Action instead.
 * @codeCoverageIgnore
 */
class Indexable_Prepare_Indexation_Action extends \Yoast\WP\SEO\Actions\Indexing\Indexable_Prepare_Indexation_Action {

}
