/**
 * WPMU Dev Card-List styles
 * (Philipp Stracker for WPMU Dev)
 *
 * @since 1.1.0
 */
#wpwrap .wpmui-list-wrapper .wpmui-list,
.wpmui-list-wrapper .wpmui-list {
  margin-left: -16px;
}
#wpwrap .wpmui-list-wrapper .wpmui-list:after,
.wpmui-list-wrapper .wpmui-list:after {
  content: '';
  display: table;
  clear: both;
}
#wpwrap .wpmui-list-wrapper .list-card,
.wpmui-list-wrapper .list-card {
  float: left;
  margin: 0 0 16px 16px;
  width: 48%;
  width: -webkit-calc(50% - 16px);
  width: calc(50% - 16px);
  background-color: #fff;
  border: 1px solid #dedede;
  box-sizing: border-box;
  opacity: .8;
}
#wpwrap .wpmui-list-wrapper .list-card .badge-container,
.wpmui-list-wrapper .list-card .badge-container {
  overflow: hidden;
  width: 100px;
  height: 100px;
  position: absolute;
  left: 0px;
  top: 0px;
}
#wpwrap .wpmui-list-wrapper .list-card .badge-active,
.wpmui-list-wrapper .list-card .badge-active {
  display: none;
}
#wpwrap .wpmui-list-wrapper .list-card.active,
.wpmui-list-wrapper .list-card.active {
  opacity: 1;
  background: #FFF;
  border: 1px solid #BBB;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12);
  z-index: 20;
}
#wpwrap .wpmui-list-wrapper .list-card.active .desc,
#wpwrap .wpmui-list-wrapper .list-card.active .name,
.wpmui-list-wrapper .list-card.active .desc,
.wpmui-list-wrapper .list-card.active .name {
  color: #333;
}
#wpwrap .wpmui-list-wrapper .list-card.active .badge-active,
.wpmui-list-wrapper .list-card.active .badge-active {
  position: absolute;
  top: 15px;
  left: -35px;
  display: block;
  background-color: #6bbb1a;
  color: #FFF;
  transform: rotate(315deg);
  padding: 3px 40px;
  z-index: 20;
  border: 1px solid #FFF;
}
#wpwrap .wpmui-list-wrapper .list-card.active .item-icon,
.wpmui-list-wrapper .list-card.active .item-icon {
  color: #3b8b08;
}
#wpwrap .wpmui-list-wrapper .list-card .item-icon,
.wpmui-list-wrapper .list-card .item-icon {
  position: absolute;
  top: 20px;
  left: 20px;
  width: 128px;
  height: 128px;
  margin: 0 20px 20px 0;
  font-size: 100px;
  z-index: 16;
}
#wpwrap .wpmui-list-wrapper .list-card .item-icon i,
.wpmui-list-wrapper .list-card .item-icon i {
  opacity: 0.8;
  font-size: 100px;
}
#wpwrap .wpmui-list-wrapper .list-card .desc,
#wpwrap .wpmui-list-wrapper .list-card .name,
.wpmui-list-wrapper .list-card .desc,
.wpmui-list-wrapper .list-card .name {
  margin-left: 148px;
  margin-right: 120px;
  color: #777;
}
#wpwrap .wpmui-list-wrapper .list-card .action-links,
.wpmui-list-wrapper .list-card .action-links {
  position: absolute;
  top: 20px;
  right: 20px;
  width: 120px;
  text-align: right;
}
#wpwrap .wpmui-list-wrapper .list-card .action-links .space,
.wpmui-list-wrapper .list-card .action-links .space {
  display: block;
  line-height: 10px;
  height: 10px;
  padding: 0;
  margin: 0;
}
#wpwrap .wpmui-list-wrapper .list-card h4,
.wpmui-list-wrapper .list-card h4 {
  margin: 0 0 12px;
  font-size: 18px;
  line-height: 1.3;
}
@media screen and (min-width: 1600px) {
  #wpwrap .wpmui-list-wrapper .list-card,
  .wpmui-list-wrapper .list-card {
    width: 30%;
    width: -webkit-calc(33.3333% - 16px);
    width: calc(33.3333% - 16px);
  }
}
#wpwrap .wpmui-list-wrapper .list-card-top,
.wpmui-list-wrapper .list-card-top {
  position: relative;
  padding: 20px 20px 10px;
  height: 135px;
  overflow: hidden;
}
#wpwrap .wpmui-list-wrapper .list-card-top .fader,
.wpmui-list-wrapper .list-card-top .fader {
  position: absolute;
  bottom: 0;
  height: 20px;
  left: 0;
  right: 0;
  z-index: 5;
  background: -moz-linear-gradient(top, rgba(255, 255, 255, 0) 0%, white 90%);
  /* FF3.6+ */
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, rgba(255, 255, 255, 0)), color-stop(90%, white));
  /* Chrome,Safari4+ */
  background: -webkit-linear-gradient(top, rgba(255, 255, 255, 0) 0%, white 90%);
  /* Chrome10+,Safari5.1+ */
  background: -o-linear-gradient(top, rgba(255, 255, 255, 0) 0%, white 90%);
  /* Opera 11.10+ */
  background: -ms-linear-gradient(top, rgba(255, 255, 255, 0) 0%, white 90%);
  /* IE10+ */
  background: linear-gradient(to bottom, rgba(255, 255, 255, 0) 0%, white 90%);
  /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#00ffffff', endColorstr='#ffffff',GradientType=0 );
  /* IE6-9 */
}
#wpwrap .wpmui-list-wrapper .list-card-bottom,
.wpmui-list-wrapper .list-card-bottom {
  clear: both;
  padding: 12px 20px;
  background-color: #fafafa;
  border-top: 1px solid #dedede;
  overflow: hidden;
  height: 45px;
}
#wpwrap .wpmui-list-wrapper .details,
#wpwrap .wpmui-list-wrapper .is-detail,
.wpmui-list-wrapper .details,
.wpmui-list-wrapper .is-detail {
  display: none;
}
#wpwrap .wpmui-list-wrapper .is-no-detail,
.wpmui-list-wrapper .is-no-detail {
  display: inline;
}
#wpwrap .wpmui-list-wrapper .details .wpmui-html-text-wrapper,
#wpwrap .wpmui-list-wrapper .details .wpmui-input-wrapper,
#wpwrap .wpmui-list-wrapper .details .wpmui-select-wrapper,
#wpwrap .wpmui-list-wrapper .details .wpmui-radio-wrapper,
#wpwrap .wpmui-list-wrapper .details .wpmui-radio-slider-wrapper,
.wpmui-list-wrapper .details .wpmui-html-text-wrapper,
.wpmui-list-wrapper .details .wpmui-input-wrapper,
.wpmui-list-wrapper .details .wpmui-select-wrapper,
.wpmui-list-wrapper .details .wpmui-radio-wrapper,
.wpmui-list-wrapper .details .wpmui-radio-slider-wrapper {
  display: block;
  position: relative;
  padding: 10px;
  margin: 0 0 10px 0;
  background-color: #FFF;
  border: 1px solid #dedede;
}
#wpwrap .wpmui-list-wrapper .details .wpmui-html-text-wrapper .wpmui-radio-slider,
#wpwrap .wpmui-list-wrapper .details .wpmui-input-wrapper .wpmui-radio-slider,
#wpwrap .wpmui-list-wrapper .details .wpmui-select-wrapper .wpmui-radio-slider,
#wpwrap .wpmui-list-wrapper .details .wpmui-radio-wrapper .wpmui-radio-slider,
#wpwrap .wpmui-list-wrapper .details .wpmui-radio-slider-wrapper .wpmui-radio-slider,
.wpmui-list-wrapper .details .wpmui-html-text-wrapper .wpmui-radio-slider,
.wpmui-list-wrapper .details .wpmui-input-wrapper .wpmui-radio-slider,
.wpmui-list-wrapper .details .wpmui-select-wrapper .wpmui-radio-slider,
.wpmui-list-wrapper .details .wpmui-radio-wrapper .wpmui-radio-slider,
.wpmui-list-wrapper .details .wpmui-radio-slider-wrapper .wpmui-radio-slider {
  position: absolute;
  top: 10px;
  right: 10px;
}
#wpwrap .wpmui-list-wrapper .details .wpmui-html-text-wrapper .wpmui-radio-slider.has-labels,
#wpwrap .wpmui-list-wrapper .details .wpmui-input-wrapper .wpmui-radio-slider.has-labels,
#wpwrap .wpmui-list-wrapper .details .wpmui-select-wrapper .wpmui-radio-slider.has-labels,
#wpwrap .wpmui-list-wrapper .details .wpmui-radio-wrapper .wpmui-radio-slider.has-labels,
#wpwrap .wpmui-list-wrapper .details .wpmui-radio-slider-wrapper .wpmui-radio-slider.has-labels,
.wpmui-list-wrapper .details .wpmui-html-text-wrapper .wpmui-radio-slider.has-labels,
.wpmui-list-wrapper .details .wpmui-input-wrapper .wpmui-radio-slider.has-labels,
.wpmui-list-wrapper .details .wpmui-select-wrapper .wpmui-radio-slider.has-labels,
.wpmui-list-wrapper .details .wpmui-radio-wrapper .wpmui-radio-slider.has-labels,
.wpmui-list-wrapper .details .wpmui-radio-slider-wrapper .wpmui-radio-slider.has-labels {
  position: relative;
  top: 0;
  right: 0;
}
#wpwrap .wpmui-list-wrapper .wpmui-list-table.has-details:before,
.wpmui-list-wrapper .wpmui-list-table.has-details:before {
  content: '';
  background: #000;
  opacity: .3;
  position: fixed;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  z-index: 21;
}
#wpwrap .wpmui-list-wrapper .wpmui-list-table.has-details .list-card,
.wpmui-list-wrapper .wpmui-list-table.has-details .list-card {
  opacity: .7;
}
#wpwrap .wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode,
.wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode {
  z-index: 25;
  opacity: 1;
}
#wpwrap .wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode .is-detail,
.wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode .is-detail {
  display: inline;
}
#wpwrap .wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode .is-no-detail,
.wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode .is-no-detail {
  display: none;
}
#wpwrap .wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode .list-card-top,
.wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode .list-card-top {
  position: absolute;
  top: 0;
  bottom: 43px;
  height: auto;
  left: 0;
  right: 0;
  overflow: visible;
}
#wpwrap .wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode .details,
.wpmui-list-wrapper .wpmui-list-table.has-details .detail-mode .details {
  display: block;
  position: absolute;
  overflow: auto;
  top: 135px;
  left: 0;
  right: 0;
  background: #FCFCFC;
  border-top: 1px solid #dedede;
  padding: 20px;
  bottom: 0;
}
#wpwrap .wpmui-list-wrapper .detail-mode,
.wpmui-list-wrapper .detail-mode {
  position: absolute;
  top: 50px;
  left: 50px;
  right: 50px;
  width: auto;
  height: auto;
  z-index: 20;
  box-shadow: 0 1px 10px rgba(0, 0, 0, 0.3);
  opacity: 1;
}
#wpwrap .wpmui-list-wrapper .detail-mode .list-card,
.wpmui-list-wrapper .detail-mode .list-card {
  border: 1px solid #999;
}
#wpwrap .wpmui-list-wrapper .detail-mode .list-card-bottom,
.wpmui-list-wrapper .detail-mode .list-card-bottom {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
}
#wpwrap .wpmui-list-wrapper .toggle-details,
.wpmui-list-wrapper .toggle-details {
  cursor: pointer;
}
#wpwrap .wpmui-list-wrapper .toggle-link,
.wpmui-list-wrapper .toggle-link {
  float: right;
  color: #0074a2;
}
#wpwrap .wpmui-list-wrapper .toggle-link:hover,
.wpmui-list-wrapper .toggle-link:hover {
  color: #2ea2cc;
}
#wpwrap .wpmui-list-wrapper .filter-links > li,
.wpmui-list-wrapper .filter-links > li {
  line-height: 48px;
  height: 48px;
}
#wpwrap .wpmui-list-wrapper .filter-links > li a,
.wpmui-list-wrapper .filter-links > li a {
  padding-top: 0;
  padding-bottom: 0;
}
#wpwrap .wpmui-list-wrapper .close-button,
.wpmui-list-wrapper .close-button {
  position: absolute;
  top: -30px;
  right: -30px;
  border-radius: 15px;
  background: #FFF;
}
#wpwrap .wpmui-list-wrapper .close-button:after,
.wpmui-list-wrapper .close-button:after {
  content: "\f335";
  display: inline-block;
  width: 30px;
  height: 30px;
  font-size: 26px;
  line-height: 30px;
  font-family: dashicons;
  text-decoration: inherit;
  font-weight: 400;
  font-style: normal;
  vertical-align: top;
  text-align: center;
  -webkit-transition: color .1s ease-in 0;
  transition: color .1s ease-in 0;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
