<?php

namespace YoastSEO_Vendor;

// Don't redefine the functions if included multiple times.
if (!\function_exists('YoastSEO_Vendor\\GuzzleHttp\\uri_template')) {
    require __DIR__ . '/functions.php';
}
