<?php
	$options .= ' type="' . $instance['type'] . '"';
	$options .= ' id="' . $instance['id'] . '"';
	$options .= ' autoplay="' . $instance['autoplay'] . '"';
	$options .= ' loop="' . $instance['loop'] . '"';

	echo do_shortcode('[gfxbucket_video ' . $options . ']');
?>